import datetime
import math
from typing import Tuple

import numpy as np
import pandas as pd

from sampo.schemas.graph import EdgeType
from sampo.utilities.name_mapper import NameMapper


def get_all_connections(graph_df: pd.DataFrame,
                        use_mapper: bool = False,
                        mapper: NameMapper | None = None) \
        -> Tuple[dict[str, list], dict[str, list]]:

    task_name_column = 'granular_name'

    num_tasks = len(graph_df)
    # Get the upper triangular indices to avoid duplicate pairs
    indices = np.triu_indices(num_tasks, k=1)
    works1_ids = graph_df['activity_id'].values[indices[0]]
    works1_names = graph_df[task_name_column].values[indices[0]]

    works2_ids = graph_df['activity_id'].values[indices[1]]
    works2_names = graph_df[task_name_column].values[indices[1]]

    if use_mapper:
        works1_names = np.vectorize(mapper.get)(works1_names)
        works2_names = np.vectorize(mapper.get)(works2_names)

    return {"ids": works1_ids, "names": works1_names}, {"ids": works2_ids, "names": works2_names}


def get_delta_between_dates(first: str, second: str) -> int:
    return max((datetime.date(int(first.split('-')[0]), int(first.split('-')[1]), int(first.split('-')[2])) -
                datetime.date(int(second.split('-')[0]), int(second.split('-')[1]), int(second.split('-')[2]))).days, 1)


def find_min_without_outliers(lst: list[float]) -> float:
    return round(min([x for x in lst if x >= np.mean(lst) - 3 * np.std(lst)]), 2)


def gather_links_types_statistics(s1: str, f1: str, s2: str, f2: str) \
        -> Tuple[int, int, int, list, list, int, list, list, int, list, list, int, list, list]:
    """
    Count statistics on the occurrence of different mutual arrangement of tasks

    :param s1: start of first work
    :param f1: finish of first work
    :param s2: start of second work
    :param f2: finish of second work
    :return: Statistics on the occurrence of different mutual arrangement of tasks
    """

    fs12, fs21, ss12, ss21 = 0, 0, 0, 0
    ss12_lags, ss12_percent_lags, ss21_lags, ss21_percent_lags = [], [], [], []

    ffs12, ffs21 = 0, 0
    ffs12_lags, ffs12_percent_lags, ffs21_lags, ffs21_percent_lags = [], [], [], []

    if s1 == s2 and f1 == f2:
        ffs12 += 1
        ffs12_percent_lags.append(0.01)
        ffs12_lags.append(0.01)
    if f2 <= s1:
        fs21 += 1
    else:
        if s2 >= f1:
            fs12 += 1
        else:
            if s2 >= s1:
                if f2 >= f1:
                    ffs12 += 1
                    if get_delta_between_dates(f1, s1) != 0:
                        ffs12_percent_lags.append(get_delta_between_dates(s2, s1) / get_delta_between_dates(f1, s1))
                    else:
                        ffs12_percent_lags.append(0)
                    ffs12_lags.append(get_delta_between_dates(s2, s1))
                else:
                    ss12 += 1
                    if get_delta_between_dates(f1, s1) != 0:
                        ss12_percent_lags.append(get_delta_between_dates(s2, s1) / get_delta_between_dates(f1, s1))
                    else:
                        ss12_percent_lags.append(0)
                    ss12_lags.append(get_delta_between_dates(s2, s1))
            else:
                if f2 <= f1:
                    ffs21 += 1
                    if get_delta_between_dates(f2, s2) != 0:
                        ffs21_percent_lags.append(get_delta_between_dates(s1, s2) / get_delta_between_dates(f2, s2))
                    else:
                        ffs21_percent_lags.append(0)
                    ffs21_lags.append(get_delta_between_dates(s1, s2))
                else:
                    ss21 += 1
                    if get_delta_between_dates(f2, s2) != 0:
                        ss21_percent_lags.append(get_delta_between_dates(s1, s2) / get_delta_between_dates(f2, s2))
                    else:
                        ss21_percent_lags.append(0)
                    ss21_lags.append(get_delta_between_dates(s1, s2))
    return fs12, fs21, ss12, ss12_lags, ss12_percent_lags, ss21, ss21_lags, ss21_percent_lags, ffs12, ffs12_lags, ffs12_percent_lags, \
        ffs21, ffs21_lags, ffs21_percent_lags


def get_all_seq_statistic(history_data: pd.DataFrame,
                          graph_df: pd.DataFrame,
                          use_model_name: bool = False,
                          mapper: NameMapper | None = None):
    df_grouped = history_data.copy()

    if use_model_name:
        column_name = 'model_name'
    else:
        if 'granular_name' not in history_data.columns:
            history_data['granular_name'] = [activity_name for activity_name in history_data['work_name']]
        column_name = 'granular_name'

    df_grouped = df_grouped.groupby('upper_works')[column_name].apply(list).reset_index(name="Works")
    works1, works2 = get_all_connections(graph_df, use_model_name, mapper)

    # Declare structure with updated connections

    tasks_names = list(zip(works1['names'], works2['names']))
    tasks_ids = list(zip(works1['ids'], works2['ids']))

    predecessors_info_dict = {w_id: [] for w_id in graph_df['activity_id']}

    if len(tasks_names) != 0:
        for i in range(len(tasks_names)):
            w1, w2 = tasks_names[i]
            w1_id, w2_id = tasks_ids[i]

            if w1 != w2:
                fs12, fs21, ss12, ss21 = 0, 0, 0, 0
                ss12_lags, ss12_percent_lags, ss21_lags, ss21_percent_lags = [], [], [], []

                count = 0

                ffs12, ffs21 = 0, 0
                ffs12_lags, ffs12_percent_lags, ffs21_lags, ffs21_percent_lags = [], [], [], []

                for i, work_list in df_grouped.iterrows():
                    # Looking to see if this pair of works occurred within the same site in the historical data
                    if w1 in work_list['Works'] and w2 in work_list['Works']:
                        ind1 = history_data.loc[(history_data['upper_works'] == work_list['upper_works']) &
                                                (history_data[column_name] == w1)]
                        ind2 = history_data.loc[(history_data['upper_works'] == work_list['upper_works']) &
                                                (history_data[column_name] == w2)]

                        ind1_sorted = ind1.sort_values(by=['first_day', 'last_day']).reset_index(drop=True)
                        ind2_sorted = ind2.sort_values(by=['first_day', 'last_day']).reset_index(drop=True)

                        for l in range(min(len(ind1_sorted), len(ind2_sorted))):
                            s1, f1 = ind1_sorted.loc[l, 'first_day'], ind1_sorted.loc[l, 'last_day']

                            s2, f2 = ind2_sorted.loc[l, 'first_day'], ind2_sorted.loc[l, 'last_day']

                            if not any([type(x) == float for x in [s1, s2, f1, f2]]):
                                tasks_fs12, tasks_fs21, tasks_ss12, tasks_ss12_lags, tasks_ss12_percent_lags, tasks_ss21, tasks_ss21_lags, \
                                    tasks_ss21_percent_lags, tasks_ffs12, tasks_ffs12_lags, tasks_ffs12_percent_lags, tasks_ffs21, tasks_ffs21_lags, tasks_ffs21_percent_lags = gather_links_types_statistics(
                                    s1, f1, s2, f2)

                                count += 1

                                fs12 += tasks_fs12
                                fs21 += tasks_fs21

                                ss12 += tasks_ss12
                                ss12_lags.extend(tasks_ss12_lags)
                                ss12_percent_lags.extend(tasks_ss12_percent_lags)
                                ss21 += tasks_ss21
                                ss21_lags.extend(tasks_ss21_lags)
                                ss21_percent_lags.extend(tasks_ss21_percent_lags)

                                ffs12 += tasks_ffs12
                                ffs12_lags.extend(tasks_ffs12_lags)
                                ffs12_percent_lags.extend(tasks_ffs12_percent_lags)
                                ffs21 += tasks_ffs21
                                ffs21_lags.extend(tasks_ffs21_lags)
                                ffs21_percent_lags.extend(tasks_ffs21_percent_lags)

                if fs12 + ffs12 + ss12 >= fs21 + ffs21 + ss21:
                    order_con = 1
                    fs = fs12
                    ffs = ffs12
                    ss = ss12
                else:
                    order_con = 2
                    fs = fs21
                    ffs = ffs21
                    ss = ss21

                if max([fs, ss, ffs]) != 0:
                    if fs > ss:
                        if ffs > 0:
                            if order_con == 1:
                                predecessors_info_dict[w2_id].append([w1_id, 'FFS',
                                                                      find_min_without_outliers(ffs12_percent_lags),
                                                                      count])
                            else:
                                predecessors_info_dict[w1_id].append([w2_id, 'FFS',
                                                                      find_min_without_outliers(ffs21_percent_lags),
                                                                      count])
                        else:
                            if order_con == 1:
                                predecessors_info_dict[w2_id].append([w1_id, 'FS', 1.0, count])
                            else:
                                predecessors_info_dict[w1_id].append([w2_id, 'FS', 1.0, count])
                    elif ss > ffs:
                        if order_con == 1:
                                predecessors_info_dict[w2_id].append([w1_id, 'SS',
                                                                      find_min_without_outliers(ss12_percent_lags),
                                                                      count])
                        else:
                            predecessors_info_dict[w1_id].append([w2_id, 'SS',
                                                                  find_min_without_outliers(ss21_percent_lags), count])
                    else:
                        if order_con == 1:
                                predecessors_info_dict[w2_id].append([w1_id, 'FFS',
                                                                      find_min_without_outliers(ffs12_percent_lags),
                                                                      count])
                        else:
                            predecessors_info_dict[w1_id].append([w2_id, 'FFS',
                                                                  find_min_without_outliers(ffs21_percent_lags), count])

    return predecessors_info_dict


def set_connections_info(graph_df: pd.DataFrame,
                         history_data: pd.DataFrame,
                         use_model_name: bool = False,
                         mapper: NameMapper | None = None,
                         change_connections_info: bool = False,
                         all_connections: bool = False,
                         id2ind: dict[str, int] = None) \
        -> pd.DataFrame:
    """
    Restore tasks' connection based on history data

    :param: change_connections_info - whether existing connections' information should be modified based on history data
    :param: expert_connections_info - whether existing connections should not be modified based on connection history data
    :return: repaired DataFrame
    """

    def update_connections(pred_ids_lst_tmp, pred_ids_lst, pred_types_lst, pred_lags_lst, pred_counts_lst):
        """Updates existing connections with new data."""
        for i, pred_id in enumerate(pred_ids_lst_tmp):
            if pred_id in pred_ids_lst:
                idx = pred_ids_lst.index(pred_id)
                pred_types_lst_tmp[i] = pred_types_lst[idx]
                pred_lags_lst_tmp[i] = pred_lags_lst[idx]
                pred_counts_lst_tmp[i] = pred_counts_lst[idx]
        return pred_ids_lst_tmp, pred_types_lst_tmp, pred_lags_lst_tmp, pred_counts_lst_tmp

    def append_new_connections(pred_ids_lst_tmp, pred_ids_lst, pred_types_lst, pred_lags_lst, pred_counts_lst):
        """Appends new connections to the existing lists."""
        for i, pred_id in enumerate(pred_ids_lst):
            if pred_id not in pred_ids_lst_tmp and pred_id != '-1' and pred_id in all_works:
                pred_ids_lst_tmp.append(pred_id)
                pred_types_lst_tmp.append(pred_types_lst[i])
                pred_lags_lst_tmp.append(pred_lags_lst[i])
                pred_counts_lst_tmp.append(pred_counts_lst[i])
        return pred_ids_lst_tmp, pred_types_lst_tmp, pred_lags_lst_tmp, pred_counts_lst_tmp

    tasks_df = graph_df.copy()

    INF = np.iinfo(np.int64).max

    # | ------ no changes ------- |
    if not change_connections_info and all_connections:
        tasks_df['counts'] = [[INF] * len(tasks_df['predecessor_ids'][i]) for i in range(tasks_df.shape[0])]

        tasks_df['connection_types'] = tasks_df['connection_types'].apply(
            lambda x: [EdgeType(elem) if elem != '-1' else EdgeType.FinishStart for elem in x]
        )
        return tasks_df

    # | ----------- for cache data ----------- |
    # connections_dict = get_all_seq_statistic(history_data, graph_df, use_model_name, mapper)
    # with open('dormitory.json', 'w') as f:
    #     json.dump(connections_dict, f)

    # | ----------- cached data -------------- |
    gas_network = {"25809398": [], "25809830": [], "25809831": [["25809830", "FFS", 0.01, 76], ["25809850", "FS", 1.0, 2], ["25809853", "FS", 1.0, 2], ["25809855", "FS", 1.0, 4]], "25809833": [["25809830", "FFS", 0.01, 263], ["25809831", "FFS", 0.01, 527]], "25813507": [["25809830", "FFS", 0.01, 57], ["25809831", "FFS", 0.01, 196], ["25809833", "FFS", 0.01, 312], ["25809852", "FS", 1.0, 1], ["25809854", "FS", 1.0, 1]], "25809836": [["25809830", "FFS", 0.01, 104], ["25809831", "FFS", 0.01, 247], ["25809833", "FFS", 0.01, 1235], ["25813507", "FFS", 0.01, 205]], "25809832": [["25809830", "FS", 1.0, 2], ["25809831", "FFS", 0.01, 2], ["25809833", "FFS", 0.01, 3], ["25809836", "FFS", 0.01, 3], ["25809839", "SS", 0.45, 4], ["25809842", "FFS", 0.5, 29], ["25809843", "SS", 0.08, 13]], "25809837": [["25809831", "FS", 1.0, 2], ["25809836", "SS", 0.75, 2], ["25809835", "FS", 1.0, 2], ["25809847", "FS", 1.0, 1]], "25809838": [["25809830", "FS", 1.0, 1], ["25809831", "FFS", 0.13, 92], ["25809833", "FFS", 0.01, 376], ["25813507", "FFS", 0.01, 89], ["25809836", "FFS", 0.01, 447]], "25809839": [["25809830", "FFS", 0.52, 21], ["25809831", "FFS", 0.01, 60], ["25809833", "FFS", 0.01, 381], ["25813507", "FFS", 0.33, 27], ["25809836", "FFS", 0.01, 444], ["25809838", "FFS", 0.01, 329], ["25809835", "FS", 1.0, 2], ["25809847", "FFS", 0.02, 65], ["25809850", "FS", 1.0, 1], ["25809852", "FFS", 0.05, 282], ["25809848", "FFS", 0.27, 9], ["25809853", "FS", 1.0, 1], ["25809854", "FFS", 0.05, 282], ["25809855", "FS", 1.0, 5]], "25809834": [["25809831", "FFS", 0.01, 17], ["25809833", "FS", 1.0, 10], ["25809836", "FS", 1.0, 11], ["25809838", "FFS", 0.5, 9], ["25809839", "FS", 1.0, 5], ["25809835", "FS", 1.0, 5], ["25809841", "FFS", 0.86, 12], ["25809847", "FS", 1.0, 7], ["25809848", "FS", 1.0, 3]], "25809835": [["25809831", "FFS", 0.01, 21], ["25809833", "SS", 0.25, 5], ["25809836", "SS", 0.19, 2], ["25809838", "SS", 0.5, 5], ["25809841", "SS", 0.76, 1], ["25809847", "FS", 1.0, 1], ["25809852", "FS", 1.0, 6], ["25809854", "FS", 1.0, 6]], "25809842": [["25809830", "FFS", 0.01, 6], ["25809831", "FFS", 0.01, 5], ["25809833", "FFS", 0.01, 8], ["25809836", "FFS", 0.01, 9], ["25809839", "FFS", 0.01, 2], ["25809840", "SS", 0.79, 1], ["25809841", "FS", 1.0, 11]], "25809843": [["25809842", "FFS", 0.06, 1]], "25809844": [["25809832", "FFS", 0.01, 4], ["25809843", "SS", 0.03, 4], ["25809841", "FS", 1.0, 1]], "25809840": [["25809830", "FS", 1.0, 2], ["25809831", "FFS", 0.01, 37], ["25809833", "FFS", 0.01, 43], ["25809836", "FFS", 0.17, 45], ["25809838", "FS", 1.0, 8], ["25809839", "FS", 1.0, 13], ["25809834", "FFS", 0.01, 22], ["25809835", "FFS", 0.01, 24], ["25809841", "FS", 1.0, 18], ["25809847", "FS", 1.0, 2], ["25809850", "FFS", 0.12, 1], ["25809848", "FS", 1.0, 7], ["25809853", "FFS", 0.12, 1], ["25809855", "SS", 0.09, 1]], "25809841": [["25809830", "FFS", 0.01, 180], ["25809831", "FFS", 0.01, 49], ["25809833", "FFS", 0.01, 368], ["25813507", "FFS", 0.01, 77], ["25809836", "FFS", 0.01, 322], ["25809832", "SS", 0.32, 7], ["25809838", "FFS", 0.01, 87], ["25809839", "FFS", 0.01, 177], ["25809847", "FFS", 0.2, 80], ["25809850", "FS", 1.0, 2], ["25809852", "FFS", 0.2, 12], ["25809848", "FS", 1.0, 17], ["25809853", "FS", 1.0, 2], ["25809854", "FFS", 0.2, 12]], "25809399": [], "25809400": [], "25809847": [["25809830", "FS", 1.0, 3], ["25809831", "FFS", 0.01, 187], ["25809833", "FFS", 0.01, 347], ["25813507", "FFS", 0.01, 67], ["25809836", "FFS", 0.01, 338], ["25809832", "FS", 1.0, 1], ["25809838", "FFS", 0.01, 50], ["25809850", "FS", 1.0, 6], ["25809852", "FFS", 0.05, 339], ["25809853", "FS", 1.0, 6], ["25809854", "FFS", 0.05, 339]], "25809850": [["25809833", "FS", 1.0, 3], ["25809836", "FFS", 0.67, 6], ["25809838", "FFS", 0.03, 43]], "25809852": [["25809830", "FS", 1.0, 1], ["25809831", "FFS", 0.01, 7], ["25809833", "FFS", 0.01, 26], ["25809836", "FFS", 0.46, 24], ["25809838", "FFS", 0.5, 14], ["25809834", "FFS", 0.01, 3], ["25809842", "FFS", 0.01, 2], ["25809840", "SS", 0.01, 2], ["25809850", "FFS", 0.01, 306], ["25809856", "FS", 1.0, 5]], "25809848": [["25809830", "FS", 1.0, 1], ["25809833", "FFS", 0.01, 85], ["25809836", "FFS", 0.01, 133], ["25809838", "FFS", 0.01, 53], ["25809847", "FFS", 0.07, 9], ["25809850", "FFS", 0.01, 68], ["25809852", "FFS", 0.01, 53], ["25809853", "FFS", 0.03, 68], ["25809856", "FS", 1.0, 1]], "25809853": [["25809833", "FS", 1.0, 3], ["25809836", "FFS", 0.67, 6], ["25809838", "FFS", 0.03, 43], ["25809852", "FFS", 0.01, 306]], "25809854": [["25809830", "FS", 1.0, 1], ["25809831", "FFS", 0.01, 7], ["25809833", "FFS", 0.01, 26], ["25809836", "FFS", 0.46, 24], ["25809838", "FFS", 0.5, 14], ["25809834", "FFS", 0.01, 3], ["25809842", "FFS", 0.01, 2], ["25809840", "SS", 0.01, 2], ["25809850", "FFS", 0.01, 306], ["25809848", "FFS", 0.01, 53], ["25809853", "FFS", 0.01, 306], ["25809856", "FS", 1.0, 5]], "25809856": [["25809830", "FS", 1.0, 2], ["25809831", "FFS", 0.01, 38], ["25809833", "FFS", 0.01, 40], ["25813507", "FS", 1.0, 21], ["25809836", "FFS", 0.01, 42], ["25809839", "FFS", 0.01, 21], ["25809834", "FS", 1.0, 2], ["25809840", "FS", 1.0, 1], ["25809841", "FS", 1.0, 10], ["25809847", "FS", 1.0, 41]], "25809401": [], "25809402": [], "25809857": [["25809847", "FS", 1.0, 1], ["25809852", "FS", 1.0, 1], ["25809854", "FS", 1.0, 1], ["25809855", "FS", 1.0, 1]], "25809858": [["25809836", "FS", 1.0, 1], ["25809838", "FS", 1.0, 1], ["25809839", "FFS", 0.01, 56], ["25809841", "SS", 0.36, 4], ["25809847", "FS", 1.0, 4], ["25809850", "FFS", 0.93, 91], ["25809852", "FFS", 0.01, 378], ["25809848", "FFS", 0.01, 17], ["25809853", "FFS", 0.93, 91], ["25809854", "FFS", 0.01, 378], ["25809855", "FFS", 0.96, 97]], "25809855": [["25809833", "FS", 1.0, 1], ["25809838", "FFS", 0.89, 4], ["25809841", "SS", 0.03, 2], ["25809847", "FFS", 0.56, 20], ["25809850", "FFS", 0.01, 190], ["25809852", "FFS", 0.01, 291], ["25809848", "FFS", 0.85, 11], ["25809853", "FFS", 0.01, 190], ["25809854", "FFS", 0.01, 291]], "25809403": []}
    electroline = {"223084": [["223094", "FS", 1.0, 1]], "223085": [["223084", "FFS", 0.01, 1602]], "223086": [["223084", "FFS", 0.01, 900], ["223085", "FFS", 0.01, 1235]], "223087": [["223084", "FFS", 0.01, 173], ["223085", "FFS", 0.01, 347], ["223086", "FFS", 0.01, 338]], "223088": [["223084", "FFS", 0.09, 18], ["223085", "FFS", 0.08, 32], ["223086", "FFS", 0.01, 38], ["223087", "FFS", 0.01, 52], ["223089", "FFS", 0.08, 52]], "223089": [["223084", "FFS", 0.01, 173], ["223085", "FFS", 0.01, 347], ["223086", "FFS", 0.01, 338]], "223092": [["223084", "FS", 1.0, 5], ["223085", "FFS", 0.5, 6], ["223086", "FFS", 0.36, 6], ["223087", "FFS", 0.36, 7], ["223089", "FFS", 0.36, 7]], "223093": [["223084", "FS", 1.0, 1], ["223085", "FS", 1.0, 1], ["223086", "FS", 1.0, 1], ["223087", "FS", 1.0, 2], ["223089", "FS", 1.0, 2], ["223092", "SS", 0.04, 62]], "223094": [["223085", "FS", 1.0, 25], ["223086", "FFS", 0.47, 28], ["223087", "FFS", 0.69, 39], ["223088", "FFS", 0.75, 8], ["223089", "FFS", 0.69, 39], ["223092", "FFS", 0.01, 14], ["223093", "FFS", 0.07, 9]], "223095": [["223084", "FFS", 0.01, 11], ["223085", "FFS", 0.01, 40], ["223086", "FFS", 0.01, 42], ["223087", "FS", 1.0, 41], ["223088", "FFS", 0.75, 10], ["223089", "FS", 1.0, 41], ["223092", "FFS", 0.01, 58], ["223093", "FFS", 0.01, 39], ["223094", "FFS", 0.01, 58]]}
    dormitory = {"100000": [], "100135": [], "100001": [["100033", "FS", 1.0, 1], ["100158", "FS", 1.0, 1], ["100160", "FS", 1.0, 1], ["100168", "FS", 1.0, 1], ["100169", "FS", 1.0, 1], ["100175", "FS", 1.0, 1], ["100176", "FS", 1.0, 1], ["100178", "FS", 1.0, 1], ["100181", "FS", 1.0, 1], ["100184", "FS", 1.0, 1], ["1000560", "FS", 1.0, 1]], "100002": [["100001", "FFS", 0.01, 263]], "100003": [["100001", "FFS", 0.01, 1235], ["100002", "FFS", 0.01, 104], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1]], "100004": [["100001", "FFS", 0.01, 42], ["100002", "FS", 1.0, 23], ["100003", "FFS", 0.01, 39], ["100012", "SS", 0.28, 3], ["100014", "SS", 0.28, 3], ["100050", "FFS", 0.29, 14], ["100073", "FFS", 0.29, 14], ["1000350", "FFS", 0.29, 14], ["100104", "FFS", 0.29, 14]], "100005": [["100001", "FFS", 0.01, 368], ["100002", "FFS", 0.01, 180], ["100003", "FFS", 0.01, 322], ["100004", "FFS", 0.01, 53], ["100010", "FFS", 0.2, 134], ["100012", "FFS", 0.71, 1], ["100013", "FFS", 0.55, 3], ["100014", "FFS", 0.71, 1], ["100015", "FFS", 0.55, 3], ["100018", "FS", 1.0, 3], ["100019", "FFS", 0.2, 58], ["100020", "FS", 1.0, 3], ["100021", "FS", 1.0, 3], ["100023", "FFS", 0.95, 2], ["100024", "FFS", 0.95, 2], ["100025", "FFS", 0.95, 2], ["100034", "FS", 1.0, 1], ["100039", "FS", 1.0, 8], ["100042", "FS", 1.0, 8], ["100044", "FS", 1.0, 8], ["100045", "FS", 1.0, 8], ["100046", "FS", 1.0, 8], ["100047", "FS", 1.0, 8], ["100049", "FFS", 0.2, 12], ["100050", "FFS", 0.2, 80], ["100054", "FFS", 0.2, 12], ["100055", "FFS", 0.2, 12], ["100056", "FFS", 0.2, 12], ["100057", "FFS", 0.2, 12], ["100065", "FFS", 0.2, 12], ["100066", "FFS", 0.2, 12], ["100067", "FFS", 0.2, 12], ["100068", "FFS", 0.2, 12], ["100069", "FFS", 0.2, 12], ["100072", "FS", 1.0, 16], ["100073", "FFS", 0.2, 80], ["1000340", "FS", 1.0, 3], ["100077", "FS", 1.0, 3], ["100078", "FS", 1.0, 3], ["100079", "FS", 1.0, 3], ["100081", "FS", 1.0, 16], ["100082", "FS", 1.0, 16], ["1000360", "FS", 1.0, 16], ["100085", "FS", 1.0, 16], ["100087", "FS", 1.0, 16], ["100088", "FS", 1.0, 16], ["100090", "FS", 1.0, 16], ["100091", "FS", 1.0, 5], ["100093", "FS", 1.0, 16], ["100094", "FS", 1.0, 3], ["100096", "FFS", 0.2, 12], ["100097", "FFS", 0.2, 12], ["100098", "FFS", 0.2, 12], ["100099", "FS", 1.0, 16], ["1000350", "FFS", 0.2, 80], ["100101", "FS", 1.0, 16], ["100102", "FS", 1.0, 16], ["100104", "FFS", 0.2, 80], ["100106", "FS", 1.0, 5], ["100107", "FS", 1.0, 16], ["100124", "FS", 1.0, 5], ["1000460", "FS", 1.0, 2], ["100126", "FS", 1.0, 2], ["100127", "FFS", 0.12, 177], ["100128", "FS", 1.0, 5], ["100129", "FS", 1.0, 5], ["100130", "FS", 1.0, 2], ["1000530", "FS", 1.0, 5], ["100132", "FS", 1.0, 5], ["100133", "FS", 1.0, 5], ["100134", "FS", 1.0, 5], ["100145", "FS", 1.0, 16], ["100149", "FS", 1.0, 2], ["100151", "FS", 1.0, 1], ["1000540", "FS", 1.0, 16], ["100162", "FFS", 0.55, 3], ["100163", "FFS", 0.55, 3], ["100164", "FS", 1.0, 16], ["100165", "FS", 1.0, 1], ["100166", "FS", 1.0, 16], ["100167", "FS", 1.0, 16], ["10003300", "FS", 1.0, 16], ["100173", "FS", 1.0, 16], ["100174", "FS", 1.0, 16], ["10003320", "FS", 1.0, 16], ["100182", "FS", 1.0, 16], ["100183", "FS", 1.0, 16], ["10003340", "FS", 1.0, 16]], "100006": [["100001", "FFS", 0.01, 368], ["100002", "FFS", 0.01, 180], ["100003", "FFS", 0.01, 322], ["100004", "FFS", 0.01, 53], ["100010", "FFS", 0.2, 134], ["100012", "FFS", 0.71, 1], ["100013", "FFS", 0.55, 3], ["100014", "FFS", 0.71, 1], ["100015", "FFS", 0.55, 3], ["100018", "FS", 1.0, 3], ["100019", "FFS", 0.2, 58], ["100020", "FS", 1.0, 3], ["100021", "FS", 1.0, 3], ["100023", "FFS", 0.95, 2], ["100024", "FFS", 0.95, 2], ["100025", "FFS", 0.95, 2], ["100034", "FS", 1.0, 1], ["100039", "FS", 1.0, 8], ["100042", "FS", 1.0, 8], ["100044", "FS", 1.0, 8], ["100045", "FS", 1.0, 8], ["100046", "FS", 1.0, 8], ["100047", "FS", 1.0, 8], ["100049", "FFS", 0.2, 12], ["100050", "FFS", 0.2, 80], ["100054", "FFS", 0.2, 12], ["100055", "FFS", 0.2, 12], ["100056", "FFS", 0.2, 12], ["100057", "FFS", 0.2, 12], ["100065", "FFS", 0.2, 12], ["100066", "FFS", 0.2, 12], ["100067", "FFS", 0.2, 12], ["100068", "FFS", 0.2, 12], ["100069", "FFS", 0.2, 12], ["100072", "FS", 1.0, 16], ["100073", "FFS", 0.2, 80], ["1000340", "FS", 1.0, 3], ["100077", "FS", 1.0, 3], ["100078", "FS", 1.0, 3], ["100079", "FS", 1.0, 3], ["100081", "FS", 1.0, 16], ["100082", "FS", 1.0, 16], ["1000360", "FS", 1.0, 16], ["100085", "FS", 1.0, 16], ["100087", "FS", 1.0, 16], ["100088", "FS", 1.0, 16], ["100090", "FS", 1.0, 16], ["100091", "FS", 1.0, 5], ["100093", "FS", 1.0, 16], ["100094", "FS", 1.0, 3], ["100096", "FFS", 0.2, 12], ["100097", "FFS", 0.2, 12], ["100098", "FFS", 0.2, 12], ["100099", "FS", 1.0, 16], ["1000350", "FFS", 0.2, 80], ["100101", "FS", 1.0, 16], ["100102", "FS", 1.0, 16], ["100104", "FFS", 0.2, 80], ["100106", "FS", 1.0, 5], ["100107", "FS", 1.0, 16], ["100124", "FS", 1.0, 5], ["1000460", "FS", 1.0, 2], ["100126", "FS", 1.0, 2], ["100127", "FFS", 0.12, 177], ["100128", "FS", 1.0, 5], ["100129", "FS", 1.0, 5], ["100130", "FS", 1.0, 2], ["1000530", "FS", 1.0, 5], ["100132", "FS", 1.0, 5], ["100133", "FS", 1.0, 5], ["100134", "FS", 1.0, 5], ["100145", "FS", 1.0, 16], ["100149", "FS", 1.0, 2], ["100151", "FS", 1.0, 1], ["1000540", "FS", 1.0, 16], ["100162", "FFS", 0.55, 3], ["100163", "FFS", 0.55, 3], ["100164", "FS", 1.0, 16], ["100165", "FS", 1.0, 1], ["100166", "FS", 1.0, 16], ["100167", "FS", 1.0, 16], ["10003300", "FS", 1.0, 16], ["100173", "FS", 1.0, 16], ["100174", "FS", 1.0, 16], ["10003320", "FS", 1.0, 16], ["100182", "FS", 1.0, 16], ["100183", "FS", 1.0, 16], ["10003340", "FS", 1.0, 16]], "100007": [], "100008": [], "100009": [], "100010": [["100001", "FFS", 0.01, 161], ["100002", "FS", 1.0, 1], ["100003", "FFS", 0.01, 211], ["100004", "FS", 1.0, 6], ["100009", "FFS", 0.83, 1], ["100012", "FFS", 0.21, 11], ["100013", "FFS", 0.2, 6], ["100014", "FFS", 0.21, 11], ["100015", "FFS", 0.2, 6], ["100019", "FFS", 0.38, 27], ["100023", "FFS", 0.62, 3], ["100024", "FFS", 0.62, 3], ["100025", "FFS", 0.62, 3], ["100028", "FFS", 0.4, 24], ["100050", "FFS", 0.14, 54], ["100073", "FFS", 0.14, 54], ["1000350", "FFS", 0.14, 54], ["100104", "FFS", 0.14, 54], ["100105", "FFS", 0.4, 24], ["1000460", "FS", 1.0, 2], ["100126", "FS", 1.0, 2], ["100127", "FFS", 0.09, 126], ["100130", "FS", 1.0, 2], ["100144", "FFS", 0.4, 24], ["100149", "FS", 1.0, 2], ["100162", "FFS", 0.2, 6], ["100163", "FFS", 0.2, 6]], "100011": [], "100012": [["100001", "FS", 1.0, 13], ["100003", "FS", 1.0, 14], ["100019", "FFS", 0.02, 19], ["100050", "FFS", 0.22, 20], ["100073", "FFS", 0.22, 20], ["1000350", "FFS", 0.22, 20], ["100104", "FFS", 0.22, 20]], "100013": [["100001", "FS", 1.0, 2], ["100003", "FS", 1.0, 2], ["100012", "FFS", 0.11, 5], ["100014", "FFS", 0.11, 5], ["100035", "FFS", 0.35, 8], ["100036", "FFS", 0.35, 8], ["100071", "FS", 1.0, 1], ["100089", "FS", 1.0, 1], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100139", "FS", 1.0, 1], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100159", "FS", 1.0, 2]], "100014": [["100001", "FS", 1.0, 13], ["100003", "FS", 1.0, 14], ["100019", "FFS", 0.02, 19], ["100050", "FFS", 0.22, 20], ["100073", "FFS", 0.22, 20], ["1000350", "FFS", 0.22, 20], ["100104", "FFS", 0.22, 20]], "100015": [["100001", "FS", 1.0, 2], ["100003", "FS", 1.0, 2], ["100012", "FFS", 0.11, 5], ["100014", "FFS", 0.11, 5], ["100035", "FFS", 0.35, 8], ["100036", "FFS", 0.35, 8], ["100071", "FS", 1.0, 1], ["100089", "FS", 1.0, 1], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100139", "FS", 1.0, 1], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100159", "FS", 1.0, 2]], "1000100": [], "100017": [["100005", "FS", 1.0, 1], ["100006", "FS", 1.0, 1], ["100012", "FS", 1.0, 1], ["100013", "FS", 1.0, 1], ["100014", "FS", 1.0, 1], ["100015", "FS", 1.0, 1], ["100018", "SS", 0.1, 2], ["100019", "FS", 1.0, 1], ["100020", "SS", 0.1, 2], ["100021", "SS", 0.1, 2], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100034", "FS", 1.0, 1], ["100035", "FS", 1.0, 1], ["100036", "FS", 1.0, 1], ["100039", "FS", 1.0, 1], ["100040", "FS", 1.0, 1], ["100041", "FS", 1.0, 1], ["100042", "FS", 1.0, 1], ["1000320", "FS", 1.0, 1], ["100044", "FS", 1.0, 1], ["100045", "FS", 1.0, 1], ["100046", "FS", 1.0, 1], ["100047", "FS", 1.0, 1], ["1000340", "SS", 0.1, 2], ["100077", "SS", 0.1, 2], ["100078", "SS", 0.1, 2], ["100079", "SS", 0.1, 2], ["100094", "SS", 0.1, 2], ["100162", "FS", 1.0, 1], ["100163", "FS", 1.0, 1], ["100172", "FS", 1.0, 1], ["10003310", "FS", 1.0, 1], ["10003330", "FS", 1.0, 1]], "100018": [["100010", "FS", 1.0, 1], ["100012", "FS", 1.0, 3], ["100013", "FFS", 0.5, 5], ["100014", "FS", 1.0, 3], ["100015", "FFS", 0.5, 5], ["100022", "FS", 1.0, 1], ["100027", "FS", 1.0, 4], ["100028", "FS", 1.0, 10], ["100033", "FS", 1.0, 2], ["100034", "FS", 1.0, 2], ["100035", "FFS", 0.82, 5], ["100036", "FFS", 0.82, 5], ["100039", "FS", 1.0, 4], ["100040", "FS", 1.0, 2], ["100041", "FS", 1.0, 2], ["100042", "FS", 1.0, 4], ["1000320", "FS", 1.0, 2], ["100044", "FS", 1.0, 4], ["100045", "FS", 1.0, 4], ["100046", "FS", 1.0, 4], ["100047", "FS", 1.0, 4], ["100050", "FS", 1.0, 8], ["100073", "FS", 1.0, 8], ["1000350", "FS", 1.0, 8], ["100104", "FS", 1.0, 8], ["100105", "FS", 1.0, 10], ["100127", "FFS", 0.1, 7], ["100144", "FS", 1.0, 10], ["100158", "FS", 1.0, 2], ["100160", "FS", 1.0, 2], ["100162", "FFS", 0.5, 5], ["100163", "FFS", 0.5, 5], ["100168", "FS", 1.0, 2], ["100169", "FS", 1.0, 2], ["100175", "FS", 1.0, 2], ["100176", "FS", 1.0, 2], ["100178", "FS", 1.0, 2], ["100181", "FS", 1.0, 2], ["100184", "FS", 1.0, 2], ["1000560", "FS", 1.0, 2]], "100019": [["100001", "FFS", 0.33, 35], ["100002", "FS", 1.0, 5], ["100003", "FFS", 0.01, 41], ["100004", "FFS", 0.36, 9], ["100013", "SS", 0.5, 1], ["100015", "SS", 0.5, 1], ["100018", "FS", 1.0, 5], ["100020", "FS", 1.0, 5], ["100021", "FS", 1.0, 5], ["100022", "FS", 1.0, 1], ["100028", "FS", 1.0, 7], ["100034", "FS", 1.0, 2], ["100040", "FS", 1.0, 2], ["100041", "FS", 1.0, 2], ["1000320", "FS", 1.0, 2], ["100049", "FFS", 0.48, 5], ["100050", "FFS", 0.1, 44], ["100054", "FFS", 0.48, 5], ["100055", "FFS", 0.48, 5], ["100056", "FFS", 0.48, 5], ["100057", "FFS", 0.48, 5], ["100065", "FFS", 0.48, 5], ["100066", "FFS", 0.48, 5], ["100067", "FFS", 0.48, 5], ["100068", "FFS", 0.48, 5], ["100069", "FFS", 0.48, 5], ["100073", "FFS", 0.1, 44], ["1000340", "FS", 1.0, 5], ["100077", "FS", 1.0, 5], ["100078", "FS", 1.0, 5], ["100079", "FS", 1.0, 5], ["100094", "FS", 1.0, 5], ["100096", "FFS", 0.48, 5], ["100097", "FFS", 0.48, 5], ["100098", "FFS", 0.48, 5], ["1000350", "FFS", 0.1, 44], ["100104", "FFS", 0.1, 44], ["100105", "FS", 1.0, 7], ["100144", "FS", 1.0, 7], ["100162", "SS", 0.5, 1], ["100163", "SS", 0.5, 1]], "100020": [["100010", "FS", 1.0, 1], ["100012", "FS", 1.0, 3], ["100013", "FFS", 0.5, 5], ["100014", "FS", 1.0, 3], ["100015", "FFS", 0.5, 5], ["100022", "FS", 1.0, 1], ["100027", "FS", 1.0, 4], ["100028", "FS", 1.0, 10], ["100033", "FS", 1.0, 2], ["100034", "FS", 1.0, 2], ["100035", "FFS", 0.82, 5], ["100036", "FFS", 0.82, 5], ["100039", "FS", 1.0, 4], ["100040", "FS", 1.0, 2], ["100041", "FS", 1.0, 2], ["100042", "FS", 1.0, 4], ["1000320", "FS", 1.0, 2], ["100044", "FS", 1.0, 4], ["100045", "FS", 1.0, 4], ["100046", "FS", 1.0, 4], ["100047", "FS", 1.0, 4], ["100050", "FS", 1.0, 8], ["100073", "FS", 1.0, 8], ["1000350", "FS", 1.0, 8], ["100104", "FS", 1.0, 8], ["100105", "FS", 1.0, 10], ["100127", "FFS", 0.1, 7], ["100144", "FS", 1.0, 10], ["100158", "FS", 1.0, 2], ["100160", "FS", 1.0, 2], ["100162", "FFS", 0.5, 5], ["100163", "FFS", 0.5, 5], ["100168", "FS", 1.0, 2], ["100169", "FS", 1.0, 2], ["100175", "FS", 1.0, 2], ["100176", "FS", 1.0, 2], ["100178", "FS", 1.0, 2], ["100181", "FS", 1.0, 2], ["100184", "FS", 1.0, 2], ["1000560", "FS", 1.0, 2]], "100021": [["100010", "FS", 1.0, 1], ["100012", "FS", 1.0, 3], ["100013", "FFS", 0.5, 5], ["100014", "FS", 1.0, 3], ["100015", "FFS", 0.5, 5], ["100022", "FS", 1.0, 1], ["100027", "FS", 1.0, 4], ["100028", "FS", 1.0, 10], ["100033", "FS", 1.0, 2], ["100034", "FS", 1.0, 2], ["100035", "FFS", 0.82, 5], ["100036", "FFS", 0.82, 5], ["100039", "FS", 1.0, 4], ["100040", "FS", 1.0, 2], ["100041", "FS", 1.0, 2], ["100042", "FS", 1.0, 4], ["1000320", "FS", 1.0, 2], ["100044", "FS", 1.0, 4], ["100045", "FS", 1.0, 4], ["100046", "FS", 1.0, 4], ["100047", "FS", 1.0, 4], ["100050", "FS", 1.0, 8], ["100073", "FS", 1.0, 8], ["1000350", "FS", 1.0, 8], ["100104", "FS", 1.0, 8], ["100105", "FS", 1.0, 10], ["100127", "FFS", 0.1, 7], ["100144", "FS", 1.0, 10], ["100158", "FS", 1.0, 2], ["100160", "FS", 1.0, 2], ["100162", "FFS", 0.5, 5], ["100163", "FFS", 0.5, 5], ["100168", "FS", 1.0, 2], ["100169", "FS", 1.0, 2], ["100175", "FS", 1.0, 2], ["100176", "FS", 1.0, 2], ["100178", "FS", 1.0, 2], ["100181", "FS", 1.0, 2], ["100184", "FS", 1.0, 2], ["1000560", "FS", 1.0, 2]], "100022": [["100013", "SS", 0.3, 1], ["100015", "SS", 0.3, 1], ["100027", "FS", 1.0, 1], ["100162", "SS", 0.3, 1], ["100163", "SS", 0.3, 1]], "100023": [["100012", "FFS", 0.5, 3], ["100013", "FS", 1.0, 4], ["100014", "FFS", 0.5, 3], ["100015", "FS", 1.0, 4], ["100018", "FS", 1.0, 2], ["100019", "FS", 1.0, 2], ["100020", "FS", 1.0, 2], ["100021", "FS", 1.0, 2], ["100022", "FS", 1.0, 1], ["100028", "FS", 1.0, 2], ["100035", "FS", 1.0, 1], ["100036", "FS", 1.0, 1], ["100071", "FS", 1.0, 1], ["100089", "FS", 1.0, 1], ["100105", "FS", 1.0, 2], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100139", "FS", 1.0, 1], ["100144", "FS", 1.0, 2], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1]], "100024": [["100012", "FFS", 0.5, 3], ["100013", "FS", 1.0, 4], ["100014", "FFS", 0.5, 3], ["100015", "FS", 1.0, 4], ["100018", "FS", 1.0, 2], ["100019", "FS", 1.0, 2], ["100020", "FS", 1.0, 2], ["100021", "FS", 1.0, 2], ["100022", "FS", 1.0, 1], ["100028", "FS", 1.0, 2], ["100035", "FS", 1.0, 1], ["100036", "FS", 1.0, 1], ["100071", "FS", 1.0, 1], ["100089", "FS", 1.0, 1], ["100105", "FS", 1.0, 2], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100139", "FS", 1.0, 1], ["100144", "FS", 1.0, 2], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1]], "100025": [["100012", "FFS", 0.5, 3], ["100013", "FS", 1.0, 4], ["100014", "FFS", 0.5, 3], ["100015", "FS", 1.0, 4], ["100018", "FS", 1.0, 2], ["100019", "FS", 1.0, 2], ["100020", "FS", 1.0, 2], ["100021", "FS", 1.0, 2], ["100022", "FS", 1.0, 1], ["100028", "FS", 1.0, 2], ["100035", "FS", 1.0, 1], ["100036", "FS", 1.0, 1], ["100071", "FS", 1.0, 1], ["100089", "FS", 1.0, 1], ["100105", "FS", 1.0, 2], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100139", "FS", 1.0, 1], ["100144", "FS", 1.0, 2], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1]], "100026": [["100012", "FS", 1.0, 1], ["100013", "FS", 1.0, 2], ["100014", "FS", 1.0, 1], ["100015", "FS", 1.0, 2], ["100017", "SS", 0.17, 1], ["100018", "SS", 0.17, 2], ["100020", "SS", 0.17, 2], ["100021", "SS", 0.17, 2], ["100023", "FS", 1.0, 2], ["100024", "FS", 1.0, 2], ["100025", "FS", 1.0, 2], ["100035", "FS", 1.0, 2], ["100036", "FS", 1.0, 2], ["100071", "FFS", 0.1, 1], ["100089", "FFS", 0.1, 1], ["100111", "FFS", 0.1, 1], ["100112", "FFS", 0.1, 1], ["1000470", "FFS", 0.1, 1], ["100115", "FFS", 0.1, 1], ["100116", "FFS", 0.1, 1], ["100117", "FFS", 0.1, 1], ["100118", "FFS", 0.1, 1], ["100119", "FFS", 0.1, 1], ["100120", "FFS", 0.1, 1], ["100121", "FFS", 0.1, 1], ["100122", "FFS", 0.1, 1], ["100123", "FFS", 0.1, 1], ["100127", "SS", 0.14, 1], ["100139", "FFS", 0.1, 1], ["100146", "FFS", 0.1, 1], ["100147", "FFS", 0.1, 1], ["100150", "FFS", 0.1, 1], ["100152", "FFS", 0.1, 1], ["100154", "FFS", 0.1, 1]], "100027": [["100001", "FS", 1.0, 1], ["100003", "FS", 1.0, 2], ["100005", "FFS", 0.56, 6], ["100006", "FFS", 0.56, 6], ["100010", "FFS", 0.21, 8], ["100012", "FFS", 0.01, 10], ["100013", "SS", 0.2, 6], ["100014", "FFS", 0.01, 10], ["100015", "SS", 0.2, 6], ["100017", "SS", 0.67, 1], ["100019", "FFS", 0.18, 9], ["100023", "FS", 1.0, 5], ["100024", "FS", 1.0, 5], ["100025", "FS", 1.0, 5], ["100026", "SS", 0.8, 4], ["100028", "FS", 1.0, 7], ["100035", "FS", 1.0, 5], ["100036", "FS", 1.0, 5], ["100049", "FS", 1.0, 2], ["100050", "FS", 1.0, 1], ["100054", "FS", 1.0, 2], ["100055", "FS", 1.0, 2], ["100056", "FS", 1.0, 2], ["100057", "FS", 1.0, 2], ["100065", "FS", 1.0, 2], ["100066", "FS", 1.0, 2], ["100067", "FS", 1.0, 2], ["100068", "FS", 1.0, 2], ["100069", "FS", 1.0, 2], ["100071", "FS", 1.0, 6], ["100072", "FS", 1.0, 10], ["100073", "FS", 1.0, 1], ["100081", "FS", 1.0, 10], ["100082", "FS", 1.0, 10], ["1000360", "FS", 1.0, 10], ["100085", "FS", 1.0, 10], ["100087", "FS", 1.0, 10], ["100088", "FS", 1.0, 10], ["100089", "FS", 1.0, 6], ["100090", "FS", 1.0, 10], ["100093", "FS", 1.0, 10], ["100096", "FS", 1.0, 2], ["100097", "FS", 1.0, 2], ["100098", "FS", 1.0, 2], ["100099", "FS", 1.0, 10], ["1000350", "FS", 1.0, 1], ["100101", "FS", 1.0, 10], ["100102", "FS", 1.0, 10], ["100104", "FS", 1.0, 1], ["100105", "FS", 1.0, 7], ["100107", "FS", 1.0, 10], ["100111", "FS", 1.0, 6], ["100112", "FS", 1.0, 6], ["1000470", "FS", 1.0, 6], ["100115", "FS", 1.0, 6], ["100116", "FS", 1.0, 6], ["100117", "FS", 1.0, 6], ["100118", "FS", 1.0, 6], ["100119", "FS", 1.0, 6], ["100120", "FS", 1.0, 6], ["100121", "FS", 1.0, 6], ["100122", "FS", 1.0, 6], ["100123", "FS", 1.0, 6], ["100127", "FFS", 0.18, 10], ["100139", "FS", 1.0, 6], ["100144", "FS", 1.0, 7], ["100145", "FS", 1.0, 10], ["100146", "FS", 1.0, 6], ["100147", "FS", 1.0, 6], ["100150", "FS", 1.0, 6], ["100152", "FS", 1.0, 6], ["100154", "FS", 1.0, 6], ["1000540", "FS", 1.0, 10], ["100162", "SS", 0.2, 6], ["100163", "SS", 0.2, 6], ["100164", "FS", 1.0, 10], ["100166", "FS", 1.0, 10], ["100167", "FS", 1.0, 10], ["10003300", "FS", 1.0, 10], ["100172", "FFS", 0.56, 6], ["100173", "FS", 1.0, 10], ["100174", "FS", 1.0, 10], ["10003320", "FS", 1.0, 10], ["10003310", "FFS", 0.56, 6], ["100182", "FS", 1.0, 10], ["100183", "FS", 1.0, 10], ["10003330", "FFS", 0.56, 6], ["10003340", "FS", 1.0, 10]], "100028": [["100001", "FFS", 0.01, 32], ["100002", "FS", 1.0, 5], ["100003", "FFS", 0.01, 34], ["100005", "FS", 1.0, 14], ["100006", "FS", 1.0, 14], ["100012", "FS", 1.0, 4], ["100013", "SS", 0.81, 4], ["100014", "FS", 1.0, 4], ["100015", "SS", 0.81, 4], ["100026", "FFS", 0.62, 3], ["100029", "FFS", 0.62, 3], ["100030", "FFS", 0.62, 3], ["100033", "FFS", 0.33, 2], ["100035", "FFS", 0.09, 14], ["100036", "FFS", 0.09, 14], ["100050", "FFS", 0.2, 28], ["100073", "FFS", 0.2, 28], ["1000350", "FFS", 0.2, 28], ["100104", "FFS", 0.2, 28], ["100141", "FS", 1.0, 1], ["100142", "SS", 0.66, 2], ["100143", "FFS", 0.57, 8], ["100155", "FFS", 0.57, 8], ["100158", "FFS", 0.33, 2], ["100160", "FFS", 0.33, 2], ["100168", "FFS", 0.33, 2], ["100169", "FFS", 0.33, 2], ["100175", "FFS", 0.33, 2], ["100176", "FFS", 0.33, 2], ["100178", "FFS", 0.33, 2], ["100181", "FFS", 0.33, 2], ["100184", "FFS", 0.33, 2], ["1000560", "FFS", 0.33, 2], ["100189", "SS", 0.66, 2]], "100029": [["100012", "FS", 1.0, 1], ["100013", "FS", 1.0, 2], ["100014", "FS", 1.0, 1], ["100015", "FS", 1.0, 2], ["100017", "SS", 0.17, 1], ["100018", "SS", 0.17, 2], ["100020", "SS", 0.17, 2], ["100021", "SS", 0.17, 2], ["100023", "FS", 1.0, 2], ["100024", "FS", 1.0, 2], ["100025", "FS", 1.0, 2], ["100027", "FS", 1.0, 4], ["100035", "FS", 1.0, 2], ["100036", "FS", 1.0, 2], ["100071", "FFS", 0.1, 1], ["100089", "FFS", 0.1, 1], ["100111", "FFS", 0.1, 1], ["100112", "FFS", 0.1, 1], ["1000470", "FFS", 0.1, 1], ["100115", "FFS", 0.1, 1], ["100116", "FFS", 0.1, 1], ["100117", "FFS", 0.1, 1], ["100118", "FFS", 0.1, 1], ["100119", "FFS", 0.1, 1], ["100120", "FFS", 0.1, 1], ["100121", "FFS", 0.1, 1], ["100122", "FFS", 0.1, 1], ["100123", "FFS", 0.1, 1], ["100127", "SS", 0.14, 1], ["100139", "FFS", 0.1, 1], ["100146", "FFS", 0.1, 1], ["100147", "FFS", 0.1, 1], ["100150", "FFS", 0.1, 1], ["100152", "FFS", 0.1, 1], ["100154", "FFS", 0.1, 1]], "100030": [["100012", "FS", 1.0, 1], ["100013", "FS", 1.0, 2], ["100014", "FS", 1.0, 1], ["100015", "FS", 1.0, 2], ["100017", "SS", 0.17, 1], ["100018", "SS", 0.17, 2], ["100020", "SS", 0.17, 2], ["100021", "SS", 0.17, 2], ["100023", "FS", 1.0, 2], ["100024", "FS", 1.0, 2], ["100025", "FS", 1.0, 2], ["100027", "FS", 1.0, 4], ["100035", "FS", 1.0, 2], ["100036", "FS", 1.0, 2], ["100071", "FFS", 0.1, 1], ["100089", "FFS", 0.1, 1], ["100111", "FFS", 0.1, 1], ["100112", "FFS", 0.1, 1], ["1000470", "FFS", 0.1, 1], ["100115", "FFS", 0.1, 1], ["100116", "FFS", 0.1, 1], ["100117", "FFS", 0.1, 1], ["100118", "FFS", 0.1, 1], ["100119", "FFS", 0.1, 1], ["100120", "FFS", 0.1, 1], ["100121", "FFS", 0.1, 1], ["100122", "FFS", 0.1, 1], ["100123", "FFS", 0.1, 1], ["100127", "SS", 0.14, 1], ["100139", "FFS", 0.1, 1], ["100146", "FFS", 0.1, 1], ["100147", "FFS", 0.1, 1], ["100150", "FFS", 0.1, 1], ["100152", "FFS", 0.1, 1], ["100154", "FFS", 0.1, 1]], "100031": [], "100032": [["100005", "FFS", 0.1, 1], ["100006", "FFS", 0.1, 1], ["100010", "FFS", 0.73, 1], ["100012", "FFS", 0.79, 1], ["100013", "FFS", 0.6, 1], ["100014", "FFS", 0.79, 1], ["100015", "FFS", 0.6, 1], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100027", "FFS", 0.01, 2], ["100162", "FFS", 0.6, 1], ["100163", "FFS", 0.6, 1], ["100172", "FFS", 0.1, 1], ["10003310", "FFS", 0.1, 1], ["10003330", "FFS", 0.1, 1]], "100033": [["100004", "FS", 1.0, 1], ["100005", "FFS", 0.01, 17], ["100006", "FFS", 0.01, 17], ["100010", "FFS", 1.0, 6], ["100012", "FS", 1.0, 4], ["100013", "FFS", 0.01, 33], ["100014", "FS", 1.0, 4], ["100015", "FFS", 0.01, 33], ["100019", "FS", 1.0, 1], ["100022", "FFS", 0.65, 1], ["100023", "FFS", 0.67, 2], ["100024", "FFS", 0.67, 2], ["100025", "FFS", 0.67, 2], ["100026", "FS", 1.0, 1], ["100027", "FS", 1.0, 4], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100032", "FFS", 0.25, 2], ["100071", "FS", 1.0, 1], ["100089", "FS", 1.0, 1], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100127", "FS", 1.0, 4], ["100139", "FS", 1.0, 1], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100172", "FFS", 0.5, 17], ["10003310", "FFS", 0.5, 17], ["10003330", "FFS", 0.5, 17]], "100034": [["100032", "FS", 1.0, 1], ["100033", "FS", 1.0, 1], ["100039", "FS", 1.0, 2], ["100040", "SS", 0.86, 2], ["100041", "SS", 0.86, 2], ["100042", "FS", 1.0, 2], ["1000320", "SS", 0.86, 2], ["100044", "FS", 1.0, 2], ["100045", "FS", 1.0, 2], ["100046", "FS", 1.0, 2], ["100047", "FS", 1.0, 2], ["100158", "FS", 1.0, 1], ["100160", "FS", 1.0, 1], ["100168", "FS", 1.0, 1], ["100169", "FS", 1.0, 1], ["100175", "FS", 1.0, 1], ["100176", "FS", 1.0, 1], ["100178", "FS", 1.0, 1], ["100181", "FS", 1.0, 1], ["100184", "FS", 1.0, 1], ["1000560", "FS", 1.0, 1]], "100035": [["100001", "FS", 1.0, 1], ["100003", "FFS", 0.64, 2], ["100005", "SS", 0.04, 5], ["100006", "SS", 0.04, 5], ["100010", "SS", 0.8, 2], ["100012", "FFS", 0.17, 6], ["100014", "FFS", 0.17, 6], ["100019", "FFS", 0.58, 8], ["100033", "SS", 0.04, 9], ["100034", "FS", 1.0, 4], ["100049", "FS", 1.0, 2], ["100051", "FS", 1.0, 1], ["100052", "FS", 1.0, 1], ["100053", "FS", 1.0, 1], ["100054", "FS", 1.0, 2], ["100055", "FS", 1.0, 2], ["100056", "FS", 1.0, 2], ["100057", "FS", 1.0, 2], ["100065", "FS", 1.0, 2], ["100066", "FS", 1.0, 2], ["100067", "FS", 1.0, 2], ["100068", "FS", 1.0, 2], ["100069", "FS", 1.0, 2], ["100096", "FS", 1.0, 2], ["100097", "FS", 1.0, 2], ["100098", "FS", 1.0, 2], ["1000460", "FS", 1.0, 1], ["100126", "FS", 1.0, 1], ["100127", "FFS", 0.38, 12], ["100130", "FS", 1.0, 1], ["100149", "FS", 1.0, 1], ["100158", "SS", 0.04, 9], ["100160", "SS", 0.04, 9], ["100168", "SS", 0.04, 9], ["100169", "SS", 0.04, 9], ["100175", "SS", 0.04, 9], ["100176", "SS", 0.04, 9], ["100178", "SS", 0.04, 9], ["100181", "SS", 0.04, 9], ["100184", "SS", 0.04, 9], ["1000560", "SS", 0.04, 9]], "100036": [["100001", "FS", 1.0, 1], ["100003", "FFS", 0.64, 2], ["100005", "SS", 0.04, 5], ["100006", "SS", 0.04, 5], ["100010", "SS", 0.8, 2], ["100012", "FFS", 0.17, 6], ["100014", "FFS", 0.17, 6], ["100019", "FFS", 0.58, 8], ["100033", "SS", 0.04, 9], ["100034", "FS", 1.0, 4], ["100049", "FS", 1.0, 2], ["100051", "FS", 1.0, 1], ["100052", "FS", 1.0, 1], ["100053", "FS", 1.0, 1], ["100054", "FS", 1.0, 2], ["100055", "FS", 1.0, 2], ["100056", "FS", 1.0, 2], ["100057", "FS", 1.0, 2], ["100065", "FS", 1.0, 2], ["100066", "FS", 1.0, 2], ["100067", "FS", 1.0, 2], ["100068", "FS", 1.0, 2], ["100069", "FS", 1.0, 2], ["100096", "FS", 1.0, 2], ["100097", "FS", 1.0, 2], ["100098", "FS", 1.0, 2], ["1000460", "FS", 1.0, 1], ["100126", "FS", 1.0, 1], ["100127", "FFS", 0.38, 12], ["100130", "FS", 1.0, 1], ["100149", "FS", 1.0, 1], ["100158", "SS", 0.04, 9], ["100160", "SS", 0.04, 9], ["100168", "SS", 0.04, 9], ["100169", "SS", 0.04, 9], ["100175", "SS", 0.04, 9], ["100176", "SS", 0.04, 9], ["100178", "SS", 0.04, 9], ["100181", "SS", 0.04, 9], ["100184", "SS", 0.04, 9], ["1000560", "SS", 0.04, 9]], "100037": [], "100038": [["100001", "FS", 1.0, 2], ["100010", "FS", 1.0, 1], ["100019", "FS", 1.0, 1], ["100035", "FS", 1.0, 1], ["100036", "FS", 1.0, 1], ["100050", "FS", 1.0, 2], ["100073", "FS", 1.0, 2], ["1000350", "FS", 1.0, 2], ["100104", "FS", 1.0, 2]], "100039": [["100001", "FS", 1.0, 4], ["100003", "FS", 1.0, 3], ["100010", "FS", 1.0, 2], ["100013", "FFS", 0.73, 2], ["100015", "FFS", 0.73, 2], ["100019", "FFS", 0.01, 3], ["100026", "FS", 1.0, 1], ["100027", "FS", 1.0, 1], ["100028", "SS", 0.89, 3], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FS", 1.0, 2], ["100035", "FFS", 0.01, 5], ["100036", "FFS", 0.01, 5], ["100049", "FFS", 0.56, 5], ["100050", "FS", 1.0, 6], ["100054", "FFS", 0.56, 5], ["100055", "FFS", 0.56, 5], ["100056", "FFS", 0.56, 5], ["100057", "FFS", 0.56, 5], ["100065", "FFS", 0.56, 5], ["100066", "FFS", 0.56, 5], ["100067", "FFS", 0.56, 5], ["100068", "FFS", 0.56, 5], ["100069", "FFS", 0.56, 5], ["100073", "FS", 1.0, 6], ["100096", "FFS", 0.56, 5], ["100097", "FFS", 0.56, 5], ["100098", "FFS", 0.56, 5], ["1000350", "FS", 1.0, 6], ["100104", "FS", 1.0, 6], ["100105", "SS", 0.89, 3], ["100144", "SS", 0.89, 3], ["100158", "FS", 1.0, 2], ["100160", "FS", 1.0, 2], ["100162", "FFS", 0.73, 2], ["100163", "FFS", 0.73, 2], ["100168", "FS", 1.0, 2], ["100169", "FS", 1.0, 2], ["100175", "FS", 1.0, 2], ["100176", "FS", 1.0, 2], ["100178", "FS", 1.0, 2], ["100181", "FS", 1.0, 2], ["100184", "FS", 1.0, 2], ["1000560", "FS", 1.0, 2]], "100040": [["100005", "FS", 1.0, 2], ["100006", "FS", 1.0, 2], ["100027", "FS", 1.0, 1], ["100035", "FS", 1.0, 3], ["100036", "FS", 1.0, 3], ["100039", "FS", 1.0, 7], ["100042", "FS", 1.0, 7], ["100044", "FS", 1.0, 7], ["100045", "FS", 1.0, 7], ["100046", "FS", 1.0, 7], ["100047", "FS", 1.0, 7], ["100049", "FS", 1.0, 1], ["100054", "FS", 1.0, 1], ["100055", "FS", 1.0, 1], ["100056", "FS", 1.0, 1], ["100057", "FS", 1.0, 1], ["100065", "FS", 1.0, 1], ["100066", "FS", 1.0, 1], ["100067", "FS", 1.0, 1], ["100068", "FS", 1.0, 1], ["100069", "FS", 1.0, 1], ["100096", "FS", 1.0, 1], ["100097", "FS", 1.0, 1], ["100098", "FS", 1.0, 1], ["100127", "FS", 1.0, 1]], "100041": [["100005", "FS", 1.0, 2], ["100006", "FS", 1.0, 2], ["100027", "FS", 1.0, 1], ["100035", "FS", 1.0, 3], ["100036", "FS", 1.0, 3], ["100039", "FS", 1.0, 7], ["100042", "FS", 1.0, 7], ["100044", "FS", 1.0, 7], ["100045", "FS", 1.0, 7], ["100046", "FS", 1.0, 7], ["100047", "FS", 1.0, 7], ["100049", "FS", 1.0, 1], ["100054", "FS", 1.0, 1], ["100055", "FS", 1.0, 1], ["100056", "FS", 1.0, 1], ["100057", "FS", 1.0, 1], ["100065", "FS", 1.0, 1], ["100066", "FS", 1.0, 1], ["100067", "FS", 1.0, 1], ["100068", "FS", 1.0, 1], ["100069", "FS", 1.0, 1], ["100096", "FS", 1.0, 1], ["100097", "FS", 1.0, 1], ["100098", "FS", 1.0, 1], ["100127", "FS", 1.0, 1]], "100042": [["100001", "FS", 1.0, 4], ["100003", "FS", 1.0, 3], ["100010", "FS", 1.0, 2], ["100013", "FFS", 0.73, 2], ["100015", "FFS", 0.73, 2], ["100019", "FFS", 0.01, 3], ["100026", "FS", 1.0, 1], ["100027", "FS", 1.0, 1], ["100028", "SS", 0.89, 3], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FS", 1.0, 2], ["100035", "FFS", 0.01, 5], ["100036", "FFS", 0.01, 5], ["100049", "FFS", 0.56, 5], ["100050", "FS", 1.0, 6], ["100054", "FFS", 0.56, 5], ["100055", "FFS", 0.56, 5], ["100056", "FFS", 0.56, 5], ["100057", "FFS", 0.56, 5], ["100065", "FFS", 0.56, 5], ["100066", "FFS", 0.56, 5], ["100067", "FFS", 0.56, 5], ["100068", "FFS", 0.56, 5], ["100069", "FFS", 0.56, 5], ["100073", "FS", 1.0, 6], ["100096", "FFS", 0.56, 5], ["100097", "FFS", 0.56, 5], ["100098", "FFS", 0.56, 5], ["1000350", "FS", 1.0, 6], ["100104", "FS", 1.0, 6], ["100105", "SS", 0.89, 3], ["100144", "SS", 0.89, 3], ["100158", "FS", 1.0, 2], ["100160", "FS", 1.0, 2], ["100162", "FFS", 0.73, 2], ["100163", "FFS", 0.73, 2], ["100168", "FS", 1.0, 2], ["100169", "FS", 1.0, 2], ["100175", "FS", 1.0, 2], ["100176", "FS", 1.0, 2], ["100178", "FS", 1.0, 2], ["100181", "FS", 1.0, 2], ["100184", "FS", 1.0, 2], ["1000560", "FS", 1.0, 2]], "1000320": [["100005", "FS", 1.0, 2], ["100006", "FS", 1.0, 2], ["100027", "FS", 1.0, 1], ["100035", "FS", 1.0, 3], ["100036", "FS", 1.0, 3], ["100039", "FS", 1.0, 7], ["100042", "FS", 1.0, 7], ["100044", "FS", 1.0, 7], ["100045", "FS", 1.0, 7], ["100046", "FS", 1.0, 7], ["100047", "FS", 1.0, 7], ["100049", "FS", 1.0, 1], ["100054", "FS", 1.0, 1], ["100055", "FS", 1.0, 1], ["100056", "FS", 1.0, 1], ["100057", "FS", 1.0, 1], ["100065", "FS", 1.0, 1], ["100066", "FS", 1.0, 1], ["100067", "FS", 1.0, 1], ["100068", "FS", 1.0, 1], ["100069", "FS", 1.0, 1], ["100096", "FS", 1.0, 1], ["100097", "FS", 1.0, 1], ["100098", "FS", 1.0, 1], ["100127", "FS", 1.0, 1]], "100044": [["100001", "FS", 1.0, 4], ["100003", "FS", 1.0, 3], ["100010", "FS", 1.0, 2], ["100013", "FFS", 0.73, 2], ["100015", "FFS", 0.73, 2], ["100019", "FFS", 0.01, 3], ["100026", "FS", 1.0, 1], ["100027", "FS", 1.0, 1], ["100028", "SS", 0.89, 3], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FS", 1.0, 2], ["100035", "FFS", 0.01, 5], ["100036", "FFS", 0.01, 5], ["100049", "FFS", 0.56, 5], ["100050", "FS", 1.0, 6], ["100054", "FFS", 0.56, 5], ["100055", "FFS", 0.56, 5], ["100056", "FFS", 0.56, 5], ["100057", "FFS", 0.56, 5], ["100065", "FFS", 0.56, 5], ["100066", "FFS", 0.56, 5], ["100067", "FFS", 0.56, 5], ["100068", "FFS", 0.56, 5], ["100069", "FFS", 0.56, 5], ["100073", "FS", 1.0, 6], ["100096", "FFS", 0.56, 5], ["100097", "FFS", 0.56, 5], ["100098", "FFS", 0.56, 5], ["1000350", "FS", 1.0, 6], ["100104", "FS", 1.0, 6], ["100105", "SS", 0.89, 3], ["100144", "SS", 0.89, 3], ["100158", "FS", 1.0, 2], ["100160", "FS", 1.0, 2], ["100162", "FFS", 0.73, 2], ["100163", "FFS", 0.73, 2], ["100168", "FS", 1.0, 2], ["100169", "FS", 1.0, 2], ["100175", "FS", 1.0, 2], ["100176", "FS", 1.0, 2], ["100178", "FS", 1.0, 2], ["100181", "FS", 1.0, 2], ["100184", "FS", 1.0, 2], ["1000560", "FS", 1.0, 2]], "100045": [["100001", "FS", 1.0, 4], ["100003", "FS", 1.0, 3], ["100010", "FS", 1.0, 2], ["100013", "FFS", 0.73, 2], ["100015", "FFS", 0.73, 2], ["100019", "FFS", 0.01, 3], ["100026", "FS", 1.0, 1], ["100027", "FS", 1.0, 1], ["100028", "SS", 0.89, 3], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FS", 1.0, 2], ["100035", "FFS", 0.01, 5], ["100036", "FFS", 0.01, 5], ["100049", "FFS", 0.56, 5], ["100050", "FS", 1.0, 6], ["100054", "FFS", 0.56, 5], ["100055", "FFS", 0.56, 5], ["100056", "FFS", 0.56, 5], ["100057", "FFS", 0.56, 5], ["100065", "FFS", 0.56, 5], ["100066", "FFS", 0.56, 5], ["100067", "FFS", 0.56, 5], ["100068", "FFS", 0.56, 5], ["100069", "FFS", 0.56, 5], ["100073", "FS", 1.0, 6], ["100096", "FFS", 0.56, 5], ["100097", "FFS", 0.56, 5], ["100098", "FFS", 0.56, 5], ["1000350", "FS", 1.0, 6], ["100104", "FS", 1.0, 6], ["100105", "SS", 0.89, 3], ["100144", "SS", 0.89, 3], ["100158", "FS", 1.0, 2], ["100160", "FS", 1.0, 2], ["100162", "FFS", 0.73, 2], ["100163", "FFS", 0.73, 2], ["100168", "FS", 1.0, 2], ["100169", "FS", 1.0, 2], ["100175", "FS", 1.0, 2], ["100176", "FS", 1.0, 2], ["100178", "FS", 1.0, 2], ["100181", "FS", 1.0, 2], ["100184", "FS", 1.0, 2], ["1000560", "FS", 1.0, 2]], "100046": [["100001", "FS", 1.0, 4], ["100003", "FS", 1.0, 3], ["100010", "FS", 1.0, 2], ["100013", "FFS", 0.73, 2], ["100015", "FFS", 0.73, 2], ["100019", "FFS", 0.01, 3], ["100026", "FS", 1.0, 1], ["100027", "FS", 1.0, 1], ["100028", "SS", 0.89, 3], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FS", 1.0, 2], ["100035", "FFS", 0.01, 5], ["100036", "FFS", 0.01, 5], ["100049", "FFS", 0.56, 5], ["100050", "FS", 1.0, 6], ["100054", "FFS", 0.56, 5], ["100055", "FFS", 0.56, 5], ["100056", "FFS", 0.56, 5], ["100057", "FFS", 0.56, 5], ["100065", "FFS", 0.56, 5], ["100066", "FFS", 0.56, 5], ["100067", "FFS", 0.56, 5], ["100068", "FFS", 0.56, 5], ["100069", "FFS", 0.56, 5], ["100073", "FS", 1.0, 6], ["100096", "FFS", 0.56, 5], ["100097", "FFS", 0.56, 5], ["100098", "FFS", 0.56, 5], ["1000350", "FS", 1.0, 6], ["100104", "FS", 1.0, 6], ["100105", "SS", 0.89, 3], ["100144", "SS", 0.89, 3], ["100158", "FS", 1.0, 2], ["100160", "FS", 1.0, 2], ["100162", "FFS", 0.73, 2], ["100163", "FFS", 0.73, 2], ["100168", "FS", 1.0, 2], ["100169", "FS", 1.0, 2], ["100175", "FS", 1.0, 2], ["100176", "FS", 1.0, 2], ["100178", "FS", 1.0, 2], ["100181", "FS", 1.0, 2], ["100184", "FS", 1.0, 2], ["1000560", "FS", 1.0, 2]], "100047": [["100001", "FS", 1.0, 4], ["100003", "FS", 1.0, 3], ["100010", "FS", 1.0, 2], ["100013", "FFS", 0.73, 2], ["100015", "FFS", 0.73, 2], ["100019", "FFS", 0.01, 3], ["100026", "FS", 1.0, 1], ["100027", "FS", 1.0, 1], ["100028", "SS", 0.89, 3], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FS", 1.0, 2], ["100035", "FFS", 0.01, 5], ["100036", "FFS", 0.01, 5], ["100049", "FFS", 0.56, 5], ["100050", "FS", 1.0, 6], ["100054", "FFS", 0.56, 5], ["100055", "FFS", 0.56, 5], ["100056", "FFS", 0.56, 5], ["100057", "FFS", 0.56, 5], ["100065", "FFS", 0.56, 5], ["100066", "FFS", 0.56, 5], ["100067", "FFS", 0.56, 5], ["100068", "FFS", 0.56, 5], ["100069", "FFS", 0.56, 5], ["100073", "FS", 1.0, 6], ["100096", "FFS", 0.56, 5], ["100097", "FFS", 0.56, 5], ["100098", "FFS", 0.56, 5], ["1000350", "FS", 1.0, 6], ["100104", "FS", 1.0, 6], ["100105", "SS", 0.89, 3], ["100144", "SS", 0.89, 3], ["100158", "FS", 1.0, 2], ["100160", "FS", 1.0, 2], ["100162", "FFS", 0.73, 2], ["100163", "FFS", 0.73, 2], ["100168", "FS", 1.0, 2], ["100169", "FS", 1.0, 2], ["100175", "FS", 1.0, 2], ["100176", "FS", 1.0, 2], ["100178", "FS", 1.0, 2], ["100181", "FS", 1.0, 2], ["100184", "FS", 1.0, 2], ["1000560", "FS", 1.0, 2]], "100048": [], "100049": [["100001", "FFS", 0.01, 26], ["100002", "FS", 1.0, 1], ["100003", "FFS", 0.46, 24], ["100004", "FFS", 0.01, 2], ["100010", "FFS", 0.04, 23], ["100012", "FS", 1.0, 2], ["100014", "FS", 1.0, 2], ["100018", "FFS", 0.01, 15], ["100020", "FFS", 0.01, 15], ["100021", "FFS", 0.01, 15], ["100028", "FFS", 0.01, 44], ["100051", "FS", 1.0, 7], ["100052", "FS", 1.0, 7], ["100053", "FS", 1.0, 7], ["1000520", "FS", 1.0, 1], ["100095", "FS", 1.0, 1], ["100103", "FFS", 0.23, 3], ["100105", "FFS", 0.4, 44], ["100144", "FFS", 0.4, 44]], "100050": [["100001", "FFS", 0.01, 347], ["100002", "FS", 1.0, 3], ["100003", "FFS", 0.01, 338], ["100033", "FS", 1.0, 2], ["100035", "FS", 1.0, 4], ["100036", "FS", 1.0, 4], ["100040", "FS", 1.0, 1], ["100041", "FS", 1.0, 1], ["1000320", "FS", 1.0, 1], ["100049", "FFS", 0.01, 339], ["100054", "FFS", 0.05, 339], ["100055", "FFS", 0.05, 339], ["100056", "FFS", 0.05, 339], ["100057", "FFS", 0.05, 339], ["100065", "FFS", 0.05, 339], ["100066", "FFS", 0.05, 339], ["100067", "FFS", 0.05, 339], ["100068", "FFS", 0.05, 339], ["100069", "FFS", 0.05, 339], ["100096", "FFS", 0.05, 339], ["100097", "FFS", 0.05, 339], ["100098", "FFS", 0.05, 339]], "100051": [["100050", "SS", 0.33, 3], ["100058", "FFS", 0.75, 3], ["100059", "FFS", 0.75, 3], ["100060", "FFS", 0.75, 3], ["100061", "FFS", 0.75, 3], ["100062", "FFS", 0.75, 3], ["100064", "FFS", 0.75, 3], ["100072", "FFS", 0.48, 11], ["100073", "SS", 0.33, 3], ["100081", "FFS", 0.48, 11], ["100082", "FFS", 0.48, 11], ["1000360", "FFS", 0.48, 11], ["100085", "FFS", 0.48, 11], ["100087", "FFS", 0.48, 11], ["100088", "FFS", 0.48, 11], ["100090", "FFS", 0.48, 11], ["100093", "FFS", 0.48, 11], ["100099", "FFS", 0.48, 11], ["1000350", "SS", 0.33, 3], ["100101", "FFS", 0.48, 11], ["100102", "FFS", 0.48, 11], ["100104", "SS", 0.33, 3], ["100107", "FFS", 0.48, 11], ["100145", "FFS", 0.48, 11], ["1000540", "FFS", 0.48, 11], ["100164", "FFS", 0.48, 11], ["100166", "FFS", 0.48, 11], ["100167", "FFS", 0.48, 11], ["10003300", "FFS", 0.48, 11], ["100173", "FFS", 0.48, 11], ["100174", "FFS", 0.48, 11], ["10003320", "FFS", 0.48, 11], ["100182", "FFS", 0.48, 11], ["100183", "FFS", 0.48, 11], ["10003340", "FFS", 0.48, 11]], "100052": [["100050", "SS", 0.33, 3], ["100058", "FFS", 0.75, 3], ["100059", "FFS", 0.75, 3], ["100060", "FFS", 0.75, 3], ["100061", "FFS", 0.75, 3], ["100062", "FFS", 0.75, 3], ["100064", "FFS", 0.75, 3], ["100072", "FFS", 0.48, 11], ["100073", "SS", 0.33, 3], ["100081", "FFS", 0.48, 11], ["100082", "FFS", 0.48, 11], ["1000360", "FFS", 0.48, 11], ["100085", "FFS", 0.48, 11], ["100087", "FFS", 0.48, 11], ["100088", "FFS", 0.48, 11], ["100090", "FFS", 0.48, 11], ["100093", "FFS", 0.48, 11], ["100099", "FFS", 0.48, 11], ["1000350", "SS", 0.33, 3], ["100101", "FFS", 0.48, 11], ["100102", "FFS", 0.48, 11], ["100104", "SS", 0.33, 3], ["100107", "FFS", 0.48, 11], ["100145", "FFS", 0.48, 11], ["1000540", "FFS", 0.48, 11], ["100164", "FFS", 0.48, 11], ["100166", "FFS", 0.48, 11], ["100167", "FFS", 0.48, 11], ["10003300", "FFS", 0.48, 11], ["100173", "FFS", 0.48, 11], ["100174", "FFS", 0.48, 11], ["10003320", "FFS", 0.48, 11], ["100182", "FFS", 0.48, 11], ["100183", "FFS", 0.48, 11], ["10003340", "FFS", 0.48, 11]], "100053": [["100050", "SS", 0.33, 3], ["100058", "FFS", 0.75, 3], ["100059", "FFS", 0.75, 3], ["100060", "FFS", 0.75, 3], ["100061", "FFS", 0.75, 3], ["100062", "FFS", 0.75, 3], ["100064", "FFS", 0.75, 3], ["100072", "FFS", 0.48, 11], ["100073", "SS", 0.33, 3], ["100081", "FFS", 0.48, 11], ["100082", "FFS", 0.48, 11], ["1000360", "FFS", 0.48, 11], ["100085", "FFS", 0.48, 11], ["100087", "FFS", 0.48, 11], ["100088", "FFS", 0.48, 11], ["100090", "FFS", 0.48, 11], ["100093", "FFS", 0.48, 11], ["100099", "FFS", 0.48, 11], ["1000350", "SS", 0.33, 3], ["100101", "FFS", 0.48, 11], ["100102", "FFS", 0.48, 11], ["100104", "SS", 0.33, 3], ["100107", "FFS", 0.48, 11], ["100145", "FFS", 0.48, 11], ["1000540", "FFS", 0.48, 11], ["100164", "FFS", 0.48, 11], ["100166", "FFS", 0.48, 11], ["100167", "FFS", 0.48, 11], ["10003300", "FFS", 0.48, 11], ["100173", "FFS", 0.48, 11], ["100174", "FFS", 0.48, 11], ["10003320", "FFS", 0.48, 11], ["100182", "FFS", 0.48, 11], ["100183", "FFS", 0.48, 11], ["10003340", "FFS", 0.48, 11]], "100054": [["100001", "FFS", 0.01, 26], ["100002", "FS", 1.0, 1], ["100003", "FFS", 0.46, 24], ["100004", "FFS", 0.01, 2], ["100010", "FFS", 0.04, 23], ["100012", "FS", 1.0, 2], ["100014", "FS", 1.0, 2], ["100018", "FFS", 0.01, 15], ["100020", "FFS", 0.01, 15], ["100021", "FFS", 0.01, 15], ["100028", "FFS", 0.01, 44], ["100051", "FFS", 0.01, 7], ["100052", "FFS", 0.01, 7], ["100053", "FFS", 0.01, 7], ["1000520", "FS", 1.0, 1], ["100095", "FS", 1.0, 1], ["100103", "FFS", 0.23, 3], ["100105", "FFS", 0.4, 44], ["100144", "FFS", 0.4, 44]], "100055": [["100001", "FFS", 0.01, 26], ["100002", "FS", 1.0, 1], ["100003", "FFS", 0.46, 24], ["100004", "FFS", 0.01, 2], ["100010", "FFS", 0.04, 23], ["100012", "FS", 1.0, 2], ["100014", "FS", 1.0, 2], ["100018", "FFS", 0.01, 15], ["100020", "FFS", 0.01, 15], ["100021", "FFS", 0.01, 15], ["100028", "FFS", 0.01, 44], ["100051", "FFS", 0.01, 7], ["100052", "FFS", 0.01, 7], ["100053", "FFS", 0.01, 7], ["1000520", "FS", 1.0, 1], ["100095", "FS", 1.0, 1], ["100103", "FFS", 0.23, 3], ["100105", "FFS", 0.4, 44], ["100144", "FFS", 0.4, 44]], "100056": [["100001", "FFS", 0.01, 26], ["100002", "FS", 1.0, 1], ["100003", "FFS", 0.46, 24], ["100004", "FFS", 0.01, 2], ["100010", "FFS", 0.04, 23], ["100012", "FS", 1.0, 2], ["100014", "FS", 1.0, 2], ["100018", "FFS", 0.01, 15], ["100020", "FFS", 0.01, 15], ["100021", "FFS", 0.01, 15], ["100028", "FFS", 0.01, 44], ["100051", "FFS", 0.01, 7], ["100052", "FFS", 0.01, 7], ["100053", "FFS", 0.01, 7], ["1000520", "FS", 1.0, 1], ["100095", "FS", 1.0, 1], ["100103", "FFS", 0.23, 3], ["100105", "FFS", 0.4, 44], ["100144", "FFS", 0.4, 44]], "100057": [["100001", "FFS", 0.01, 26], ["100002", "FS", 1.0, 1], ["100003", "FFS", 0.46, 24], ["100004", "FFS", 0.01, 2], ["100010", "FFS", 0.04, 23], ["100012", "FS", 1.0, 2], ["100014", "FS", 1.0, 2], ["100018", "FFS", 0.01, 15], ["100020", "FFS", 0.01, 15], ["100021", "FFS", 0.01, 15], ["100028", "FFS", 0.01, 44], ["100051", "FFS", 0.01, 7], ["100052", "FFS", 0.01, 7], ["100053", "FFS", 0.01, 7], ["1000520", "FS", 1.0, 1], ["100095", "FS", 1.0, 1], ["100103", "FFS", 0.23, 3], ["100105", "FFS", 0.4, 44], ["100144", "FFS", 0.4, 44]], "100058": [["100018", "FS", 1.0, 1], ["100020", "FS", 1.0, 1], ["100021", "FS", 1.0, 1], ["100049", "FFS", 0.01, 17], ["100050", "FS", 1.0, 2], ["100054", "FFS", 0.01, 17], ["100055", "FFS", 0.01, 17], ["100056", "FFS", 0.01, 17], ["100057", "FFS", 0.01, 17], ["100063", "SS", 0.08, 3], ["100065", "FFS", 0.5, 17], ["100066", "FFS", 0.5, 17], ["100067", "FFS", 0.5, 17], ["100068", "FFS", 0.5, 17], ["100069", "FFS", 0.5, 17], ["100072", "FS", 1.0, 4], ["100073", "FS", 1.0, 2], ["1000340", "FS", 1.0, 1], ["100077", "FS", 1.0, 1], ["100078", "FS", 1.0, 1], ["100079", "FS", 1.0, 1], ["100081", "FS", 1.0, 4], ["100082", "FS", 1.0, 4], ["1000360", "FS", 1.0, 4], ["100085", "FS", 1.0, 4], ["100087", "FS", 1.0, 4], ["100088", "FS", 1.0, 4], ["100090", "FS", 1.0, 4], ["100093", "FS", 1.0, 4], ["100094", "FS", 1.0, 1], ["100096", "FFS", 0.5, 17], ["100097", "FFS", 0.5, 17], ["100098", "FFS", 0.5, 17], ["100099", "FS", 1.0, 4], ["1000350", "FS", 1.0, 2], ["100101", "FS", 1.0, 4], ["100102", "FS", 1.0, 4], ["100104", "FS", 1.0, 2], ["100107", "FS", 1.0, 4], ["100145", "FS", 1.0, 4], ["1000540", "FS", 1.0, 4], ["100164", "FS", 1.0, 4], ["100166", "FS", 1.0, 4], ["100167", "FS", 1.0, 4], ["10003300", "FS", 1.0, 4], ["100173", "FS", 1.0, 4], ["100174", "FS", 1.0, 4], ["10003320", "FS", 1.0, 4], ["100182", "FS", 1.0, 4], ["100183", "FS", 1.0, 4], ["10003340", "FS", 1.0, 4]], "100059": [["100018", "FS", 1.0, 1], ["100020", "FS", 1.0, 1], ["100021", "FS", 1.0, 1], ["100049", "FFS", 0.01, 17], ["100050", "FS", 1.0, 2], ["100054", "FFS", 0.01, 17], ["100055", "FFS", 0.01, 17], ["100056", "FFS", 0.01, 17], ["100057", "FFS", 0.01, 17], ["100063", "SS", 0.08, 3], ["100065", "FFS", 0.5, 17], ["100066", "FFS", 0.5, 17], ["100067", "FFS", 0.5, 17], ["100068", "FFS", 0.5, 17], ["100069", "FFS", 0.5, 17], ["100072", "FS", 1.0, 4], ["100073", "FS", 1.0, 2], ["1000340", "FS", 1.0, 1], ["100077", "FS", 1.0, 1], ["100078", "FS", 1.0, 1], ["100079", "FS", 1.0, 1], ["100081", "FS", 1.0, 4], ["100082", "FS", 1.0, 4], ["1000360", "FS", 1.0, 4], ["100085", "FS", 1.0, 4], ["100087", "FS", 1.0, 4], ["100088", "FS", 1.0, 4], ["100090", "FS", 1.0, 4], ["100093", "FS", 1.0, 4], ["100094", "FS", 1.0, 1], ["100096", "FFS", 0.5, 17], ["100097", "FFS", 0.5, 17], ["100098", "FFS", 0.5, 17], ["100099", "FS", 1.0, 4], ["1000350", "FS", 1.0, 2], ["100101", "FS", 1.0, 4], ["100102", "FS", 1.0, 4], ["100104", "FS", 1.0, 2], ["100107", "FS", 1.0, 4], ["100145", "FS", 1.0, 4], ["1000540", "FS", 1.0, 4], ["100164", "FS", 1.0, 4], ["100166", "FS", 1.0, 4], ["100167", "FS", 1.0, 4], ["10003300", "FS", 1.0, 4], ["100173", "FS", 1.0, 4], ["100174", "FS", 1.0, 4], ["10003320", "FS", 1.0, 4], ["100182", "FS", 1.0, 4], ["100183", "FS", 1.0, 4], ["10003340", "FS", 1.0, 4]], "100060": [["100018", "FS", 1.0, 1], ["100020", "FS", 1.0, 1], ["100021", "FS", 1.0, 1], ["100049", "FFS", 0.01, 17], ["100050", "FS", 1.0, 2], ["100054", "FFS", 0.01, 17], ["100055", "FFS", 0.01, 17], ["100056", "FFS", 0.01, 17], ["100057", "FFS", 0.01, 17], ["100063", "SS", 0.08, 3], ["100065", "FFS", 0.5, 17], ["100066", "FFS", 0.5, 17], ["100067", "FFS", 0.5, 17], ["100068", "FFS", 0.5, 17], ["100069", "FFS", 0.5, 17], ["100072", "FS", 1.0, 4], ["100073", "FS", 1.0, 2], ["1000340", "FS", 1.0, 1], ["100077", "FS", 1.0, 1], ["100078", "FS", 1.0, 1], ["100079", "FS", 1.0, 1], ["100081", "FS", 1.0, 4], ["100082", "FS", 1.0, 4], ["1000360", "FS", 1.0, 4], ["100085", "FS", 1.0, 4], ["100087", "FS", 1.0, 4], ["100088", "FS", 1.0, 4], ["100090", "FS", 1.0, 4], ["100093", "FS", 1.0, 4], ["100094", "FS", 1.0, 1], ["100096", "FFS", 0.5, 17], ["100097", "FFS", 0.5, 17], ["100098", "FFS", 0.5, 17], ["100099", "FS", 1.0, 4], ["1000350", "FS", 1.0, 2], ["100101", "FS", 1.0, 4], ["100102", "FS", 1.0, 4], ["100104", "FS", 1.0, 2], ["100107", "FS", 1.0, 4], ["100145", "FS", 1.0, 4], ["1000540", "FS", 1.0, 4], ["100164", "FS", 1.0, 4], ["100166", "FS", 1.0, 4], ["100167", "FS", 1.0, 4], ["10003300", "FS", 1.0, 4], ["100173", "FS", 1.0, 4], ["100174", "FS", 1.0, 4], ["10003320", "FS", 1.0, 4], ["100182", "FS", 1.0, 4], ["100183", "FS", 1.0, 4], ["10003340", "FS", 1.0, 4]], "100061": [["100018", "FS", 1.0, 1], ["100020", "FS", 1.0, 1], ["100021", "FS", 1.0, 1], ["100049", "FFS", 0.01, 17], ["100050", "FS", 1.0, 2], ["100054", "FFS", 0.01, 17], ["100055", "FFS", 0.01, 17], ["100056", "FFS", 0.01, 17], ["100057", "FFS", 0.01, 17], ["100063", "SS", 0.08, 3], ["100065", "FFS", 0.5, 17], ["100066", "FFS", 0.5, 17], ["100067", "FFS", 0.5, 17], ["100068", "FFS", 0.5, 17], ["100069", "FFS", 0.5, 17], ["100072", "FS", 1.0, 4], ["100073", "FS", 1.0, 2], ["1000340", "FS", 1.0, 1], ["100077", "FS", 1.0, 1], ["100078", "FS", 1.0, 1], ["100079", "FS", 1.0, 1], ["100081", "FS", 1.0, 4], ["100082", "FS", 1.0, 4], ["1000360", "FS", 1.0, 4], ["100085", "FS", 1.0, 4], ["100087", "FS", 1.0, 4], ["100088", "FS", 1.0, 4], ["100090", "FS", 1.0, 4], ["100093", "FS", 1.0, 4], ["100094", "FS", 1.0, 1], ["100096", "FFS", 0.5, 17], ["100097", "FFS", 0.5, 17], ["100098", "FFS", 0.5, 17], ["100099", "FS", 1.0, 4], ["1000350", "FS", 1.0, 2], ["100101", "FS", 1.0, 4], ["100102", "FS", 1.0, 4], ["100104", "FS", 1.0, 2], ["100107", "FS", 1.0, 4], ["100145", "FS", 1.0, 4], ["1000540", "FS", 1.0, 4], ["100164", "FS", 1.0, 4], ["100166", "FS", 1.0, 4], ["100167", "FS", 1.0, 4], ["10003300", "FS", 1.0, 4], ["100173", "FS", 1.0, 4], ["100174", "FS", 1.0, 4], ["10003320", "FS", 1.0, 4], ["100182", "FS", 1.0, 4], ["100183", "FS", 1.0, 4], ["10003340", "FS", 1.0, 4]], "100062": [["100018", "FS", 1.0, 1], ["100020", "FS", 1.0, 1], ["100021", "FS", 1.0, 1], ["100049", "FFS", 0.01, 17], ["100050", "FS", 1.0, 2], ["100054", "FFS", 0.01, 17], ["100055", "FFS", 0.01, 17], ["100056", "FFS", 0.01, 17], ["100057", "FFS", 0.01, 17], ["100063", "SS", 0.08, 3], ["100065", "FFS", 0.5, 17], ["100066", "FFS", 0.5, 17], ["100067", "FFS", 0.5, 17], ["100068", "FFS", 0.5, 17], ["100069", "FFS", 0.5, 17], ["100072", "FS", 1.0, 4], ["100073", "FS", 1.0, 2], ["1000340", "FS", 1.0, 1], ["100077", "FS", 1.0, 1], ["100078", "FS", 1.0, 1], ["100079", "FS", 1.0, 1], ["100081", "FS", 1.0, 4], ["100082", "FS", 1.0, 4], ["1000360", "FS", 1.0, 4], ["100085", "FS", 1.0, 4], ["100087", "FS", 1.0, 4], ["100088", "FS", 1.0, 4], ["100090", "FS", 1.0, 4], ["100093", "FS", 1.0, 4], ["100094", "FS", 1.0, 1], ["100096", "FFS", 0.5, 17], ["100097", "FFS", 0.5, 17], ["100098", "FFS", 0.5, 17], ["100099", "FS", 1.0, 4], ["1000350", "FS", 1.0, 2], ["100101", "FS", 1.0, 4], ["100102", "FS", 1.0, 4], ["100104", "FS", 1.0, 2], ["100107", "FS", 1.0, 4], ["100145", "FS", 1.0, 4], ["1000540", "FS", 1.0, 4], ["100164", "FS", 1.0, 4], ["100166", "FS", 1.0, 4], ["100167", "FS", 1.0, 4], ["10003300", "FS", 1.0, 4], ["100173", "FS", 1.0, 4], ["100174", "FS", 1.0, 4], ["10003320", "FS", 1.0, 4], ["100182", "FS", 1.0, 4], ["100183", "FS", 1.0, 4], ["10003340", "FS", 1.0, 4]], "100063": [["100049", "FFS", 0.5, 1], ["100054", "FFS", 0.5, 1], ["100055", "FFS", 0.5, 1], ["100056", "FFS", 0.5, 1], ["100057", "FFS", 0.5, 1], ["100065", "FFS", 0.5, 1], ["100066", "FFS", 0.5, 1], ["100067", "FFS", 0.5, 1], ["100068", "FFS", 0.5, 1], ["100069", "FFS", 0.5, 1], ["100096", "FFS", 0.5, 1], ["100097", "FFS", 0.5, 1], ["100098", "FFS", 0.5, 1], ["100127", "FS", 1.0, 1]], "100064": [["100018", "FS", 1.0, 1], ["100020", "FS", 1.0, 1], ["100021", "FS", 1.0, 1], ["100049", "FFS", 0.01, 17], ["100050", "FS", 1.0, 2], ["100054", "FFS", 0.01, 17], ["100055", "FFS", 0.01, 17], ["100056", "FFS", 0.01, 17], ["100057", "FFS", 0.01, 17], ["100063", "SS", 0.08, 3], ["100065", "FFS", 0.5, 17], ["100066", "FFS", 0.5, 17], ["100067", "FFS", 0.5, 17], ["100068", "FFS", 0.5, 17], ["100069", "FFS", 0.5, 17], ["100072", "FS", 1.0, 4], ["100073", "FS", 1.0, 2], ["1000340", "FS", 1.0, 1], ["100077", "FS", 1.0, 1], ["100078", "FS", 1.0, 1], ["100079", "FS", 1.0, 1], ["100081", "FS", 1.0, 4], ["100082", "FS", 1.0, 4], ["1000360", "FS", 1.0, 4], ["100085", "FS", 1.0, 4], ["100087", "FS", 1.0, 4], ["100088", "FS", 1.0, 4], ["100090", "FS", 1.0, 4], ["100093", "FS", 1.0, 4], ["100094", "FS", 1.0, 1], ["100096", "FFS", 0.5, 17], ["100097", "FFS", 0.5, 17], ["100098", "FFS", 0.5, 17], ["100099", "FS", 1.0, 4], ["1000350", "FS", 1.0, 2], ["100101", "FS", 1.0, 4], ["100102", "FS", 1.0, 4], ["100104", "FS", 1.0, 2], ["100107", "FS", 1.0, 4], ["100145", "FS", 1.0, 4], ["1000540", "FS", 1.0, 4], ["100164", "FS", 1.0, 4], ["100166", "FS", 1.0, 4], ["100167", "FS", 1.0, 4], ["10003300", "FS", 1.0, 4], ["100173", "FS", 1.0, 4], ["100174", "FS", 1.0, 4], ["10003320", "FS", 1.0, 4], ["100182", "FS", 1.0, 4], ["100183", "FS", 1.0, 4], ["10003340", "FS", 1.0, 4]], "100065": [["100001", "FFS", 0.01, 26], ["100002", "FS", 1.0, 1], ["100003", "FFS", 0.46, 24], ["100004", "FFS", 0.01, 2], ["100010", "FFS", 0.04, 23], ["100012", "FS", 1.0, 2], ["100014", "FS", 1.0, 2], ["100018", "FFS", 0.01, 15], ["100020", "FFS", 0.01, 15], ["100021", "FFS", 0.01, 15], ["100028", "FFS", 0.01, 44], ["100051", "FFS", 0.01, 7], ["100052", "FFS", 0.01, 7], ["100053", "FFS", 0.01, 7], ["1000520", "FS", 1.0, 1], ["100095", "FS", 1.0, 1], ["100103", "FFS", 0.23, 3], ["100105", "FFS", 0.4, 44], ["100144", "FFS", 0.4, 44]], "100066": [["100001", "FFS", 0.01, 26], ["100002", "FS", 1.0, 1], ["100003", "FFS", 0.46, 24], ["100004", "FFS", 0.01, 2], ["100010", "FFS", 0.04, 23], ["100012", "FS", 1.0, 2], ["100014", "FS", 1.0, 2], ["100018", "FFS", 0.01, 15], ["100020", "FFS", 0.01, 15], ["100021", "FFS", 0.01, 15], ["100028", "FFS", 0.01, 44], ["100051", "FFS", 0.01, 7], ["100052", "FFS", 0.01, 7], ["100053", "FFS", 0.01, 7], ["1000520", "FS", 1.0, 1], ["100095", "FS", 1.0, 1], ["100103", "FFS", 0.23, 3], ["100105", "FFS", 0.4, 44], ["100144", "FFS", 0.4, 44]], "100067": [["100001", "FFS", 0.01, 26], ["100002", "FS", 1.0, 1], ["100003", "FFS", 0.46, 24], ["100004", "FFS", 0.01, 2], ["100010", "FFS", 0.04, 23], ["100012", "FS", 1.0, 2], ["100014", "FS", 1.0, 2], ["100018", "FFS", 0.01, 15], ["100020", "FFS", 0.01, 15], ["100021", "FFS", 0.01, 15], ["100028", "FFS", 0.01, 44], ["100051", "FFS", 0.01, 7], ["100052", "FFS", 0.01, 7], ["100053", "FFS", 0.01, 7], ["1000520", "FS", 1.0, 1], ["100095", "FS", 1.0, 1], ["100103", "FFS", 0.23, 3], ["100105", "FFS", 0.4, 44], ["100144", "FFS", 0.4, 44]], "100068": [["100001", "FFS", 0.01, 26], ["100002", "FS", 1.0, 1], ["100003", "FFS", 0.46, 24], ["100004", "FFS", 0.01, 2], ["100010", "FFS", 0.04, 23], ["100012", "FS", 1.0, 2], ["100014", "FS", 1.0, 2], ["100018", "FFS", 0.01, 15], ["100020", "FFS", 0.01, 15], ["100021", "FFS", 0.01, 15], ["100028", "FFS", 0.01, 44], ["100051", "FFS", 0.01, 7], ["100052", "FFS", 0.01, 7], ["100053", "FFS", 0.01, 7], ["1000520", "FS", 1.0, 1], ["100095", "FS", 1.0, 1], ["100103", "FFS", 0.23, 3], ["100105", "FFS", 0.4, 44], ["100144", "FFS", 0.4, 44]], "100069": [["100001", "FFS", 0.01, 26], ["100002", "FS", 1.0, 1], ["100003", "FFS", 0.46, 24], ["100004", "FFS", 0.01, 2], ["100010", "FFS", 0.04, 23], ["100012", "FS", 1.0, 2], ["100014", "FS", 1.0, 2], ["100018", "FFS", 0.01, 15], ["100020", "FFS", 0.01, 15], ["100021", "FFS", 0.01, 15], ["100028", "FFS", 0.01, 44], ["100051", "FFS", 0.01, 7], ["100052", "FFS", 0.01, 7], ["100053", "FFS", 0.01, 7], ["1000520", "FS", 1.0, 1], ["100095", "FS", 1.0, 1], ["100103", "FFS", 0.23, 3], ["100105", "FFS", 0.4, 44], ["100144", "FFS", 0.4, 44]], "1000520": [["100050", "FS", 1.0, 1], ["100051", "FS", 1.0, 2], ["100052", "FS", 1.0, 2], ["100053", "FS", 1.0, 2], ["100071", "FS", 1.0, 2], ["100072", "FS", 1.0, 2], ["100073", "FS", 1.0, 1], ["100081", "FS", 1.0, 2], ["100082", "FS", 1.0, 2], ["1000360", "FS", 1.0, 2], ["100085", "FS", 1.0, 2], ["100087", "FS", 1.0, 2], ["100088", "FS", 1.0, 2], ["100089", "FS", 1.0, 2], ["100090", "FS", 1.0, 2], ["100093", "FS", 1.0, 2], ["100099", "FS", 1.0, 2], ["1000350", "FS", 1.0, 1], ["100101", "FS", 1.0, 2], ["100102", "FS", 1.0, 2], ["100104", "FS", 1.0, 1], ["100107", "FS", 1.0, 2], ["100111", "FS", 1.0, 2], ["100112", "FS", 1.0, 2], ["1000470", "FS", 1.0, 2], ["100115", "FS", 1.0, 2], ["100116", "FS", 1.0, 2], ["100117", "FS", 1.0, 2], ["100118", "FS", 1.0, 2], ["100119", "FS", 1.0, 2], ["100120", "FS", 1.0, 2], ["100121", "FS", 1.0, 2], ["100122", "FS", 1.0, 2], ["100123", "FS", 1.0, 2], ["100139", "FS", 1.0, 2], ["100145", "FS", 1.0, 2], ["100146", "FS", 1.0, 2], ["100147", "FS", 1.0, 2], ["100150", "FS", 1.0, 2], ["100152", "FS", 1.0, 2], ["100154", "FS", 1.0, 2], ["1000540", "FS", 1.0, 2], ["100164", "FS", 1.0, 2], ["100166", "FS", 1.0, 2], ["100167", "FS", 1.0, 2], ["10003300", "FS", 1.0, 2], ["100173", "FS", 1.0, 2], ["100174", "FS", 1.0, 2], ["10003320", "FS", 1.0, 2], ["100182", "FS", 1.0, 2], ["100183", "FS", 1.0, 2], ["10003340", "FS", 1.0, 2]], "100071": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100073", "FFS", 0.25, 47], ["100091", "FFS", 0.5, 36], ["1000350", "FFS", 0.25, 47], ["100104", "FFS", 0.25, 47], ["100105", "FS", 1.0, 60], ["100106", "FFS", 0.5, 36], ["100124", "FFS", 0.5, 36], ["100127", "FFS", 0.05, 43], ["100128", "FFS", 0.5, 36], ["100129", "FFS", 0.5, 36], ["1000530", "FFS", 0.5, 36], ["100132", "FFS", 0.5, 36], ["100133", "FFS", 0.5, 36], ["100134", "FFS", 0.5, 36], ["100144", "FS", 1.0, 60]], "100072": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FS", 1.0, 22], ["100096", "FFS", 0.1, 102], ["100097", "FFS", 0.1, 102], ["100098", "FFS", 0.1, 102], ["1000350", "FS", 1.0, 22], ["100104", "FS", 1.0, 22], ["100105", "FS", 1.0, 37], ["1000460", "FS", 1.0, 18], ["100126", "FS", 1.0, 18], ["100127", "FFS", 0.16, 48], ["100130", "FS", 1.0, 18], ["100141", "FS", 1.0, 1], ["100144", "FS", 1.0, 37], ["100148", "FS", 1.0, 2], ["100149", "FS", 1.0, 18], ["100153", "FS", 1.0, 1], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100073": [["100001", "FFS", 0.01, 347], ["100002", "FS", 1.0, 3], ["100003", "FFS", 0.01, 338], ["100033", "FS", 1.0, 2], ["100035", "FS", 1.0, 4], ["100036", "FS", 1.0, 4], ["100040", "FS", 1.0, 1], ["100041", "FS", 1.0, 1], ["1000320", "FS", 1.0, 1], ["100049", "FFS", 0.01, 339], ["100054", "FFS", 0.01, 339], ["100055", "FFS", 0.01, 339], ["100056", "FFS", 0.01, 339], ["100057", "FFS", 0.01, 339], ["100065", "FFS", 0.01, 339], ["100066", "FFS", 0.01, 339], ["100067", "FFS", 0.01, 339], ["100068", "FFS", 0.01, 339], ["100069", "FFS", 0.01, 339], ["100096", "FFS", 0.05, 339], ["100097", "FFS", 0.05, 339], ["100098", "FFS", 0.05, 339]], "100074": [], "100075": [], "1000340": [["100010", "FS", 1.0, 1], ["100012", "FS", 1.0, 3], ["100013", "FFS", 0.5, 5], ["100014", "FS", 1.0, 3], ["100015", "FFS", 0.5, 5], ["100022", "FS", 1.0, 1], ["100023", "FS", 1.0, 2], ["100024", "FS", 1.0, 2], ["100025", "FS", 1.0, 2], ["100026", "FS", 1.0, 2], ["100027", "FS", 1.0, 4], ["100028", "FS", 1.0, 10], ["100029", "FS", 1.0, 2], ["100030", "FS", 1.0, 2], ["100033", "FS", 1.0, 2], ["100034", "FS", 1.0, 2], ["100035", "FFS", 0.82, 5], ["100036", "FFS", 0.82, 5], ["100039", "FS", 1.0, 4], ["100040", "FS", 1.0, 2], ["100041", "FS", 1.0, 2], ["100042", "FS", 1.0, 4], ["1000320", "FS", 1.0, 2], ["100044", "FS", 1.0, 4], ["100045", "FS", 1.0, 4], ["100046", "FS", 1.0, 4], ["100047", "FS", 1.0, 4], ["100049", "FFS", 0.01, 15], ["100050", "FFS", 0.01, 8], ["100054", "FFS", 0.01, 15], ["100055", "FFS", 0.01, 15], ["100056", "FFS", 0.01, 15], ["100057", "FFS", 0.01, 15], ["100065", "FFS", 0.01, 15], ["100066", "FFS", 0.01, 15], ["100067", "FFS", 0.01, 15], ["100068", "FFS", 0.01, 15], ["100069", "FFS", 0.01, 15], ["100071", "FFS", 0.01, 23], ["100072", "FFS", 0.01, 20], ["100073", "FFS", 0.01, 8], ["1000350", "FS", 1.0, 8], ["100104", "FS", 1.0, 8], ["100105", "FS", 1.0, 10], ["100127", "FFS", 0.1, 7], ["100144", "FS", 1.0, 10], ["100158", "FS", 1.0, 2], ["100160", "FS", 1.0, 2], ["100162", "FFS", 0.5, 5], ["100163", "FFS", 0.5, 5], ["100168", "FS", 1.0, 2], ["100169", "FS", 1.0, 2], ["100175", "FS", 1.0, 2], ["100176", "FS", 1.0, 2], ["100178", "FS", 1.0, 2], ["100181", "FS", 1.0, 2], ["100184", "FS", 1.0, 2], ["1000560", "FS", 1.0, 2]], "100077": [["100010", "FS", 1.0, 1], ["100012", "FS", 1.0, 3], ["100013", "FFS", 0.5, 5], ["100014", "FS", 1.0, 3], ["100015", "FFS", 0.5, 5], ["100022", "FS", 1.0, 1], ["100023", "FS", 1.0, 2], ["100024", "FS", 1.0, 2], ["100025", "FS", 1.0, 2], ["100026", "FS", 1.0, 2], ["100027", "FS", 1.0, 4], ["100028", "FS", 1.0, 10], ["100029", "FS", 1.0, 2], ["100030", "FS", 1.0, 2], ["100033", "FS", 1.0, 2], ["100034", "FS", 1.0, 2], ["100035", "FFS", 0.82, 5], ["100036", "FFS", 0.82, 5], ["100039", "FS", 1.0, 4], ["100040", "FS", 1.0, 2], ["100041", "FS", 1.0, 2], ["100042", "FS", 1.0, 4], ["1000320", "FS", 1.0, 2], ["100044", "FS", 1.0, 4], ["100045", "FS", 1.0, 4], ["100046", "FS", 1.0, 4], ["100047", "FS", 1.0, 4], ["100049", "FFS", 0.01, 15], ["100050", "FFS", 0.01, 8], ["100054", "FFS", 0.01, 15], ["100055", "FFS", 0.01, 15], ["100056", "FFS", 0.01, 15], ["100057", "FFS", 0.01, 15], ["100065", "FFS", 0.01, 15], ["100066", "FFS", 0.01, 15], ["100067", "FFS", 0.01, 15], ["100068", "FFS", 0.01, 15], ["100069", "FFS", 0.01, 15], ["100071", "FFS", 0.01, 23], ["100072", "FFS", 0.01, 20], ["100073", "FFS", 0.01, 8], ["1000350", "FS", 1.0, 8], ["100104", "FS", 1.0, 8], ["100105", "FS", 1.0, 10], ["100127", "FFS", 0.1, 7], ["100144", "FS", 1.0, 10], ["100158", "FS", 1.0, 2], ["100160", "FS", 1.0, 2], ["100162", "FFS", 0.5, 5], ["100163", "FFS", 0.5, 5], ["100168", "FS", 1.0, 2], ["100169", "FS", 1.0, 2], ["100175", "FS", 1.0, 2], ["100176", "FS", 1.0, 2], ["100178", "FS", 1.0, 2], ["100181", "FS", 1.0, 2], ["100184", "FS", 1.0, 2], ["1000560", "FS", 1.0, 2]], "100078": [["100010", "FS", 1.0, 1], ["100012", "FS", 1.0, 3], ["100013", "FFS", 0.5, 5], ["100014", "FS", 1.0, 3], ["100015", "FFS", 0.5, 5], ["100022", "FS", 1.0, 1], ["100023", "FS", 1.0, 2], ["100024", "FS", 1.0, 2], ["100025", "FS", 1.0, 2], ["100026", "FS", 1.0, 2], ["100027", "FS", 1.0, 4], ["100028", "FS", 1.0, 10], ["100029", "FS", 1.0, 2], ["100030", "FS", 1.0, 2], ["100033", "FS", 1.0, 2], ["100034", "FS", 1.0, 2], ["100035", "FFS", 0.82, 5], ["100036", "FFS", 0.82, 5], ["100039", "FS", 1.0, 4], ["100040", "FS", 1.0, 2], ["100041", "FS", 1.0, 2], ["100042", "FS", 1.0, 4], ["1000320", "FS", 1.0, 2], ["100044", "FS", 1.0, 4], ["100045", "FS", 1.0, 4], ["100046", "FS", 1.0, 4], ["100047", "FS", 1.0, 4], ["100049", "FFS", 0.01, 15], ["100050", "FFS", 0.01, 8], ["100054", "FFS", 0.01, 15], ["100055", "FFS", 0.01, 15], ["100056", "FFS", 0.01, 15], ["100057", "FFS", 0.01, 15], ["100065", "FFS", 0.01, 15], ["100066", "FFS", 0.01, 15], ["100067", "FFS", 0.01, 15], ["100068", "FFS", 0.01, 15], ["100069", "FFS", 0.01, 15], ["100071", "FFS", 0.01, 23], ["100072", "FFS", 0.01, 20], ["100073", "FFS", 0.01, 8], ["1000350", "FS", 1.0, 8], ["100104", "FS", 1.0, 8], ["100105", "FS", 1.0, 10], ["100127", "FFS", 0.1, 7], ["100144", "FS", 1.0, 10], ["100158", "FS", 1.0, 2], ["100160", "FS", 1.0, 2], ["100162", "FFS", 0.5, 5], ["100163", "FFS", 0.5, 5], ["100168", "FS", 1.0, 2], ["100169", "FS", 1.0, 2], ["100175", "FS", 1.0, 2], ["100176", "FS", 1.0, 2], ["100178", "FS", 1.0, 2], ["100181", "FS", 1.0, 2], ["100184", "FS", 1.0, 2], ["1000560", "FS", 1.0, 2]], "100079": [["100010", "FS", 1.0, 1], ["100012", "FS", 1.0, 3], ["100013", "FFS", 0.5, 5], ["100014", "FS", 1.0, 3], ["100015", "FFS", 0.5, 5], ["100022", "FS", 1.0, 1], ["100023", "FS", 1.0, 2], ["100024", "FS", 1.0, 2], ["100025", "FS", 1.0, 2], ["100026", "FS", 1.0, 2], ["100027", "FS", 1.0, 4], ["100028", "FS", 1.0, 10], ["100029", "FS", 1.0, 2], ["100030", "FS", 1.0, 2], ["100033", "FS", 1.0, 2], ["100034", "FS", 1.0, 2], ["100035", "FFS", 0.82, 5], ["100036", "FFS", 0.82, 5], ["100039", "FS", 1.0, 4], ["100040", "FS", 1.0, 2], ["100041", "FS", 1.0, 2], ["100042", "FS", 1.0, 4], ["1000320", "FS", 1.0, 2], ["100044", "FS", 1.0, 4], ["100045", "FS", 1.0, 4], ["100046", "FS", 1.0, 4], ["100047", "FS", 1.0, 4], ["100049", "FFS", 0.01, 15], ["100050", "FFS", 0.01, 8], ["100054", "FFS", 0.01, 15], ["100055", "FFS", 0.01, 15], ["100056", "FFS", 0.01, 15], ["100057", "FFS", 0.01, 15], ["100065", "FFS", 0.01, 15], ["100066", "FFS", 0.01, 15], ["100067", "FFS", 0.01, 15], ["100068", "FFS", 0.01, 15], ["100069", "FFS", 0.01, 15], ["100071", "FFS", 0.01, 23], ["100072", "FFS", 0.01, 20], ["100073", "FFS", 0.01, 8], ["1000350", "FS", 1.0, 8], ["100104", "FS", 1.0, 8], ["100105", "FS", 1.0, 10], ["100127", "FFS", 0.1, 7], ["100144", "FS", 1.0, 10], ["100158", "FS", 1.0, 2], ["100160", "FS", 1.0, 2], ["100162", "FFS", 0.5, 5], ["100163", "FFS", 0.5, 5], ["100168", "FS", 1.0, 2], ["100169", "FS", 1.0, 2], ["100175", "FS", 1.0, 2], ["100176", "FS", 1.0, 2], ["100178", "FS", 1.0, 2], ["100181", "FS", 1.0, 2], ["100184", "FS", 1.0, 2], ["1000560", "FS", 1.0, 2]], "100080": [["100018", "SS", 0.04, 14], ["100020", "SS", 0.04, 14], ["100021", "SS", 0.04, 14], ["100049", "FFS", 0.74, 10], ["100050", "SS", 0.07, 1], ["100054", "FFS", 0.74, 10], ["100055", "FFS", 0.74, 10], ["100056", "FFS", 0.74, 10], ["100057", "FFS", 0.74, 10], ["100065", "FFS", 0.74, 10], ["100066", "FFS", 0.74, 10], ["100067", "FFS", 0.74, 10], ["100068", "FFS", 0.74, 10], ["100069", "FFS", 0.74, 10], ["100071", "FS", 1.0, 4], ["100072", "SS", 0.06, 8], ["100073", "SS", 0.07, 1], ["1000340", "SS", 0.04, 14], ["100077", "SS", 0.04, 14], ["100078", "SS", 0.04, 14], ["100079", "SS", 0.04, 14], ["100086", "FFS", 0.32, 1], ["100089", "FS", 1.0, 4], ["100094", "SS", 0.37, 14], ["100096", "FFS", 0.74, 10], ["100097", "FFS", 0.74, 10], ["100098", "FFS", 0.74, 10], ["100111", "FS", 1.0, 4], ["100112", "FS", 1.0, 4], ["1000470", "FS", 1.0, 4], ["100115", "FS", 1.0, 4], ["100116", "FS", 1.0, 4], ["100117", "FS", 1.0, 4], ["100118", "FS", 1.0, 4], ["100119", "FS", 1.0, 4], ["100120", "FS", 1.0, 4], ["100121", "FS", 1.0, 4], ["100122", "FS", 1.0, 4], ["100123", "FS", 1.0, 4], ["100139", "FS", 1.0, 4], ["100146", "FS", 1.0, 4], ["100147", "FS", 1.0, 4], ["100150", "FS", 1.0, 4], ["100152", "FS", 1.0, 4], ["100154", "FS", 1.0, 4]], "100081": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100096", "FFS", 0.1, 102], ["100097", "FFS", 0.1, 102], ["100098", "FFS", 0.1, 102], ["1000350", "FS", 1.0, 22], ["100104", "FS", 1.0, 22], ["100105", "FS", 1.0, 37], ["1000460", "FS", 1.0, 18], ["100126", "FS", 1.0, 18], ["100127", "FFS", 0.16, 48], ["100130", "FS", 1.0, 18], ["100141", "FS", 1.0, 1], ["100144", "FS", 1.0, 37], ["100148", "FS", 1.0, 2], ["100149", "FS", 1.0, 18], ["100153", "FS", 1.0, 1], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100082": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100096", "FFS", 0.1, 102], ["100097", "FFS", 0.1, 102], ["100098", "FFS", 0.1, 102], ["1000350", "FS", 1.0, 22], ["100104", "FS", 1.0, 22], ["100105", "FS", 1.0, 37], ["1000460", "FS", 1.0, 18], ["100126", "FS", 1.0, 18], ["100127", "FFS", 0.16, 48], ["100130", "FS", 1.0, 18], ["100141", "FS", 1.0, 1], ["100144", "FS", 1.0, 37], ["100148", "FS", 1.0, 2], ["100149", "FS", 1.0, 18], ["100153", "FS", 1.0, 1], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "1000360": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100096", "FFS", 0.1, 102], ["100097", "FFS", 0.1, 102], ["100098", "FFS", 0.1, 102], ["1000350", "FS", 1.0, 22], ["100104", "FS", 1.0, 22], ["100105", "FS", 1.0, 37], ["1000460", "FS", 1.0, 18], ["100126", "FS", 1.0, 18], ["100127", "FFS", 0.16, 48], ["100130", "FS", 1.0, 18], ["100141", "FS", 1.0, 1], ["100144", "FS", 1.0, 37], ["100148", "FS", 1.0, 2], ["100149", "FS", 1.0, 18], ["100153", "FS", 1.0, 1], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100084": [["100018", "SS", 0.04, 14], ["100020", "SS", 0.04, 14], ["100021", "SS", 0.04, 14], ["100049", "FFS", 0.74, 10], ["100050", "SS", 0.07, 1], ["100054", "FFS", 0.74, 10], ["100055", "FFS", 0.74, 10], ["100056", "FFS", 0.74, 10], ["100057", "FFS", 0.74, 10], ["100065", "FFS", 0.74, 10], ["100066", "FFS", 0.74, 10], ["100067", "FFS", 0.74, 10], ["100068", "FFS", 0.74, 10], ["100069", "FFS", 0.74, 10], ["100071", "FS", 1.0, 4], ["100072", "SS", 0.06, 8], ["100073", "SS", 0.07, 1], ["1000340", "SS", 0.04, 14], ["100077", "SS", 0.04, 14], ["100078", "SS", 0.04, 14], ["100079", "SS", 0.04, 14], ["100081", "SS", 0.06, 8], ["100082", "SS", 0.06, 8], ["1000360", "SS", 0.06, 8], ["100086", "FFS", 0.32, 1], ["100089", "FS", 1.0, 4], ["100094", "SS", 0.37, 14], ["100096", "FFS", 0.74, 10], ["100097", "FFS", 0.74, 10], ["100098", "FFS", 0.74, 10], ["100111", "FS", 1.0, 4], ["100112", "FS", 1.0, 4], ["1000470", "FS", 1.0, 4], ["100115", "FS", 1.0, 4], ["100116", "FS", 1.0, 4], ["100117", "FS", 1.0, 4], ["100118", "FS", 1.0, 4], ["100119", "FS", 1.0, 4], ["100120", "FS", 1.0, 4], ["100121", "FS", 1.0, 4], ["100122", "FS", 1.0, 4], ["100123", "FS", 1.0, 4], ["100139", "FS", 1.0, 4], ["100146", "FS", 1.0, 4], ["100147", "FS", 1.0, 4], ["100150", "FS", 1.0, 4], ["100152", "FS", 1.0, 4], ["100154", "FS", 1.0, 4]], "100085": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100096", "FFS", 0.1, 102], ["100097", "FFS", 0.1, 102], ["100098", "FFS", 0.1, 102], ["1000350", "FS", 1.0, 22], ["100104", "FS", 1.0, 22], ["100105", "FS", 1.0, 37], ["1000460", "FS", 1.0, 18], ["100126", "FS", 1.0, 18], ["100127", "FFS", 0.16, 48], ["100130", "FS", 1.0, 18], ["100141", "FS", 1.0, 1], ["100144", "FS", 1.0, 37], ["100148", "FS", 1.0, 2], ["100149", "FS", 1.0, 18], ["100153", "FS", 1.0, 1], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100086": [["100071", "SS", 0.36, 1], ["100072", "FFS", 0.01, 2], ["100081", "FFS", 0.01, 2], ["100082", "FFS", 0.01, 2], ["1000360", "FFS", 0.01, 2], ["100085", "FFS", 0.01, 2], ["100089", "SS", 0.36, 1], ["100111", "SS", 0.36, 1], ["100112", "SS", 0.36, 1], ["1000470", "SS", 0.36, 1], ["100115", "SS", 0.36, 1], ["100116", "SS", 0.36, 1], ["100117", "SS", 0.36, 1], ["100118", "SS", 0.36, 1], ["100119", "SS", 0.36, 1], ["100120", "SS", 0.36, 1], ["100121", "SS", 0.36, 1], ["100122", "SS", 0.36, 1], ["100123", "SS", 0.36, 1], ["100139", "SS", 0.36, 1], ["100146", "SS", 0.36, 1], ["100147", "SS", 0.36, 1], ["100150", "SS", 0.36, 1], ["100152", "SS", 0.36, 1], ["100154", "SS", 0.36, 1]], "100087": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100096", "FFS", 0.1, 102], ["100097", "FFS", 0.1, 102], ["100098", "FFS", 0.1, 102], ["1000350", "FS", 1.0, 22], ["100104", "FS", 1.0, 22], ["100105", "FS", 1.0, 37], ["1000460", "FS", 1.0, 18], ["100126", "FS", 1.0, 18], ["100127", "FFS", 0.16, 48], ["100130", "FS", 1.0, 18], ["100141", "FS", 1.0, 1], ["100144", "FS", 1.0, 37], ["100148", "FS", 1.0, 2], ["100149", "FS", 1.0, 18], ["100153", "FS", 1.0, 1], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100088": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100096", "FFS", 0.1, 102], ["100097", "FFS", 0.1, 102], ["100098", "FFS", 0.1, 102], ["1000350", "FS", 1.0, 22], ["100104", "FS", 1.0, 22], ["100105", "FS", 1.0, 37], ["1000460", "FS", 1.0, 18], ["100126", "FS", 1.0, 18], ["100127", "FFS", 0.16, 48], ["100130", "FS", 1.0, 18], ["100141", "FS", 1.0, 1], ["100144", "FS", 1.0, 37], ["100148", "FS", 1.0, 2], ["100149", "FS", 1.0, 18], ["100153", "FS", 1.0, 1], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100089": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100091", "FFS", 0.5, 36], ["1000350", "FFS", 0.25, 47], ["100104", "FFS", 0.25, 47], ["100105", "FS", 1.0, 60], ["100106", "FFS", 0.5, 36], ["100124", "FFS", 0.5, 36], ["100127", "FFS", 0.05, 43], ["100128", "FFS", 0.5, 36], ["100129", "FFS", 0.5, 36], ["1000530", "FFS", 0.5, 36], ["100132", "FFS", 0.5, 36], ["100133", "FFS", 0.5, 36], ["100134", "FFS", 0.5, 36], ["100144", "FS", 1.0, 60]], "100090": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100096", "FFS", 0.1, 102], ["100097", "FFS", 0.1, 102], ["100098", "FFS", 0.1, 102], ["1000350", "FS", 1.0, 22], ["100104", "FS", 1.0, 22], ["100105", "FS", 1.0, 37], ["1000460", "FS", 1.0, 18], ["100126", "FS", 1.0, 18], ["100127", "FFS", 0.16, 48], ["100130", "FS", 1.0, 18], ["100141", "FS", 1.0, 1], ["100144", "FS", 1.0, 37], ["100148", "FS", 1.0, 2], ["100149", "FS", 1.0, 18], ["100153", "FS", 1.0, 1], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100091": [["100001", "FFS", 0.01, 3], ["100003", "FFS", 0.06, 2], ["100010", "FS", 1.0, 4], ["100018", "FS", 1.0, 6], ["100019", "FS", 1.0, 1], ["100020", "FS", 1.0, 6], ["100021", "FS", 1.0, 6], ["100028", "FS", 1.0, 9], ["100039", "FS", 1.0, 1], ["100042", "FS", 1.0, 1], ["100044", "FS", 1.0, 1], ["100045", "FS", 1.0, 1], ["100046", "FS", 1.0, 1], ["100047", "FS", 1.0, 1], ["100049", "FS", 1.0, 11], ["100050", "FS", 1.0, 7], ["100051", "FS", 1.0, 1], ["100052", "FS", 1.0, 1], ["100053", "FS", 1.0, 1], ["100054", "FS", 1.0, 11], ["100055", "FS", 1.0, 11], ["100056", "FS", 1.0, 11], ["100057", "FS", 1.0, 11], ["100065", "FS", 1.0, 11], ["100066", "FS", 1.0, 11], ["100067", "FS", 1.0, 11], ["100068", "FS", 1.0, 11], ["100069", "FS", 1.0, 11], ["100072", "FFS", 0.01, 16], ["100073", "FS", 1.0, 7], ["1000340", "FS", 1.0, 6], ["100077", "FS", 1.0, 6], ["100078", "FS", 1.0, 6], ["100079", "FS", 1.0, 6], ["100080", "SS", 0.25, 1], ["100081", "FFS", 0.01, 16], ["100082", "FFS", 0.01, 16], ["1000360", "FFS", 0.01, 16], ["100084", "SS", 0.25, 1], ["100085", "FFS", 0.01, 16], ["100087", "FFS", 0.01, 16], ["100088", "FFS", 0.01, 16], ["100090", "FFS", 0.01, 16], ["100093", "FS", 1.0, 16], ["100096", "FS", 1.0, 11], ["100097", "FS", 1.0, 11], ["100098", "FS", 1.0, 11], ["100099", "FS", 1.0, 16], ["1000350", "FS", 1.0, 7], ["100101", "FS", 1.0, 16], ["100102", "FS", 1.0, 16], ["100104", "FS", 1.0, 7], ["100105", "FS", 1.0, 9], ["100107", "FS", 1.0, 16], ["1000460", "FS", 1.0, 9], ["100126", "FS", 1.0, 9], ["100127", "FS", 1.0, 9], ["100130", "FS", 1.0, 9], ["100142", "FFS", 0.44, 2], ["100144", "FS", 1.0, 9], ["100145", "FS", 1.0, 16], ["100149", "FS", 1.0, 9], ["100159", "FS", 1.0, 1], ["1000540", "FS", 1.0, 16], ["100164", "FS", 1.0, 16], ["100166", "FS", 1.0, 16], ["100167", "FS", 1.0, 16], ["10003300", "FS", 1.0, 16], ["100173", "FS", 1.0, 16], ["100174", "FS", 1.0, 16], ["10003320", "FS", 1.0, 16], ["100182", "FS", 1.0, 16], ["100183", "FS", 1.0, 16], ["10003340", "FS", 1.0, 16], ["100189", "FFS", 0.44, 2], ["100191", "FFS", 0.11, 142], ["100192", "FFS", 0.11, 142]], "100092": [["100018", "FS", 1.0, 2], ["100020", "FS", 1.0, 2], ["100021", "FS", 1.0, 2], ["100071", "FS", 1.0, 1], ["100072", "FS", 1.0, 3], ["1000340", "FS", 1.0, 2], ["100077", "FS", 1.0, 2], ["100078", "FS", 1.0, 2], ["100079", "FS", 1.0, 2], ["100080", "FS", 1.0, 2], ["100081", "FS", 1.0, 3], ["100082", "FS", 1.0, 3], ["1000360", "FS", 1.0, 3], ["100084", "FS", 1.0, 2], ["100085", "FS", 1.0, 3], ["100087", "FS", 1.0, 3], ["100088", "FS", 1.0, 3], ["100089", "FS", 1.0, 1], ["100090", "FS", 1.0, 3], ["100091", "FS", 1.0, 1], ["100093", "FS", 1.0, 3], ["100094", "FS", 1.0, 2], ["100099", "FS", 1.0, 3], ["100101", "FS", 1.0, 3], ["100102", "FS", 1.0, 3], ["100106", "FS", 1.0, 1], ["100107", "FS", 1.0, 3], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100124", "FS", 1.0, 1], ["100128", "FS", 1.0, 1], ["100129", "FS", 1.0, 1], ["1000530", "FS", 1.0, 1], ["100132", "FS", 1.0, 1], ["100133", "FS", 1.0, 1], ["100134", "FS", 1.0, 1], ["100139", "FS", 1.0, 1], ["100145", "FS", 1.0, 3], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["1000540", "FS", 1.0, 3], ["100164", "FS", 1.0, 3], ["100166", "FS", 1.0, 3], ["100167", "FS", 1.0, 3], ["10003300", "FS", 1.0, 3], ["100173", "FS", 1.0, 3], ["100174", "FS", 1.0, 3], ["10003320", "FS", 1.0, 3], ["100182", "FS", 1.0, 3], ["100183", "FS", 1.0, 3], ["10003340", "FS", 1.0, 3]], "100093": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100096", "FFS", 0.1, 102], ["100097", "FFS", 0.1, 102], ["100098", "FFS", 0.1, 102], ["1000350", "FS", 1.0, 22], ["100104", "FS", 1.0, 22], ["100105", "FS", 1.0, 37], ["1000460", "FS", 1.0, 18], ["100126", "FS", 1.0, 18], ["100127", "FFS", 0.16, 48], ["100130", "FS", 1.0, 18], ["100141", "FS", 1.0, 1], ["100144", "FS", 1.0, 37], ["100148", "FS", 1.0, 2], ["100149", "FS", 1.0, 18], ["100153", "FS", 1.0, 1], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100094": [["100010", "FS", 1.0, 1], ["100012", "FS", 1.0, 3], ["100013", "FFS", 0.5, 5], ["100014", "FS", 1.0, 3], ["100015", "FFS", 0.5, 5], ["100022", "FS", 1.0, 1], ["100023", "FS", 1.0, 2], ["100024", "FS", 1.0, 2], ["100025", "FS", 1.0, 2], ["100026", "FS", 1.0, 2], ["100027", "FS", 1.0, 4], ["100028", "FS", 1.0, 10], ["100029", "FS", 1.0, 2], ["100030", "FS", 1.0, 2], ["100033", "FS", 1.0, 2], ["100034", "FS", 1.0, 2], ["100035", "FFS", 0.82, 5], ["100036", "FFS", 0.82, 5], ["100039", "FS", 1.0, 4], ["100040", "FS", 1.0, 2], ["100041", "FS", 1.0, 2], ["100042", "FS", 1.0, 4], ["1000320", "FS", 1.0, 2], ["100044", "FS", 1.0, 4], ["100045", "FS", 1.0, 4], ["100046", "FS", 1.0, 4], ["100047", "FS", 1.0, 4], ["100049", "FFS", 0.01, 15], ["100050", "FFS", 0.01, 8], ["100054", "FFS", 0.01, 15], ["100055", "FFS", 0.01, 15], ["100056", "FFS", 0.01, 15], ["100057", "FFS", 0.01, 15], ["100065", "FFS", 0.01, 15], ["100066", "FFS", 0.01, 15], ["100067", "FFS", 0.01, 15], ["100068", "FFS", 0.01, 15], ["100069", "FFS", 0.01, 15], ["100071", "FFS", 0.01, 23], ["100072", "FFS", 0.01, 20], ["100073", "FFS", 0.01, 8], ["100081", "FFS", 0.01, 20], ["100082", "FFS", 0.01, 20], ["1000360", "FFS", 0.01, 20], ["100085", "FFS", 0.01, 20], ["100087", "FFS", 0.01, 20], ["100088", "FFS", 0.01, 20], ["100089", "FFS", 0.01, 23], ["100090", "FFS", 0.01, 20], ["100091", "FFS", 0.09, 6], ["100093", "FFS", 0.01, 20], ["1000350", "FS", 1.0, 8], ["100104", "FS", 1.0, 8], ["100105", "FS", 1.0, 10], ["100127", "FFS", 0.1, 7], ["100144", "FS", 1.0, 10], ["100158", "FS", 1.0, 2], ["100160", "FS", 1.0, 2], ["100162", "FFS", 0.5, 5], ["100163", "FFS", 0.5, 5], ["100168", "FS", 1.0, 2], ["100169", "FS", 1.0, 2], ["100175", "FS", 1.0, 2], ["100176", "FS", 1.0, 2], ["100178", "FS", 1.0, 2], ["100181", "FS", 1.0, 2], ["100184", "FS", 1.0, 2], ["1000560", "FS", 1.0, 2]], "100095": [["100018", "FS", 1.0, 2], ["100020", "FS", 1.0, 2], ["100021", "FS", 1.0, 2], ["100071", "FFS", 0.01, 1], ["100072", "FFS", 0.87, 2], ["1000340", "FS", 1.0, 2], ["100077", "FS", 1.0, 2], ["100078", "FS", 1.0, 2], ["100079", "FS", 1.0, 2], ["100081", "FFS", 0.87, 2], ["100082", "FFS", 0.87, 2], ["1000360", "FFS", 0.87, 2], ["100085", "FFS", 0.87, 2], ["100087", "FFS", 0.87, 2], ["100088", "FFS", 0.87, 2], ["100089", "FFS", 0.01, 1], ["100090", "FFS", 0.87, 2], ["100093", "FFS", 0.87, 2], ["100094", "FS", 1.0, 2], ["100099", "FFS", 0.87, 2], ["100101", "FFS", 0.87, 2], ["100102", "FFS", 0.87, 2], ["100107", "FFS", 0.87, 2], ["100145", "FFS", 0.87, 2], ["1000540", "FFS", 0.87, 2], ["100164", "FFS", 0.87, 2], ["100166", "FFS", 0.87, 2], ["100167", "FFS", 0.87, 2], ["10003300", "FFS", 0.87, 2], ["100173", "FFS", 0.87, 2], ["100174", "FFS", 0.87, 2], ["10003320", "FFS", 0.87, 2], ["100182", "FFS", 0.87, 2], ["100183", "FFS", 0.87, 2], ["10003340", "FFS", 0.87, 2]], "100096": [["100001", "FFS", 0.01, 26], ["100002", "FS", 1.0, 1], ["100003", "FFS", 0.46, 24], ["100004", "FFS", 0.01, 2], ["100010", "FFS", 0.04, 23], ["100012", "FS", 1.0, 2], ["100014", "FS", 1.0, 2], ["100018", "FFS", 0.01, 15], ["100020", "FFS", 0.01, 15], ["100021", "FFS", 0.01, 15], ["100028", "FFS", 0.01, 44], ["100051", "FFS", 0.01, 7], ["100052", "FFS", 0.01, 7], ["100053", "FFS", 0.01, 7], ["1000520", "FS", 1.0, 1], ["100071", "FFS", 0.01, 57], ["1000340", "FFS", 0.01, 15], ["100077", "FFS", 0.01, 15], ["100078", "FFS", 0.01, 15], ["100079", "FFS", 0.01, 15], ["100089", "FFS", 0.01, 57], ["100094", "FFS", 0.01, 15], ["100095", "FS", 1.0, 1], ["100103", "FFS", 0.23, 3], ["100105", "FFS", 0.4, 44], ["100144", "FFS", 0.4, 44]], "100097": [["100001", "FFS", 0.01, 26], ["100002", "FS", 1.0, 1], ["100003", "FFS", 0.46, 24], ["100004", "FFS", 0.01, 2], ["100010", "FFS", 0.04, 23], ["100012", "FS", 1.0, 2], ["100014", "FS", 1.0, 2], ["100018", "FFS", 0.01, 15], ["100020", "FFS", 0.01, 15], ["100021", "FFS", 0.01, 15], ["100028", "FFS", 0.01, 44], ["100051", "FFS", 0.01, 7], ["100052", "FFS", 0.01, 7], ["100053", "FFS", 0.01, 7], ["1000520", "FS", 1.0, 1], ["100071", "FFS", 0.01, 57], ["1000340", "FFS", 0.01, 15], ["100077", "FFS", 0.01, 15], ["100078", "FFS", 0.01, 15], ["100079", "FFS", 0.01, 15], ["100089", "FFS", 0.01, 57], ["100094", "FFS", 0.01, 15], ["100095", "FS", 1.0, 1], ["100103", "FFS", 0.23, 3], ["100105", "FFS", 0.4, 44], ["100144", "FFS", 0.4, 44]], "100098": [["100001", "FFS", 0.01, 26], ["100002", "FS", 1.0, 1], ["100003", "FFS", 0.46, 24], ["100004", "FFS", 0.01, 2], ["100010", "FFS", 0.04, 23], ["100012", "FS", 1.0, 2], ["100014", "FS", 1.0, 2], ["100018", "FFS", 0.01, 15], ["100020", "FFS", 0.01, 15], ["100021", "FFS", 0.01, 15], ["100028", "FFS", 0.01, 44], ["100051", "FFS", 0.01, 7], ["100052", "FFS", 0.01, 7], ["100053", "FFS", 0.01, 7], ["1000520", "FS", 1.0, 1], ["100071", "FFS", 0.01, 57], ["1000340", "FFS", 0.01, 15], ["100077", "FFS", 0.01, 15], ["100078", "FFS", 0.01, 15], ["100079", "FFS", 0.01, 15], ["100089", "FFS", 0.01, 57], ["100094", "FFS", 0.01, 15], ["100095", "FS", 1.0, 1], ["100103", "FFS", 0.23, 3], ["100105", "FFS", 0.4, 44], ["100144", "FFS", 0.4, 44]], "100099": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 20], ["100096", "FFS", 0.01, 102], ["100097", "FFS", 0.01, 102], ["100098", "FFS", 0.01, 102], ["1000350", "FS", 1.0, 22], ["100104", "FS", 1.0, 22], ["100105", "FS", 1.0, 37], ["1000460", "FS", 1.0, 18], ["100126", "FS", 1.0, 18], ["100127", "FFS", 0.16, 48], ["100130", "FS", 1.0, 18], ["100141", "FS", 1.0, 1], ["100144", "FS", 1.0, 37], ["100148", "FS", 1.0, 2], ["100149", "FS", 1.0, 18], ["100153", "FS", 1.0, 1], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "1000350": [["100001", "FFS", 0.01, 347], ["100002", "FS", 1.0, 3], ["100003", "FFS", 0.01, 338], ["100033", "FS", 1.0, 2], ["100035", "FS", 1.0, 4], ["100036", "FS", 1.0, 4], ["100040", "FS", 1.0, 1], ["100041", "FS", 1.0, 1], ["1000320", "FS", 1.0, 1], ["100049", "FFS", 0.01, 339], ["100054", "FFS", 0.01, 339], ["100055", "FFS", 0.01, 339], ["100056", "FFS", 0.01, 339], ["100057", "FFS", 0.01, 339], ["100065", "FFS", 0.01, 339], ["100066", "FFS", 0.01, 339], ["100067", "FFS", 0.01, 339], ["100068", "FFS", 0.01, 339], ["100069", "FFS", 0.01, 339], ["100080", "FFS", 0.1, 1], ["100084", "FFS", 0.1, 1], ["100096", "FFS", 0.01, 339], ["100097", "FFS", 0.01, 339], ["100098", "FFS", 0.01, 339]], "100101": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 20], ["100096", "FFS", 0.01, 102], ["100097", "FFS", 0.01, 102], ["100098", "FFS", 0.01, 102], ["1000350", "FFS", 0.01, 22], ["100104", "FS", 1.0, 22], ["100105", "FS", 1.0, 37], ["1000460", "FS", 1.0, 18], ["100126", "FS", 1.0, 18], ["100127", "FFS", 0.16, 48], ["100130", "FS", 1.0, 18], ["100141", "FS", 1.0, 1], ["100144", "FS", 1.0, 37], ["100148", "FS", 1.0, 2], ["100149", "FS", 1.0, 18], ["100153", "FS", 1.0, 1], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100102": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 20], ["100096", "FFS", 0.01, 102], ["100097", "FFS", 0.01, 102], ["100098", "FFS", 0.01, 102], ["1000350", "FFS", 0.01, 22], ["100104", "FS", 1.0, 22], ["100105", "FS", 1.0, 37], ["1000460", "FS", 1.0, 18], ["100126", "FS", 1.0, 18], ["100127", "FFS", 0.16, 48], ["100130", "FS", 1.0, 18], ["100141", "FS", 1.0, 1], ["100144", "FS", 1.0, 37], ["100148", "FS", 1.0, 2], ["100149", "FS", 1.0, 18], ["100153", "FS", 1.0, 1], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100103": [["100050", "FS", 1.0, 1], ["100071", "FFS", 0.01, 1], ["100072", "FS", 1.0, 1], ["100073", "FS", 1.0, 1], ["100081", "FS", 1.0, 1], ["100082", "FS", 1.0, 1], ["1000360", "FS", 1.0, 1], ["100085", "FS", 1.0, 1], ["100087", "FS", 1.0, 1], ["100088", "FS", 1.0, 1], ["100089", "FFS", 0.01, 1], ["100090", "FS", 1.0, 1], ["100093", "FS", 1.0, 1], ["100099", "FS", 1.0, 1], ["1000350", "FS", 1.0, 1], ["100101", "FS", 1.0, 1], ["100102", "FS", 1.0, 1], ["100104", "FS", 1.0, 1], ["100107", "FS", 1.0, 1], ["100145", "FS", 1.0, 1], ["1000540", "FS", 1.0, 1], ["100164", "FS", 1.0, 1], ["100166", "FS", 1.0, 1], ["100167", "FS", 1.0, 1], ["10003300", "FS", 1.0, 1], ["100173", "FS", 1.0, 1], ["100174", "FS", 1.0, 1], ["10003320", "FS", 1.0, 1], ["100182", "FS", 1.0, 1], ["100183", "FS", 1.0, 1], ["10003340", "FS", 1.0, 1]], "100104": [["100001", "FFS", 0.01, 347], ["100002", "FS", 1.0, 3], ["100003", "FFS", 0.01, 338], ["100033", "FS", 1.0, 2], ["100035", "FS", 1.0, 4], ["100036", "FS", 1.0, 4], ["100040", "FS", 1.0, 1], ["100041", "FS", 1.0, 1], ["1000320", "FS", 1.0, 1], ["100049", "FFS", 0.01, 339], ["100054", "FFS", 0.01, 339], ["100055", "FFS", 0.01, 339], ["100056", "FFS", 0.01, 339], ["100057", "FFS", 0.01, 339], ["100065", "FFS", 0.01, 339], ["100066", "FFS", 0.01, 339], ["100067", "FFS", 0.01, 339], ["100068", "FFS", 0.01, 339], ["100069", "FFS", 0.01, 339], ["100080", "FFS", 0.1, 1], ["100084", "FFS", 0.1, 1], ["100096", "FFS", 0.01, 339], ["100097", "FFS", 0.01, 339], ["100098", "FFS", 0.01, 339]], "100105": [["100001", "FFS", 0.01, 32], ["100002", "FS", 1.0, 5], ["100003", "FFS", 0.01, 34], ["100005", "FS", 1.0, 14], ["100006", "FS", 1.0, 14], ["100012", "FS", 1.0, 4], ["100013", "SS", 0.81, 4], ["100014", "FS", 1.0, 4], ["100015", "SS", 0.81, 4], ["100026", "FFS", 0.62, 3], ["100029", "FFS", 0.62, 3], ["100030", "FFS", 0.62, 3], ["100033", "FFS", 0.33, 2], ["100035", "FFS", 0.01, 14], ["100036", "FFS", 0.01, 14], ["100050", "FFS", 0.01, 28], ["100073", "FFS", 0.01, 28], ["1000350", "FFS", 0.01, 28], ["100104", "FFS", 0.01, 28], ["100141", "FS", 1.0, 1], ["100142", "SS", 0.66, 2], ["100143", "FFS", 0.57, 8], ["100155", "FFS", 0.57, 8], ["100158", "FFS", 0.33, 2], ["100160", "FFS", 0.33, 2], ["100168", "FFS", 0.33, 2], ["100169", "FFS", 0.33, 2], ["100175", "FFS", 0.33, 2], ["100176", "FFS", 0.33, 2], ["100178", "FFS", 0.33, 2], ["100181", "FFS", 0.33, 2], ["100184", "FFS", 0.33, 2], ["1000560", "FFS", 0.33, 2], ["100189", "SS", 0.66, 2]], "100106": [["100001", "FFS", 0.01, 3], ["100003", "FFS", 0.06, 2], ["100010", "FS", 1.0, 4], ["100018", "FS", 1.0, 6], ["100019", "FS", 1.0, 1], ["100020", "FS", 1.0, 6], ["100021", "FS", 1.0, 6], ["100028", "FS", 1.0, 9], ["100039", "FS", 1.0, 1], ["100042", "FS", 1.0, 1], ["100044", "FS", 1.0, 1], ["100045", "FS", 1.0, 1], ["100046", "FS", 1.0, 1], ["100047", "FS", 1.0, 1], ["100049", "FS", 1.0, 11], ["100050", "FS", 1.0, 7], ["100051", "FS", 1.0, 1], ["100052", "FS", 1.0, 1], ["100053", "FS", 1.0, 1], ["100054", "FS", 1.0, 11], ["100055", "FS", 1.0, 11], ["100056", "FS", 1.0, 11], ["100057", "FS", 1.0, 11], ["100065", "FS", 1.0, 11], ["100066", "FS", 1.0, 11], ["100067", "FS", 1.0, 11], ["100068", "FS", 1.0, 11], ["100069", "FS", 1.0, 11], ["100072", "FFS", 0.01, 16], ["100073", "FS", 1.0, 7], ["1000340", "FS", 1.0, 6], ["100077", "FS", 1.0, 6], ["100078", "FS", 1.0, 6], ["100079", "FS", 1.0, 6], ["100080", "SS", 0.25, 1], ["100081", "FFS", 0.01, 16], ["100082", "FFS", 0.01, 16], ["1000360", "FFS", 0.01, 16], ["100084", "SS", 0.25, 1], ["100085", "FFS", 0.01, 16], ["100087", "FFS", 0.01, 16], ["100088", "FFS", 0.01, 16], ["100090", "FFS", 0.01, 16], ["100093", "FFS", 0.01, 16], ["100094", "FS", 1.0, 6], ["100096", "FS", 1.0, 11], ["100097", "FS", 1.0, 11], ["100098", "FS", 1.0, 11], ["100099", "FFS", 0.01, 16], ["1000350", "FS", 1.0, 7], ["100101", "FFS", 0.01, 16], ["100102", "FFS", 0.01, 16], ["100104", "FS", 1.0, 7], ["100105", "FS", 1.0, 9], ["100107", "FS", 1.0, 16], ["1000460", "FS", 1.0, 9], ["100126", "FS", 1.0, 9], ["100127", "FS", 1.0, 9], ["100130", "FS", 1.0, 9], ["100142", "FFS", 0.44, 2], ["100144", "FS", 1.0, 9], ["100145", "FS", 1.0, 16], ["100149", "FS", 1.0, 9], ["100159", "FS", 1.0, 1], ["1000540", "FS", 1.0, 16], ["100164", "FS", 1.0, 16], ["100166", "FS", 1.0, 16], ["100167", "FS", 1.0, 16], ["10003300", "FS", 1.0, 16], ["100173", "FS", 1.0, 16], ["100174", "FS", 1.0, 16], ["10003320", "FS", 1.0, 16], ["100182", "FS", 1.0, 16], ["100183", "FS", 1.0, 16], ["10003340", "FS", 1.0, 16], ["100189", "FFS", 0.44, 2], ["100191", "FFS", 0.11, 142], ["100192", "FFS", 0.11, 142]], "100107": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 20], ["100096", "FFS", 0.01, 102], ["100097", "FFS", 0.01, 102], ["100098", "FFS", 0.01, 102], ["1000350", "FFS", 0.01, 22], ["100104", "FFS", 0.01, 22], ["100105", "FFS", 0.01, 37], ["1000460", "FS", 1.0, 18], ["100126", "FS", 1.0, 18], ["100127", "FFS", 0.16, 48], ["100130", "FS", 1.0, 18], ["100141", "FS", 1.0, 1], ["100144", "FS", 1.0, 37], ["100148", "FS", 1.0, 2], ["100149", "FS", 1.0, 18], ["100153", "FS", 1.0, 1], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100108": [["100018", "FS", 1.0, 1], ["100020", "FS", 1.0, 1], ["100021", "FS", 1.0, 1], ["100049", "FS", 1.0, 2], ["100050", "FS", 1.0, 2], ["100054", "FS", 1.0, 2], ["100055", "FS", 1.0, 2], ["100056", "FS", 1.0, 2], ["100057", "FS", 1.0, 2], ["100065", "FS", 1.0, 2], ["100066", "FS", 1.0, 2], ["100067", "FS", 1.0, 2], ["100068", "FS", 1.0, 2], ["100069", "FS", 1.0, 2], ["100072", "FS", 1.0, 2], ["100073", "FS", 1.0, 2], ["1000340", "FS", 1.0, 1], ["100077", "FS", 1.0, 1], ["100078", "FS", 1.0, 1], ["100079", "FS", 1.0, 1], ["100081", "FS", 1.0, 2], ["100082", "FS", 1.0, 2], ["1000360", "FS", 1.0, 2], ["100085", "FS", 1.0, 2], ["100087", "FS", 1.0, 2], ["100088", "FS", 1.0, 2], ["100090", "FS", 1.0, 2], ["100093", "FS", 1.0, 2], ["100094", "FS", 1.0, 1], ["100096", "FS", 1.0, 2], ["100097", "FS", 1.0, 2], ["100098", "FS", 1.0, 2], ["100099", "FS", 1.0, 2], ["1000350", "FS", 1.0, 2], ["100101", "FS", 1.0, 2], ["100102", "FS", 1.0, 2], ["100103", "FS", 1.0, 1], ["100104", "FS", 1.0, 2], ["100107", "FS", 1.0, 2], ["100145", "FS", 1.0, 2], ["1000540", "FS", 1.0, 2], ["100164", "FS", 1.0, 2], ["100166", "FS", 1.0, 2], ["100167", "FS", 1.0, 2], ["10003300", "FS", 1.0, 2], ["100173", "FS", 1.0, 2], ["100174", "FS", 1.0, 2], ["10003320", "FS", 1.0, 2], ["100182", "FS", 1.0, 2], ["100183", "FS", 1.0, 2], ["10003340", "FS", 1.0, 2]], "100109": [["100108", "FFS", 0.01, 2]], "100110": [], "100111": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.5, 36], ["100127", "FFS", 0.05, 43], ["100128", "FFS", 0.5, 36], ["100129", "FFS", 0.5, 36], ["1000530", "FFS", 0.5, 36], ["100132", "FFS", 0.5, 36], ["100133", "FFS", 0.5, 36], ["100134", "FFS", 0.5, 36], ["100144", "FS", 1.0, 60]], "100112": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.5, 36], ["100127", "FFS", 0.05, 43], ["100128", "FFS", 0.5, 36], ["100129", "FFS", 0.5, 36], ["1000530", "FFS", 0.5, 36], ["100132", "FFS", 0.5, 36], ["100133", "FFS", 0.5, 36], ["100134", "FFS", 0.5, 36], ["100144", "FS", 1.0, 60]], "100113": [], "1000470": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.5, 36], ["100127", "FFS", 0.05, 43], ["100128", "FFS", 0.5, 36], ["100129", "FFS", 0.5, 36], ["1000530", "FFS", 0.5, 36], ["100132", "FFS", 0.5, 36], ["100133", "FFS", 0.5, 36], ["100134", "FFS", 0.5, 36], ["100144", "FS", 1.0, 60]], "100115": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.5, 36], ["100127", "FFS", 0.05, 43], ["100128", "FFS", 0.5, 36], ["100129", "FFS", 0.5, 36], ["1000530", "FFS", 0.5, 36], ["100132", "FFS", 0.5, 36], ["100133", "FFS", 0.5, 36], ["100134", "FFS", 0.5, 36], ["100144", "FS", 1.0, 60]], "100116": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.5, 36], ["100127", "FFS", 0.05, 43], ["100128", "FFS", 0.5, 36], ["100129", "FFS", 0.5, 36], ["1000530", "FFS", 0.5, 36], ["100132", "FFS", 0.5, 36], ["100133", "FFS", 0.5, 36], ["100134", "FFS", 0.5, 36], ["100144", "FS", 1.0, 60]], "100117": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.5, 36], ["100127", "FFS", 0.05, 43], ["100128", "FFS", 0.5, 36], ["100129", "FFS", 0.5, 36], ["1000530", "FFS", 0.5, 36], ["100132", "FFS", 0.5, 36], ["100133", "FFS", 0.5, 36], ["100134", "FFS", 0.5, 36], ["100144", "FS", 1.0, 60]], "100118": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.5, 36], ["100127", "FFS", 0.05, 43], ["100128", "FFS", 0.5, 36], ["100129", "FFS", 0.5, 36], ["1000530", "FFS", 0.5, 36], ["100132", "FFS", 0.5, 36], ["100133", "FFS", 0.5, 36], ["100134", "FFS", 0.5, 36], ["100144", "FS", 1.0, 60]], "100119": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.5, 36], ["100127", "FFS", 0.05, 43], ["100128", "FFS", 0.5, 36], ["100129", "FFS", 0.5, 36], ["1000530", "FFS", 0.5, 36], ["100132", "FFS", 0.5, 36], ["100133", "FFS", 0.5, 36], ["100134", "FFS", 0.5, 36], ["100144", "FS", 1.0, 60]], "100120": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.5, 36], ["100127", "FFS", 0.05, 43], ["100128", "FFS", 0.5, 36], ["100129", "FFS", 0.5, 36], ["1000530", "FFS", 0.5, 36], ["100132", "FFS", 0.5, 36], ["100133", "FFS", 0.5, 36], ["100134", "FFS", 0.5, 36], ["100144", "FS", 1.0, 60]], "100121": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.5, 36], ["100127", "FFS", 0.05, 43], ["100128", "FFS", 0.5, 36], ["100129", "FFS", 0.5, 36], ["1000530", "FFS", 0.5, 36], ["100132", "FFS", 0.5, 36], ["100133", "FFS", 0.5, 36], ["100134", "FFS", 0.5, 36], ["100144", "FS", 1.0, 60]], "100122": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.5, 36], ["100127", "FFS", 0.05, 43], ["100128", "FFS", 0.5, 36], ["100129", "FFS", 0.5, 36], ["1000530", "FFS", 0.5, 36], ["100132", "FFS", 0.5, 36], ["100133", "FFS", 0.5, 36], ["100134", "FFS", 0.5, 36], ["100144", "FS", 1.0, 60]], "100123": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.5, 36], ["100127", "FFS", 0.05, 43], ["100128", "FFS", 0.5, 36], ["100129", "FFS", 0.5, 36], ["1000530", "FFS", 0.5, 36], ["100132", "FFS", 0.5, 36], ["100133", "FFS", 0.5, 36], ["100134", "FFS", 0.5, 36], ["100144", "FS", 1.0, 60]], "100124": [["100001", "FFS", 0.01, 3], ["100003", "FFS", 0.06, 2], ["100010", "FS", 1.0, 4], ["100018", "FS", 1.0, 6], ["100019", "FS", 1.0, 1], ["100020", "FS", 1.0, 6], ["100021", "FS", 1.0, 6], ["100028", "FS", 1.0, 9], ["100039", "FS", 1.0, 1], ["100042", "FS", 1.0, 1], ["100044", "FS", 1.0, 1], ["100045", "FS", 1.0, 1], ["100046", "FS", 1.0, 1], ["100047", "FS", 1.0, 1], ["100049", "FS", 1.0, 11], ["100050", "FS", 1.0, 7], ["100051", "FS", 1.0, 1], ["100052", "FS", 1.0, 1], ["100053", "FS", 1.0, 1], ["100054", "FS", 1.0, 11], ["100055", "FS", 1.0, 11], ["100056", "FS", 1.0, 11], ["100057", "FS", 1.0, 11], ["100065", "FS", 1.0, 11], ["100066", "FS", 1.0, 11], ["100067", "FS", 1.0, 11], ["100068", "FS", 1.0, 11], ["100069", "FS", 1.0, 11], ["100072", "FFS", 0.01, 16], ["100073", "FS", 1.0, 7], ["1000340", "FS", 1.0, 6], ["100077", "FS", 1.0, 6], ["100078", "FS", 1.0, 6], ["100079", "FS", 1.0, 6], ["100080", "SS", 0.25, 1], ["100081", "FFS", 0.01, 16], ["100082", "FFS", 0.01, 16], ["1000360", "FFS", 0.01, 16], ["100084", "SS", 0.25, 1], ["100085", "FFS", 0.01, 16], ["100087", "FFS", 0.01, 16], ["100088", "FFS", 0.01, 16], ["100090", "FFS", 0.01, 16], ["100093", "FFS", 0.01, 16], ["100094", "FS", 1.0, 6], ["100096", "FS", 1.0, 11], ["100097", "FS", 1.0, 11], ["100098", "FS", 1.0, 11], ["100099", "FFS", 0.01, 16], ["1000350", "FS", 1.0, 7], ["100101", "FFS", 0.01, 16], ["100102", "FFS", 0.01, 16], ["100104", "FS", 1.0, 7], ["100105", "FS", 1.0, 9], ["100107", "FFS", 0.01, 16], ["1000460", "FS", 1.0, 9], ["100126", "FS", 1.0, 9], ["100127", "FS", 1.0, 9], ["100130", "FS", 1.0, 9], ["100142", "FFS", 0.44, 2], ["100144", "FS", 1.0, 9], ["100145", "FS", 1.0, 16], ["100149", "FS", 1.0, 9], ["100159", "FS", 1.0, 1], ["1000540", "FS", 1.0, 16], ["100164", "FS", 1.0, 16], ["100166", "FS", 1.0, 16], ["100167", "FS", 1.0, 16], ["10003300", "FS", 1.0, 16], ["100173", "FS", 1.0, 16], ["100174", "FS", 1.0, 16], ["10003320", "FS", 1.0, 16], ["100182", "FS", 1.0, 16], ["100183", "FS", 1.0, 16], ["10003340", "FS", 1.0, 16], ["100189", "FFS", 0.44, 2], ["100191", "FFS", 0.11, 142], ["100192", "FFS", 0.11, 142]], "1000460": [["100003", "FS", 1.0, 3], ["100018", "FS", 1.0, 1], ["100020", "FS", 1.0, 1], ["100021", "FS", 1.0, 1], ["100028", "FFS", 0.01, 5], ["100039", "FS", 1.0, 1], ["100042", "FS", 1.0, 1], ["100044", "FS", 1.0, 1], ["100045", "FS", 1.0, 1], ["100046", "FS", 1.0, 1], ["100047", "FS", 1.0, 1], ["100049", "FS", 1.0, 1], ["100050", "FS", 1.0, 1], ["100054", "FS", 1.0, 1], ["100055", "FS", 1.0, 1], ["100056", "FS", 1.0, 1], ["100057", "FS", 1.0, 1], ["100065", "FS", 1.0, 1], ["100066", "FS", 1.0, 1], ["100067", "FS", 1.0, 1], ["100068", "FS", 1.0, 1], ["100069", "FS", 1.0, 1], ["100071", "FFS", 0.01, 25], ["100073", "FS", 1.0, 1], ["1000340", "FS", 1.0, 1], ["100077", "FS", 1.0, 1], ["100078", "FS", 1.0, 1], ["100079", "FS", 1.0, 1], ["100089", "FFS", 0.01, 25], ["100094", "FS", 1.0, 1], ["100096", "FS", 1.0, 1], ["100097", "FS", 1.0, 1], ["100098", "FS", 1.0, 1], ["1000350", "FS", 1.0, 1], ["100104", "FS", 1.0, 1], ["100105", "FFS", 0.01, 5], ["100111", "FFS", 0.01, 25], ["100112", "FFS", 0.01, 25], ["1000470", "FFS", 0.01, 25], ["100115", "FFS", 0.01, 25], ["100116", "FFS", 0.01, 25], ["100117", "FFS", 0.01, 25], ["100118", "FFS", 0.01, 25], ["100119", "FFS", 0.01, 25], ["100120", "FFS", 0.01, 25], ["100121", "FFS", 0.01, 25], ["100122", "FFS", 0.01, 25], ["100123", "FFS", 0.01, 25], ["100139", "FS", 1.0, 25], ["100143", "FS", 1.0, 3], ["100144", "FS", 1.0, 5], ["100146", "FS", 1.0, 25], ["100147", "FS", 1.0, 25], ["100150", "FS", 1.0, 25], ["100152", "FS", 1.0, 25], ["100154", "FS", 1.0, 25], ["100155", "FS", 1.0, 3], ["100159", "FS", 1.0, 1], ["100191", "FFS", 0.94, 35], ["100192", "FFS", 0.94, 35]], "100126": [["100003", "FS", 1.0, 3], ["100018", "FS", 1.0, 1], ["100020", "FS", 1.0, 1], ["100021", "FS", 1.0, 1], ["100028", "FFS", 0.01, 5], ["100039", "FS", 1.0, 1], ["100042", "FS", 1.0, 1], ["100044", "FS", 1.0, 1], ["100045", "FS", 1.0, 1], ["100046", "FS", 1.0, 1], ["100047", "FS", 1.0, 1], ["100049", "FS", 1.0, 1], ["100050", "FS", 1.0, 1], ["100054", "FS", 1.0, 1], ["100055", "FS", 1.0, 1], ["100056", "FS", 1.0, 1], ["100057", "FS", 1.0, 1], ["100065", "FS", 1.0, 1], ["100066", "FS", 1.0, 1], ["100067", "FS", 1.0, 1], ["100068", "FS", 1.0, 1], ["100069", "FS", 1.0, 1], ["100071", "FFS", 0.01, 25], ["100073", "FS", 1.0, 1], ["1000340", "FS", 1.0, 1], ["100077", "FS", 1.0, 1], ["100078", "FS", 1.0, 1], ["100079", "FS", 1.0, 1], ["100089", "FFS", 0.01, 25], ["100094", "FS", 1.0, 1], ["100096", "FS", 1.0, 1], ["100097", "FS", 1.0, 1], ["100098", "FS", 1.0, 1], ["1000350", "FS", 1.0, 1], ["100104", "FS", 1.0, 1], ["100105", "FFS", 0.01, 5], ["100111", "FFS", 0.01, 25], ["100112", "FFS", 0.01, 25], ["1000470", "FFS", 0.01, 25], ["100115", "FFS", 0.01, 25], ["100116", "FFS", 0.01, 25], ["100117", "FFS", 0.01, 25], ["100118", "FFS", 0.01, 25], ["100119", "FFS", 0.01, 25], ["100120", "FFS", 0.01, 25], ["100121", "FFS", 0.01, 25], ["100122", "FFS", 0.01, 25], ["100123", "FFS", 0.01, 25], ["100139", "FS", 1.0, 25], ["100143", "FS", 1.0, 3], ["100144", "FS", 1.0, 5], ["100146", "FS", 1.0, 25], ["100147", "FS", 1.0, 25], ["100150", "FS", 1.0, 25], ["100152", "FS", 1.0, 25], ["100154", "FS", 1.0, 25], ["100155", "FS", 1.0, 3], ["100159", "FS", 1.0, 1], ["100191", "FFS", 0.94, 35], ["100192", "FFS", 0.94, 35]], "100127": [["100001", "FFS", 0.01, 381], ["100002", "FFS", 0.52, 21], ["100003", "FFS", 0.01, 444], ["100004", "FFS", 0.01, 31], ["100012", "FFS", 0.01, 45], ["100014", "FFS", 0.01, 45], ["100019", "FFS", 0.01, 54], ["100023", "FS", 1.0, 2], ["100024", "FS", 1.0, 2], ["100025", "FS", 1.0, 2], ["100028", "FFS", 0.01, 32], ["100039", "FS", 1.0, 5], ["100042", "FS", 1.0, 5], ["100044", "FS", 1.0, 5], ["100045", "FS", 1.0, 5], ["100046", "FS", 1.0, 5], ["100047", "FS", 1.0, 5], ["100049", "FFS", 0.01, 282], ["100050", "FFS", 0.01, 65], ["100054", "FFS", 0.01, 282], ["100055", "FFS", 0.01, 282], ["100056", "FFS", 0.01, 282], ["100057", "FFS", 0.01, 282], ["100065", "FFS", 0.01, 282], ["100066", "FFS", 0.01, 282], ["100067", "FFS", 0.01, 282], ["100068", "FFS", 0.01, 282], ["100069", "FFS", 0.01, 282], ["100073", "FFS", 0.01, 65], ["100096", "FFS", 0.01, 282], ["100097", "FFS", 0.01, 282], ["100098", "FFS", 0.01, 282], ["1000350", "FFS", 0.01, 65], ["100104", "FFS", 0.01, 65], ["100105", "FFS", 0.01, 32], ["1000460", "FS", 1.0, 6], ["100126", "FS", 1.0, 6], ["100142", "FS", 1.0, 1], ["100143", "FS", 1.0, 4], ["100144", "FS", 1.0, 32], ["100155", "FS", 1.0, 4], ["100189", "FS", 1.0, 1]], "100128": [["100001", "FFS", 0.01, 3], ["100003", "FFS", 0.06, 2], ["100010", "FS", 1.0, 4], ["100018", "FS", 1.0, 6], ["100019", "FS", 1.0, 1], ["100020", "FS", 1.0, 6], ["100021", "FS", 1.0, 6], ["100028", "FS", 1.0, 9], ["100039", "FS", 1.0, 1], ["100042", "FS", 1.0, 1], ["100044", "FS", 1.0, 1], ["100045", "FS", 1.0, 1], ["100046", "FS", 1.0, 1], ["100047", "FS", 1.0, 1], ["100049", "FS", 1.0, 11], ["100050", "FS", 1.0, 7], ["100051", "FS", 1.0, 1], ["100052", "FS", 1.0, 1], ["100053", "FS", 1.0, 1], ["100054", "FS", 1.0, 11], ["100055", "FS", 1.0, 11], ["100056", "FS", 1.0, 11], ["100057", "FS", 1.0, 11], ["100065", "FS", 1.0, 11], ["100066", "FS", 1.0, 11], ["100067", "FS", 1.0, 11], ["100068", "FS", 1.0, 11], ["100069", "FS", 1.0, 11], ["100072", "FFS", 0.01, 16], ["100073", "FS", 1.0, 7], ["1000340", "FS", 1.0, 6], ["100077", "FS", 1.0, 6], ["100078", "FS", 1.0, 6], ["100079", "FS", 1.0, 6], ["100080", "SS", 0.25, 1], ["100081", "FFS", 0.01, 16], ["100082", "FFS", 0.01, 16], ["1000360", "FFS", 0.01, 16], ["100084", "SS", 0.25, 1], ["100085", "FFS", 0.01, 16], ["100087", "FFS", 0.01, 16], ["100088", "FFS", 0.01, 16], ["100090", "FFS", 0.01, 16], ["100093", "FFS", 0.01, 16], ["100094", "FS", 1.0, 6], ["100096", "FS", 1.0, 11], ["100097", "FS", 1.0, 11], ["100098", "FS", 1.0, 11], ["100099", "FFS", 0.01, 16], ["1000350", "FS", 1.0, 7], ["100101", "FFS", 0.01, 16], ["100102", "FFS", 0.01, 16], ["100104", "FS", 1.0, 7], ["100105", "FS", 1.0, 9], ["100107", "FFS", 0.01, 16], ["1000460", "FFS", 0.01, 9], ["100126", "FFS", 0.01, 9], ["100127", "FS", 1.0, 9], ["100130", "FS", 1.0, 9], ["100142", "FFS", 0.44, 2], ["100144", "FS", 1.0, 9], ["100145", "FS", 1.0, 16], ["100149", "FS", 1.0, 9], ["100159", "FS", 1.0, 1], ["1000540", "FS", 1.0, 16], ["100164", "FS", 1.0, 16], ["100166", "FS", 1.0, 16], ["100167", "FS", 1.0, 16], ["10003300", "FS", 1.0, 16], ["100173", "FS", 1.0, 16], ["100174", "FS", 1.0, 16], ["10003320", "FS", 1.0, 16], ["100182", "FS", 1.0, 16], ["100183", "FS", 1.0, 16], ["10003340", "FS", 1.0, 16], ["100189", "FFS", 0.44, 2], ["100191", "FFS", 0.11, 142], ["100192", "FFS", 0.11, 142]], "100129": [["100001", "FFS", 0.01, 3], ["100003", "FFS", 0.06, 2], ["100010", "FS", 1.0, 4], ["100018", "FS", 1.0, 6], ["100019", "FS", 1.0, 1], ["100020", "FS", 1.0, 6], ["100021", "FS", 1.0, 6], ["100028", "FS", 1.0, 9], ["100039", "FS", 1.0, 1], ["100042", "FS", 1.0, 1], ["100044", "FS", 1.0, 1], ["100045", "FS", 1.0, 1], ["100046", "FS", 1.0, 1], ["100047", "FS", 1.0, 1], ["100049", "FS", 1.0, 11], ["100050", "FS", 1.0, 7], ["100051", "FS", 1.0, 1], ["100052", "FS", 1.0, 1], ["100053", "FS", 1.0, 1], ["100054", "FS", 1.0, 11], ["100055", "FS", 1.0, 11], ["100056", "FS", 1.0, 11], ["100057", "FS", 1.0, 11], ["100065", "FS", 1.0, 11], ["100066", "FS", 1.0, 11], ["100067", "FS", 1.0, 11], ["100068", "FS", 1.0, 11], ["100069", "FS", 1.0, 11], ["100072", "FFS", 0.01, 16], ["100073", "FS", 1.0, 7], ["1000340", "FS", 1.0, 6], ["100077", "FS", 1.0, 6], ["100078", "FS", 1.0, 6], ["100079", "FS", 1.0, 6], ["100080", "SS", 0.25, 1], ["100081", "FFS", 0.01, 16], ["100082", "FFS", 0.01, 16], ["1000360", "FFS", 0.01, 16], ["100084", "SS", 0.25, 1], ["100085", "FFS", 0.01, 16], ["100087", "FFS", 0.01, 16], ["100088", "FFS", 0.01, 16], ["100090", "FFS", 0.01, 16], ["100093", "FFS", 0.01, 16], ["100094", "FS", 1.0, 6], ["100096", "FS", 1.0, 11], ["100097", "FS", 1.0, 11], ["100098", "FS", 1.0, 11], ["100099", "FFS", 0.01, 16], ["1000350", "FS", 1.0, 7], ["100101", "FFS", 0.01, 16], ["100102", "FFS", 0.01, 16], ["100104", "FS", 1.0, 7], ["100105", "FS", 1.0, 9], ["100107", "FFS", 0.01, 16], ["1000460", "FFS", 0.01, 9], ["100126", "FFS", 0.01, 9], ["100127", "FS", 1.0, 9], ["100130", "FS", 1.0, 9], ["100142", "FFS", 0.44, 2], ["100144", "FS", 1.0, 9], ["100145", "FS", 1.0, 16], ["100149", "FS", 1.0, 9], ["100159", "FS", 1.0, 1], ["1000540", "FS", 1.0, 16], ["100164", "FS", 1.0, 16], ["100166", "FS", 1.0, 16], ["100167", "FS", 1.0, 16], ["10003300", "FS", 1.0, 16], ["100173", "FS", 1.0, 16], ["100174", "FS", 1.0, 16], ["10003320", "FS", 1.0, 16], ["100182", "FS", 1.0, 16], ["100183", "FS", 1.0, 16], ["10003340", "FS", 1.0, 16], ["100189", "FFS", 0.44, 2], ["100191", "FFS", 0.11, 142], ["100192", "FFS", 0.11, 142]], "100130": [["100003", "FS", 1.0, 3], ["100018", "FS", 1.0, 1], ["100020", "FS", 1.0, 1], ["100021", "FS", 1.0, 1], ["100028", "FFS", 0.01, 5], ["100039", "FS", 1.0, 1], ["100042", "FS", 1.0, 1], ["100044", "FS", 1.0, 1], ["100045", "FS", 1.0, 1], ["100046", "FS", 1.0, 1], ["100047", "FS", 1.0, 1], ["100049", "FS", 1.0, 1], ["100050", "FS", 1.0, 1], ["100054", "FS", 1.0, 1], ["100055", "FS", 1.0, 1], ["100056", "FS", 1.0, 1], ["100057", "FS", 1.0, 1], ["100065", "FS", 1.0, 1], ["100066", "FS", 1.0, 1], ["100067", "FS", 1.0, 1], ["100068", "FS", 1.0, 1], ["100069", "FS", 1.0, 1], ["100071", "FFS", 0.01, 25], ["100073", "FS", 1.0, 1], ["1000340", "FS", 1.0, 1], ["100077", "FS", 1.0, 1], ["100078", "FS", 1.0, 1], ["100079", "FS", 1.0, 1], ["100089", "FFS", 0.01, 25], ["100094", "FS", 1.0, 1], ["100096", "FS", 1.0, 1], ["100097", "FS", 1.0, 1], ["100098", "FS", 1.0, 1], ["1000350", "FS", 1.0, 1], ["100104", "FS", 1.0, 1], ["100105", "FFS", 0.01, 5], ["100111", "FFS", 0.01, 25], ["100112", "FFS", 0.01, 25], ["1000470", "FFS", 0.01, 25], ["100115", "FFS", 0.01, 25], ["100116", "FFS", 0.01, 25], ["100117", "FFS", 0.01, 25], ["100118", "FFS", 0.01, 25], ["100119", "FFS", 0.01, 25], ["100120", "FFS", 0.01, 25], ["100121", "FFS", 0.01, 25], ["100122", "FFS", 0.01, 25], ["100123", "FFS", 0.01, 25], ["100127", "FS", 1.0, 6], ["100139", "FS", 1.0, 25], ["100143", "FS", 1.0, 3], ["100144", "FS", 1.0, 5], ["100146", "FS", 1.0, 25], ["100147", "FS", 1.0, 25], ["100150", "FS", 1.0, 25], ["100152", "FS", 1.0, 25], ["100154", "FS", 1.0, 25], ["100155", "FS", 1.0, 3], ["100159", "FS", 1.0, 1], ["100191", "FFS", 0.94, 35], ["100192", "FFS", 0.94, 35]], "1000530": [["100001", "FFS", 0.01, 3], ["100003", "FFS", 0.06, 2], ["100010", "FS", 1.0, 4], ["100018", "FS", 1.0, 6], ["100019", "FS", 1.0, 1], ["100020", "FS", 1.0, 6], ["100021", "FS", 1.0, 6], ["100028", "FS", 1.0, 9], ["100039", "FS", 1.0, 1], ["100042", "FS", 1.0, 1], ["100044", "FS", 1.0, 1], ["100045", "FS", 1.0, 1], ["100046", "FS", 1.0, 1], ["100047", "FS", 1.0, 1], ["100049", "FS", 1.0, 11], ["100050", "FS", 1.0, 7], ["100051", "FS", 1.0, 1], ["100052", "FS", 1.0, 1], ["100053", "FS", 1.0, 1], ["100054", "FS", 1.0, 11], ["100055", "FS", 1.0, 11], ["100056", "FS", 1.0, 11], ["100057", "FS", 1.0, 11], ["100065", "FS", 1.0, 11], ["100066", "FS", 1.0, 11], ["100067", "FS", 1.0, 11], ["100068", "FS", 1.0, 11], ["100069", "FS", 1.0, 11], ["100072", "FFS", 0.01, 16], ["100073", "FS", 1.0, 7], ["1000340", "FS", 1.0, 6], ["100077", "FS", 1.0, 6], ["100078", "FS", 1.0, 6], ["100079", "FS", 1.0, 6], ["100080", "SS", 0.25, 1], ["100081", "FFS", 0.01, 16], ["100082", "FFS", 0.01, 16], ["1000360", "FFS", 0.01, 16], ["100084", "SS", 0.25, 1], ["100085", "FFS", 0.01, 16], ["100087", "FFS", 0.01, 16], ["100088", "FFS", 0.01, 16], ["100090", "FFS", 0.01, 16], ["100093", "FFS", 0.01, 16], ["100094", "FS", 1.0, 6], ["100096", "FS", 1.0, 11], ["100097", "FS", 1.0, 11], ["100098", "FS", 1.0, 11], ["100099", "FFS", 0.01, 16], ["1000350", "FS", 1.0, 7], ["100101", "FFS", 0.01, 16], ["100102", "FFS", 0.01, 16], ["100104", "FS", 1.0, 7], ["100105", "FS", 1.0, 9], ["100107", "FFS", 0.01, 16], ["1000460", "FFS", 0.01, 9], ["100126", "FFS", 0.01, 9], ["100127", "FS", 1.0, 9], ["100130", "FFS", 0.01, 9], ["100142", "FFS", 0.44, 2], ["100144", "FS", 1.0, 9], ["100145", "FS", 1.0, 16], ["100149", "FS", 1.0, 9], ["100159", "FS", 1.0, 1], ["1000540", "FS", 1.0, 16], ["100164", "FS", 1.0, 16], ["100166", "FS", 1.0, 16], ["100167", "FS", 1.0, 16], ["10003300", "FS", 1.0, 16], ["100173", "FS", 1.0, 16], ["100174", "FS", 1.0, 16], ["10003320", "FS", 1.0, 16], ["100182", "FS", 1.0, 16], ["100183", "FS", 1.0, 16], ["10003340", "FS", 1.0, 16], ["100189", "FFS", 0.44, 2], ["100191", "FFS", 0.11, 142], ["100192", "FFS", 0.11, 142]], "100132": [["100001", "FFS", 0.01, 3], ["100003", "FFS", 0.06, 2], ["100010", "FS", 1.0, 4], ["100018", "FS", 1.0, 6], ["100019", "FS", 1.0, 1], ["100020", "FS", 1.0, 6], ["100021", "FS", 1.0, 6], ["100028", "FS", 1.0, 9], ["100039", "FS", 1.0, 1], ["100042", "FS", 1.0, 1], ["100044", "FS", 1.0, 1], ["100045", "FS", 1.0, 1], ["100046", "FS", 1.0, 1], ["100047", "FS", 1.0, 1], ["100049", "FS", 1.0, 11], ["100050", "FS", 1.0, 7], ["100051", "FS", 1.0, 1], ["100052", "FS", 1.0, 1], ["100053", "FS", 1.0, 1], ["100054", "FS", 1.0, 11], ["100055", "FS", 1.0, 11], ["100056", "FS", 1.0, 11], ["100057", "FS", 1.0, 11], ["100065", "FS", 1.0, 11], ["100066", "FS", 1.0, 11], ["100067", "FS", 1.0, 11], ["100068", "FS", 1.0, 11], ["100069", "FS", 1.0, 11], ["100072", "FFS", 0.01, 16], ["100073", "FS", 1.0, 7], ["1000340", "FS", 1.0, 6], ["100077", "FS", 1.0, 6], ["100078", "FS", 1.0, 6], ["100079", "FS", 1.0, 6], ["100080", "SS", 0.25, 1], ["100081", "FFS", 0.01, 16], ["100082", "FFS", 0.01, 16], ["1000360", "FFS", 0.01, 16], ["100084", "SS", 0.25, 1], ["100085", "FFS", 0.01, 16], ["100087", "FFS", 0.01, 16], ["100088", "FFS", 0.01, 16], ["100090", "FFS", 0.01, 16], ["100093", "FFS", 0.01, 16], ["100094", "FS", 1.0, 6], ["100096", "FS", 1.0, 11], ["100097", "FS", 1.0, 11], ["100098", "FS", 1.0, 11], ["100099", "FFS", 0.01, 16], ["1000350", "FS", 1.0, 7], ["100101", "FFS", 0.01, 16], ["100102", "FFS", 0.01, 16], ["100104", "FS", 1.0, 7], ["100105", "FS", 1.0, 9], ["100107", "FFS", 0.01, 16], ["1000460", "FFS", 0.01, 9], ["100126", "FFS", 0.01, 9], ["100127", "FS", 1.0, 9], ["100130", "FFS", 0.01, 9], ["100142", "FFS", 0.44, 2], ["100144", "FS", 1.0, 9], ["100145", "FS", 1.0, 16], ["100149", "FS", 1.0, 9], ["100159", "FS", 1.0, 1], ["1000540", "FS", 1.0, 16], ["100164", "FS", 1.0, 16], ["100166", "FS", 1.0, 16], ["100167", "FS", 1.0, 16], ["10003300", "FS", 1.0, 16], ["100173", "FS", 1.0, 16], ["100174", "FS", 1.0, 16], ["10003320", "FS", 1.0, 16], ["100182", "FS", 1.0, 16], ["100183", "FS", 1.0, 16], ["10003340", "FS", 1.0, 16], ["100189", "FFS", 0.44, 2], ["100191", "FFS", 0.11, 142], ["100192", "FFS", 0.11, 142]], "100133": [["100001", "FFS", 0.01, 3], ["100003", "FFS", 0.06, 2], ["100010", "FS", 1.0, 4], ["100018", "FS", 1.0, 6], ["100019", "FS", 1.0, 1], ["100020", "FS", 1.0, 6], ["100021", "FS", 1.0, 6], ["100028", "FS", 1.0, 9], ["100039", "FS", 1.0, 1], ["100042", "FS", 1.0, 1], ["100044", "FS", 1.0, 1], ["100045", "FS", 1.0, 1], ["100046", "FS", 1.0, 1], ["100047", "FS", 1.0, 1], ["100049", "FS", 1.0, 11], ["100050", "FS", 1.0, 7], ["100051", "FS", 1.0, 1], ["100052", "FS", 1.0, 1], ["100053", "FS", 1.0, 1], ["100054", "FS", 1.0, 11], ["100055", "FS", 1.0, 11], ["100056", "FS", 1.0, 11], ["100057", "FS", 1.0, 11], ["100065", "FS", 1.0, 11], ["100066", "FS", 1.0, 11], ["100067", "FS", 1.0, 11], ["100068", "FS", 1.0, 11], ["100069", "FS", 1.0, 11], ["100072", "FFS", 0.01, 16], ["100073", "FS", 1.0, 7], ["1000340", "FS", 1.0, 6], ["100077", "FS", 1.0, 6], ["100078", "FS", 1.0, 6], ["100079", "FS", 1.0, 6], ["100080", "SS", 0.25, 1], ["100081", "FFS", 0.01, 16], ["100082", "FFS", 0.01, 16], ["1000360", "FFS", 0.01, 16], ["100084", "SS", 0.25, 1], ["100085", "FFS", 0.01, 16], ["100087", "FFS", 0.01, 16], ["100088", "FFS", 0.01, 16], ["100090", "FFS", 0.01, 16], ["100093", "FFS", 0.01, 16], ["100094", "FS", 1.0, 6], ["100096", "FS", 1.0, 11], ["100097", "FS", 1.0, 11], ["100098", "FS", 1.0, 11], ["100099", "FFS", 0.01, 16], ["1000350", "FS", 1.0, 7], ["100101", "FFS", 0.01, 16], ["100102", "FFS", 0.01, 16], ["100104", "FS", 1.0, 7], ["100105", "FS", 1.0, 9], ["100107", "FFS", 0.01, 16], ["1000460", "FFS", 0.01, 9], ["100126", "FFS", 0.01, 9], ["100127", "FS", 1.0, 9], ["100130", "FFS", 0.01, 9], ["100142", "FFS", 0.44, 2], ["100144", "FS", 1.0, 9], ["100145", "FS", 1.0, 16], ["100149", "FS", 1.0, 9], ["100159", "FS", 1.0, 1], ["1000540", "FS", 1.0, 16], ["100164", "FS", 1.0, 16], ["100166", "FS", 1.0, 16], ["100167", "FS", 1.0, 16], ["10003300", "FS", 1.0, 16], ["100173", "FS", 1.0, 16], ["100174", "FS", 1.0, 16], ["10003320", "FS", 1.0, 16], ["100182", "FS", 1.0, 16], ["100183", "FS", 1.0, 16], ["10003340", "FS", 1.0, 16], ["100189", "FFS", 0.44, 2], ["100191", "FFS", 0.11, 142], ["100192", "FFS", 0.11, 142]], "100134": [["100001", "FFS", 0.01, 3], ["100003", "FFS", 0.06, 2], ["100010", "FS", 1.0, 4], ["100018", "FS", 1.0, 6], ["100019", "FS", 1.0, 1], ["100020", "FS", 1.0, 6], ["100021", "FS", 1.0, 6], ["100028", "FS", 1.0, 9], ["100039", "FS", 1.0, 1], ["100042", "FS", 1.0, 1], ["100044", "FS", 1.0, 1], ["100045", "FS", 1.0, 1], ["100046", "FS", 1.0, 1], ["100047", "FS", 1.0, 1], ["100049", "FS", 1.0, 11], ["100050", "FS", 1.0, 7], ["100051", "FS", 1.0, 1], ["100052", "FS", 1.0, 1], ["100053", "FS", 1.0, 1], ["100054", "FS", 1.0, 11], ["100055", "FS", 1.0, 11], ["100056", "FS", 1.0, 11], ["100057", "FS", 1.0, 11], ["100065", "FS", 1.0, 11], ["100066", "FS", 1.0, 11], ["100067", "FS", 1.0, 11], ["100068", "FS", 1.0, 11], ["100069", "FS", 1.0, 11], ["100072", "FFS", 0.01, 16], ["100073", "FS", 1.0, 7], ["1000340", "FS", 1.0, 6], ["100077", "FS", 1.0, 6], ["100078", "FS", 1.0, 6], ["100079", "FS", 1.0, 6], ["100080", "SS", 0.25, 1], ["100081", "FFS", 0.01, 16], ["100082", "FFS", 0.01, 16], ["1000360", "FFS", 0.01, 16], ["100084", "SS", 0.25, 1], ["100085", "FFS", 0.01, 16], ["100087", "FFS", 0.01, 16], ["100088", "FFS", 0.01, 16], ["100090", "FFS", 0.01, 16], ["100093", "FFS", 0.01, 16], ["100094", "FS", 1.0, 6], ["100096", "FS", 1.0, 11], ["100097", "FS", 1.0, 11], ["100098", "FS", 1.0, 11], ["100099", "FFS", 0.01, 16], ["1000350", "FS", 1.0, 7], ["100101", "FFS", 0.01, 16], ["100102", "FFS", 0.01, 16], ["100104", "FS", 1.0, 7], ["100105", "FS", 1.0, 9], ["100107", "FFS", 0.01, 16], ["1000460", "FFS", 0.01, 9], ["100126", "FFS", 0.01, 9], ["100127", "FS", 1.0, 9], ["100130", "FFS", 0.01, 9], ["100142", "FFS", 0.44, 2], ["100144", "FS", 1.0, 9], ["100145", "FS", 1.0, 16], ["100149", "FS", 1.0, 9], ["100159", "FS", 1.0, 1], ["1000540", "FS", 1.0, 16], ["100164", "FS", 1.0, 16], ["100166", "FS", 1.0, 16], ["100167", "FS", 1.0, 16], ["10003300", "FS", 1.0, 16], ["100173", "FS", 1.0, 16], ["100174", "FS", 1.0, 16], ["10003320", "FS", 1.0, 16], ["100182", "FS", 1.0, 16], ["100183", "FS", 1.0, 16], ["10003340", "FS", 1.0, 16], ["100189", "FFS", 0.44, 2], ["100191", "FFS", 0.11, 142], ["100192", "FFS", 0.11, 142]], "100136": [], "100156": [], "100137": [["100071", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 2], ["100111", "FFS", 0.01, 2], ["100112", "FFS", 0.01, 2], ["1000470", "FFS", 0.01, 2], ["100115", "FFS", 0.01, 2], ["100116", "FFS", 0.01, 2], ["100117", "FFS", 0.01, 2], ["100118", "FFS", 0.01, 2], ["100119", "FFS", 0.01, 2], ["100120", "FFS", 0.01, 2], ["100121", "FFS", 0.01, 2], ["100122", "FFS", 0.01, 2], ["100123", "FFS", 0.01, 2], ["1000460", "FFS", 0.01, 1], ["100126", "FFS", 0.01, 1], ["100130", "FFS", 0.01, 1], ["100139", "FS", 1.0, 2], ["100146", "FS", 1.0, 2], ["100147", "FS", 1.0, 2], ["100150", "FS", 1.0, 2], ["100152", "FS", 1.0, 2], ["100154", "FS", 1.0, 2], ["100191", "FS", 1.0, 1], ["100192", "FS", 1.0, 1]], "100138": [["100071", "FS", 1.0, 1], ["100089", "FS", 1.0, 1], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100137", "FS", 1.0, 1], ["100139", "FS", 1.0, 1], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1]], "100139": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.01, 36], ["100127", "FFS", 0.01, 43], ["100128", "FFS", 0.01, 36], ["100129", "FFS", 0.01, 36], ["1000530", "FFS", 0.01, 36], ["100132", "FFS", 0.01, 36], ["100133", "FFS", 0.01, 36], ["100134", "FFS", 0.01, 36], ["100144", "FS", 1.0, 60]], "100140": [["100028", "FS", 1.0, 1], ["100071", "FS", 1.0, 2], ["100072", "FS", 1.0, 1], ["100081", "FS", 1.0, 1], ["100082", "FS", 1.0, 1], ["1000360", "FS", 1.0, 1], ["100085", "FS", 1.0, 1], ["100087", "FS", 1.0, 1], ["100088", "FS", 1.0, 1], ["100089", "FS", 1.0, 2], ["100090", "FS", 1.0, 1], ["100093", "FS", 1.0, 1], ["100099", "FS", 1.0, 1], ["100101", "FS", 1.0, 1], ["100102", "FS", 1.0, 1], ["100105", "FS", 1.0, 1], ["100107", "FS", 1.0, 1], ["100111", "FS", 1.0, 2], ["100112", "FS", 1.0, 2], ["1000470", "FS", 1.0, 2], ["100115", "FS", 1.0, 2], ["100116", "FS", 1.0, 2], ["100117", "FS", 1.0, 2], ["100118", "FS", 1.0, 2], ["100119", "FS", 1.0, 2], ["100120", "FS", 1.0, 2], ["100121", "FS", 1.0, 2], ["100122", "FS", 1.0, 2], ["100123", "FS", 1.0, 2], ["100137", "FS", 1.0, 1], ["100138", "FFS", 0.57, 1], ["100139", "FS", 1.0, 2], ["100142", "FS", 1.0, 1], ["100143", "FS", 1.0, 1], ["100144", "FS", 1.0, 1], ["100145", "FS", 1.0, 1], ["100146", "FS", 1.0, 2], ["100147", "FS", 1.0, 2], ["100150", "FS", 1.0, 2], ["100151", "FS", 1.0, 1], ["100152", "FS", 1.0, 2], ["100154", "FS", 1.0, 2], ["100155", "FS", 1.0, 1], ["1000540", "FS", 1.0, 1], ["100164", "FS", 1.0, 1], ["100166", "FS", 1.0, 1], ["100167", "FS", 1.0, 1], ["10003300", "FS", 1.0, 1], ["100173", "FS", 1.0, 1], ["100174", "FS", 1.0, 1], ["10003320", "FS", 1.0, 1], ["100182", "FS", 1.0, 1], ["100183", "FS", 1.0, 1], ["10003340", "FS", 1.0, 1], ["100189", "FS", 1.0, 1], ["100191", "FS", 1.0, 1], ["100192", "FS", 1.0, 1]], "100141": [["100071", "FS", 1.0, 3], ["100089", "FS", 1.0, 3], ["100111", "FS", 1.0, 3], ["100112", "FS", 1.0, 3], ["1000470", "FS", 1.0, 3], ["100115", "FS", 1.0, 3], ["100116", "FS", 1.0, 3], ["100117", "FS", 1.0, 3], ["100118", "FS", 1.0, 3], ["100119", "FS", 1.0, 3], ["100120", "FS", 1.0, 3], ["100121", "FS", 1.0, 3], ["100122", "FS", 1.0, 3], ["100123", "FS", 1.0, 3], ["100137", "FS", 1.0, 1], ["100138", "FS", 1.0, 1], ["100139", "FS", 1.0, 3], ["100140", "SS", 0.63, 2], ["100142", "FS", 1.0, 2], ["100143", "FS", 1.0, 3], ["100146", "FS", 1.0, 3], ["100147", "FS", 1.0, 3], ["100150", "FS", 1.0, 3], ["100151", "FS", 1.0, 2], ["100152", "FS", 1.0, 3], ["100154", "FS", 1.0, 3], ["100155", "FS", 1.0, 3], ["100189", "FS", 1.0, 2], ["100191", "FFS", 0.14, 3], ["100192", "FFS", 0.14, 3]], "100142": [["100071", "FFS", 0.01, 4], ["100072", "FFS", 0.01, 5], ["100081", "FFS", 0.01, 5], ["100082", "FFS", 0.01, 5], ["1000360", "FFS", 0.01, 5], ["100085", "FFS", 0.01, 5], ["100087", "FFS", 0.01, 5], ["100088", "FFS", 0.01, 5], ["100089", "FFS", 0.01, 4], ["100090", "FFS", 0.01, 5], ["100093", "FFS", 0.01, 5], ["100099", "FFS", 0.01, 5], ["100101", "FFS", 0.01, 5], ["100102", "FFS", 0.01, 5], ["100107", "FFS", 0.01, 5], ["100111", "FFS", 0.01, 4], ["100112", "FFS", 0.01, 4], ["1000470", "FFS", 0.01, 4], ["100115", "FFS", 0.01, 4], ["100116", "FFS", 0.01, 4], ["100117", "FFS", 0.01, 4], ["100118", "FFS", 0.01, 4], ["100119", "FFS", 0.01, 4], ["100120", "FFS", 0.01, 4], ["100121", "FFS", 0.01, 4], ["100122", "FFS", 0.01, 4], ["100123", "FFS", 0.01, 4], ["1000460", "FFS", 0.01, 2], ["100126", "FFS", 0.01, 2], ["100130", "FFS", 0.01, 2], ["100139", "FFS", 0.01, 4], ["100143", "FS", 1.0, 3], ["100146", "FS", 1.0, 4], ["100147", "FS", 1.0, 4], ["100149", "SS", 0.33, 2], ["100150", "FS", 1.0, 4], ["100151", "FS", 1.0, 2], ["100152", "FS", 1.0, 4], ["100154", "FS", 1.0, 4], ["100155", "FS", 1.0, 3]], "100143": [["100018", "FS", 1.0, 2], ["100020", "FS", 1.0, 2], ["100021", "FS", 1.0, 2], ["100049", "FS", 1.0, 2], ["100054", "FS", 1.0, 2], ["100055", "FS", 1.0, 2], ["100056", "FS", 1.0, 2], ["100057", "FS", 1.0, 2], ["100065", "FS", 1.0, 2], ["100066", "FS", 1.0, 2], ["100067", "FS", 1.0, 2], ["100068", "FS", 1.0, 2], ["100069", "FS", 1.0, 2], ["100071", "FFS", 0.17, 19], ["100072", "FFS", 0.01, 13], ["1000340", "FS", 1.0, 2], ["100077", "FS", 1.0, 2], ["100078", "FS", 1.0, 2], ["100079", "FS", 1.0, 2], ["100081", "FFS", 0.01, 13], ["100082", "FFS", 0.01, 13], ["1000360", "FFS", 0.01, 13], ["100085", "FFS", 0.01, 13], ["100087", "FFS", 0.01, 13], ["100088", "FFS", 0.01, 13], ["100089", "FFS", 0.17, 19], ["100090", "FFS", 0.01, 13], ["100093", "FFS", 0.01, 13], ["100094", "FS", 1.0, 2], ["100096", "FS", 1.0, 2], ["100097", "FS", 1.0, 2], ["100098", "FS", 1.0, 2], ["100099", "FFS", 0.01, 13], ["100101", "FFS", 0.01, 13], ["100102", "FFS", 0.01, 13], ["100107", "FFS", 0.01, 13], ["100111", "FFS", 0.17, 19], ["100112", "FFS", 0.17, 19], ["1000470", "FFS", 0.17, 19], ["100115", "FFS", 0.17, 19], ["100116", "FFS", 0.17, 19], ["100117", "FFS", 0.17, 19], ["100118", "FFS", 0.17, 19], ["100119", "FFS", 0.17, 19], ["100120", "FFS", 0.17, 19], ["100121", "FFS", 0.17, 19], ["100122", "FFS", 0.17, 19], ["100123", "FFS", 0.17, 19], ["100139", "FFS", 0.17, 19], ["100146", "FFS", 0.17, 19], ["100147", "FFS", 0.17, 19], ["100148", "FS", 1.0, 2], ["100150", "FFS", 0.17, 19], ["100151", "FS", 1.0, 3], ["100152", "FFS", 0.17, 19], ["100153", "FS", 1.0, 1], ["100154", "FFS", 0.17, 19]], "100144": [["100001", "FFS", 0.01, 32], ["100002", "FS", 1.0, 5], ["100003", "FFS", 0.01, 34], ["100005", "FS", 1.0, 14], ["100006", "FS", 1.0, 14], ["100012", "FS", 1.0, 4], ["100013", "SS", 0.81, 4], ["100014", "FS", 1.0, 4], ["100015", "SS", 0.81, 4], ["100026", "FFS", 0.62, 3], ["100029", "FFS", 0.62, 3], ["100030", "FFS", 0.62, 3], ["100033", "FFS", 0.33, 2], ["100035", "FFS", 0.01, 14], ["100036", "FFS", 0.01, 14], ["100050", "FFS", 0.01, 28], ["100073", "FFS", 0.01, 28], ["1000350", "FFS", 0.01, 28], ["100104", "FFS", 0.01, 28], ["100141", "FS", 1.0, 1], ["100142", "SS", 0.66, 2], ["100143", "FFS", 0.01, 8], ["100155", "FFS", 0.57, 8], ["100158", "FFS", 0.33, 2], ["100160", "FFS", 0.33, 2], ["100168", "FFS", 0.33, 2], ["100169", "FFS", 0.33, 2], ["100175", "FFS", 0.33, 2], ["100176", "FFS", 0.33, 2], ["100178", "FFS", 0.33, 2], ["100181", "FFS", 0.33, 2], ["100184", "FFS", 0.33, 2], ["1000560", "FFS", 0.33, 2], ["100189", "SS", 0.66, 2]], "100145": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 20], ["100096", "FFS", 0.01, 102], ["100097", "FFS", 0.01, 102], ["100098", "FFS", 0.01, 102], ["1000350", "FFS", 0.01, 22], ["100104", "FFS", 0.01, 22], ["100105", "FFS", 0.01, 37], ["100111", "FFS", 0.01, 60], ["100112", "FFS", 0.01, 60], ["1000470", "FFS", 0.01, 60], ["100115", "FFS", 0.01, 60], ["100116", "FFS", 0.01, 60], ["100117", "FFS", 0.01, 60], ["100118", "FFS", 0.01, 60], ["100119", "FFS", 0.01, 60], ["100120", "FFS", 0.01, 60], ["100121", "FFS", 0.01, 60], ["100122", "FFS", 0.01, 60], ["100123", "FFS", 0.01, 60], ["1000460", "FFS", 0.01, 18], ["100126", "FFS", 0.01, 18], ["100127", "FFS", 0.01, 48], ["100130", "FFS", 0.01, 18], ["100139", "FFS", 0.01, 60], ["100141", "FS", 1.0, 1], ["100142", "FFS", 0.01, 5], ["100143", "FFS", 0.01, 13], ["100144", "FFS", 0.01, 37], ["100148", "FS", 1.0, 2], ["100149", "FS", 1.0, 18], ["100153", "FS", 1.0, 1], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100146": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.01, 36], ["100127", "FFS", 0.01, 43], ["100128", "FFS", 0.01, 36], ["100129", "FFS", 0.01, 36], ["1000530", "FFS", 0.01, 36], ["100132", "FFS", 0.01, 36], ["100133", "FFS", 0.01, 36], ["100134", "FFS", 0.01, 36], ["100144", "FFS", 0.01, 60], ["100145", "FFS", 0.01, 60]], "100147": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.01, 36], ["100127", "FFS", 0.01, 43], ["100128", "FFS", 0.01, 36], ["100129", "FFS", 0.01, 36], ["1000530", "FFS", 0.01, 36], ["100132", "FFS", 0.01, 36], ["100133", "FFS", 0.01, 36], ["100134", "FFS", 0.01, 36], ["100144", "FFS", 0.01, 60], ["100145", "FFS", 0.01, 60]], "100148": [["100018", "FS", 1.0, 1], ["100020", "FS", 1.0, 1], ["100021", "FS", 1.0, 1], ["100028", "FFS", 0.01, 3], ["100039", "FS", 1.0, 1], ["100042", "FS", 1.0, 1], ["100044", "FS", 1.0, 1], ["100045", "FS", 1.0, 1], ["100046", "FS", 1.0, 1], ["100047", "FS", 1.0, 1], ["100071", "FFS", 0.01, 6], ["1000340", "FS", 1.0, 1], ["100077", "FS", 1.0, 1], ["100078", "FS", 1.0, 1], ["100079", "FS", 1.0, 1], ["100089", "FFS", 0.01, 6], ["100094", "FS", 1.0, 1], ["100105", "FFS", 0.01, 3], ["100111", "FFS", 0.01, 6], ["100112", "FFS", 0.01, 6], ["1000470", "FFS", 0.01, 6], ["100115", "FFS", 0.01, 6], ["100116", "FFS", 0.01, 6], ["100117", "FFS", 0.01, 6], ["100118", "FFS", 0.01, 6], ["100119", "FFS", 0.01, 6], ["100120", "FFS", 0.01, 6], ["100121", "FFS", 0.01, 6], ["100122", "FFS", 0.01, 6], ["100123", "FFS", 0.01, 6], ["1000460", "FFS", 0.01, 5], ["100126", "FFS", 0.01, 5], ["100127", "FS", 1.0, 1], ["100130", "FFS", 0.01, 5], ["100137", "FFS", 0.01, 1], ["100139", "FFS", 0.01, 6], ["100144", "FFS", 0.01, 3], ["100146", "FFS", 0.01, 6], ["100147", "FFS", 0.01, 6], ["100150", "FS", 1.0, 6], ["100152", "FS", 1.0, 6], ["100154", "FS", 1.0, 6]], "100149": [["100003", "FS", 1.0, 3], ["100018", "FS", 1.0, 1], ["100020", "FS", 1.0, 1], ["100021", "FS", 1.0, 1], ["100028", "FFS", 0.01, 5], ["100039", "FS", 1.0, 1], ["100042", "FS", 1.0, 1], ["100044", "FS", 1.0, 1], ["100045", "FS", 1.0, 1], ["100046", "FS", 1.0, 1], ["100047", "FS", 1.0, 1], ["100049", "FS", 1.0, 1], ["100050", "FS", 1.0, 1], ["100054", "FS", 1.0, 1], ["100055", "FS", 1.0, 1], ["100056", "FS", 1.0, 1], ["100057", "FS", 1.0, 1], ["100065", "FS", 1.0, 1], ["100066", "FS", 1.0, 1], ["100067", "FS", 1.0, 1], ["100068", "FS", 1.0, 1], ["100069", "FS", 1.0, 1], ["100071", "FFS", 0.01, 25], ["100073", "FS", 1.0, 1], ["1000340", "FS", 1.0, 1], ["100077", "FS", 1.0, 1], ["100078", "FS", 1.0, 1], ["100079", "FS", 1.0, 1], ["100089", "FFS", 0.01, 25], ["100094", "FS", 1.0, 1], ["100096", "FS", 1.0, 1], ["100097", "FS", 1.0, 1], ["100098", "FS", 1.0, 1], ["1000350", "FS", 1.0, 1], ["100104", "FS", 1.0, 1], ["100105", "FFS", 0.01, 5], ["100111", "FFS", 0.01, 25], ["100112", "FFS", 0.01, 25], ["1000470", "FFS", 0.01, 25], ["100115", "FFS", 0.01, 25], ["100116", "FFS", 0.01, 25], ["100117", "FFS", 0.01, 25], ["100118", "FFS", 0.01, 25], ["100119", "FFS", 0.01, 25], ["100120", "FFS", 0.01, 25], ["100121", "FFS", 0.01, 25], ["100122", "FFS", 0.01, 25], ["100123", "FFS", 0.01, 25], ["100127", "FS", 1.0, 6], ["100137", "FFS", 0.01, 1], ["100139", "FFS", 0.01, 25], ["100143", "FS", 1.0, 3], ["100144", "FFS", 0.01, 5], ["100146", "FFS", 0.01, 25], ["100147", "FFS", 0.01, 25], ["100148", "FFS", 0.01, 5], ["100150", "FS", 1.0, 25], ["100152", "FS", 1.0, 25], ["100154", "FS", 1.0, 25], ["100155", "FS", 1.0, 3], ["100159", "FS", 1.0, 1], ["100191", "FFS", 0.94, 35], ["100192", "FFS", 0.94, 35]], "100150": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.01, 36], ["100127", "FFS", 0.01, 43], ["100128", "FFS", 0.01, 36], ["100129", "FFS", 0.01, 36], ["1000530", "FFS", 0.01, 36], ["100132", "FFS", 0.01, 36], ["100133", "FFS", 0.01, 36], ["100134", "FFS", 0.01, 36], ["100144", "FFS", 0.01, 60], ["100145", "FFS", 0.01, 60]], "100151": [["100028", "FFS", 0.01, 3], ["100049", "FS", 1.0, 2], ["100054", "FS", 1.0, 2], ["100055", "FS", 1.0, 2], ["100056", "FS", 1.0, 2], ["100057", "FS", 1.0, 2], ["100065", "FS", 1.0, 2], ["100066", "FS", 1.0, 2], ["100067", "FS", 1.0, 2], ["100068", "FS", 1.0, 2], ["100069", "FS", 1.0, 2], ["100071", "FFS", 0.01, 5], ["100072", "FFS", 0.01, 3], ["100081", "FFS", 0.01, 3], ["100082", "FFS", 0.01, 3], ["1000360", "FFS", 0.01, 3], ["100085", "FFS", 0.01, 3], ["100087", "FFS", 0.01, 3], ["100088", "FFS", 0.01, 3], ["100089", "FFS", 0.01, 5], ["100090", "FFS", 0.01, 3], ["100093", "FFS", 0.01, 3], ["100096", "FS", 1.0, 2], ["100097", "FS", 1.0, 2], ["100098", "FS", 1.0, 2], ["100099", "FFS", 0.01, 3], ["100101", "FFS", 0.01, 3], ["100102", "FFS", 0.01, 3], ["100105", "FFS", 0.01, 3], ["100107", "FFS", 0.01, 3], ["100111", "FFS", 0.01, 5], ["100112", "FFS", 0.01, 5], ["1000470", "FFS", 0.01, 5], ["100115", "FFS", 0.01, 5], ["100116", "FFS", 0.01, 5], ["100117", "FFS", 0.01, 5], ["100118", "FFS", 0.01, 5], ["100119", "FFS", 0.01, 5], ["100120", "FFS", 0.01, 5], ["100121", "FFS", 0.01, 5], ["100122", "FFS", 0.01, 5], ["100123", "FFS", 0.01, 5], ["1000460", "FFS", 0.01, 2], ["100126", "FFS", 0.01, 2], ["100130", "FFS", 0.01, 2], ["100139", "FFS", 0.01, 5], ["100144", "FFS", 0.01, 3], ["100145", "FFS", 0.01, 3], ["100146", "FFS", 0.01, 5], ["100147", "FFS", 0.01, 5], ["100148", "FFS", 0.01, 2], ["100149", "FFS", 0.01, 2], ["100150", "FFS", 0.01, 5], ["100152", "FFS", 0.96, 5], ["100153", "FS", 1.0, 1], ["100154", "FFS", 0.96, 5], ["100191", "FS", 1.0, 2], ["100192", "FS", 1.0, 2]], "100152": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.01, 36], ["100127", "FFS", 0.01, 43], ["100128", "FFS", 0.01, 36], ["100129", "FFS", 0.01, 36], ["1000530", "FFS", 0.01, 36], ["100132", "FFS", 0.01, 36], ["100133", "FFS", 0.01, 36], ["100134", "FFS", 0.01, 36], ["100144", "FFS", 0.01, 60], ["100145", "FFS", 0.01, 60]], "100153": [["100028", "FFS", 0.01, 1], ["100071", "SS", 0.96, 1], ["100089", "SS", 0.96, 1], ["100105", "FFS", 0.01, 1], ["100111", "SS", 0.96, 1], ["100112", "SS", 0.96, 1], ["1000470", "SS", 0.96, 1], ["100115", "SS", 0.96, 1], ["100116", "SS", 0.96, 1], ["100117", "SS", 0.96, 1], ["100118", "SS", 0.96, 1], ["100119", "SS", 0.96, 1], ["100120", "SS", 0.96, 1], ["100121", "SS", 0.96, 1], ["100122", "SS", 0.96, 1], ["100123", "SS", 0.96, 1], ["1000460", "FFS", 0.01, 1], ["100126", "FFS", 0.01, 1], ["100130", "FFS", 0.01, 1], ["100139", "SS", 0.96, 1], ["100144", "FFS", 0.01, 1], ["100146", "SS", 0.96, 1], ["100147", "SS", 0.96, 1], ["100148", "FFS", 0.01, 1], ["100149", "FFS", 0.01, 1], ["100150", "SS", 0.96, 1], ["100152", "SS", 0.96, 1], ["100154", "SS", 0.96, 1]], "100154": [["100001", "FFS", 0.17, 33], ["100003", "FFS", 0.01, 34], ["100004", "FS", 1.0, 7], ["100005", "FS", 1.0, 11], ["100006", "FS", 1.0, 11], ["100010", "FFS", 0.01, 42], ["100012", "FS", 1.0, 4], ["100014", "FS", 1.0, 4], ["100018", "FFS", 0.01, 23], ["100019", "FFS", 0.01, 6], ["100020", "FFS", 0.01, 23], ["100021", "FFS", 0.01, 23], ["100028", "FFS", 0.01, 60], ["100035", "FFS", 0.01, 9], ["100036", "FFS", 0.01, 9], ["100039", "FFS", 0.67, 6], ["100042", "FFS", 0.67, 6], ["100044", "FFS", 0.67, 6], ["100045", "FFS", 0.67, 6], ["100046", "FFS", 0.67, 6], ["100047", "FFS", 0.67, 6], ["100049", "FFS", 0.01, 57], ["100050", "FFS", 0.25, 47], ["100051", "FFS", 0.01, 4], ["100052", "FFS", 0.01, 4], ["100053", "FFS", 0.01, 4], ["100054", "FFS", 0.01, 57], ["100055", "FFS", 0.01, 57], ["100056", "FFS", 0.01, 57], ["100057", "FFS", 0.01, 57], ["100058", "FFS", 0.82, 1], ["100059", "FFS", 0.82, 1], ["100060", "FFS", 0.82, 1], ["100061", "FFS", 0.82, 1], ["100062", "FFS", 0.82, 1], ["100063", "FFS", 0.93, 1], ["100064", "FFS", 0.82, 1], ["100065", "FFS", 0.01, 57], ["100066", "FFS", 0.01, 57], ["100067", "FFS", 0.01, 57], ["100068", "FFS", 0.01, 57], ["100069", "FFS", 0.01, 57], ["100072", "FFS", 0.01, 60], ["100073", "FFS", 0.25, 47], ["1000340", "FFS", 0.01, 23], ["100077", "FFS", 0.01, 23], ["100078", "FFS", 0.01, 23], ["100079", "FFS", 0.01, 23], ["100081", "FFS", 0.01, 60], ["100082", "FFS", 0.01, 60], ["1000360", "FFS", 0.01, 60], ["100085", "FFS", 0.01, 60], ["100087", "FFS", 0.01, 60], ["100088", "FFS", 0.01, 60], ["100090", "FFS", 0.01, 60], ["100091", "FFS", 0.01, 36], ["100093", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 23], ["100095", "FFS", 0.01, 1], ["100096", "FFS", 0.01, 57], ["100097", "FFS", 0.01, 57], ["100098", "FFS", 0.01, 57], ["100099", "FFS", 0.01, 60], ["1000350", "FFS", 0.25, 47], ["100101", "FFS", 0.01, 60], ["100102", "FFS", 0.01, 60], ["100103", "FFS", 0.01, 1], ["100104", "FFS", 0.25, 47], ["100105", "FFS", 0.01, 60], ["100106", "FFS", 0.01, 36], ["100107", "FFS", 0.01, 60], ["100124", "FFS", 0.01, 36], ["100127", "FFS", 0.01, 43], ["100128", "FFS", 0.01, 36], ["100129", "FFS", 0.01, 36], ["1000530", "FFS", 0.01, 36], ["100132", "FFS", 0.01, 36], ["100133", "FFS", 0.01, 36], ["100134", "FFS", 0.01, 36], ["100144", "FFS", 0.01, 60], ["100145", "FFS", 0.01, 60]], "100155": [["100018", "FS", 1.0, 2], ["100020", "FS", 1.0, 2], ["100021", "FS", 1.0, 2], ["100049", "FS", 1.0, 2], ["100054", "FS", 1.0, 2], ["100055", "FS", 1.0, 2], ["100056", "FS", 1.0, 2], ["100057", "FS", 1.0, 2], ["100065", "FS", 1.0, 2], ["100066", "FS", 1.0, 2], ["100067", "FS", 1.0, 2], ["100068", "FS", 1.0, 2], ["100069", "FS", 1.0, 2], ["100071", "FFS", 0.17, 19], ["100072", "FFS", 0.01, 13], ["1000340", "FS", 1.0, 2], ["100077", "FS", 1.0, 2], ["100078", "FS", 1.0, 2], ["100079", "FS", 1.0, 2], ["100081", "FFS", 0.01, 13], ["100082", "FFS", 0.01, 13], ["1000360", "FFS", 0.01, 13], ["100085", "FFS", 0.01, 13], ["100087", "FFS", 0.01, 13], ["100088", "FFS", 0.01, 13], ["100089", "FFS", 0.17, 19], ["100090", "FFS", 0.01, 13], ["100093", "FFS", 0.01, 13], ["100094", "FS", 1.0, 2], ["100096", "FS", 1.0, 2], ["100097", "FS", 1.0, 2], ["100098", "FS", 1.0, 2], ["100099", "FFS", 0.01, 13], ["100101", "FFS", 0.01, 13], ["100102", "FFS", 0.01, 13], ["100107", "FFS", 0.01, 13], ["100111", "FFS", 0.17, 19], ["100112", "FFS", 0.17, 19], ["1000470", "FFS", 0.17, 19], ["100115", "FFS", 0.17, 19], ["100116", "FFS", 0.17, 19], ["100117", "FFS", 0.17, 19], ["100118", "FFS", 0.17, 19], ["100119", "FFS", 0.17, 19], ["100120", "FFS", 0.17, 19], ["100121", "FFS", 0.17, 19], ["100122", "FFS", 0.17, 19], ["100123", "FFS", 0.17, 19], ["100139", "FFS", 0.17, 19], ["100145", "FFS", 0.01, 13], ["100146", "FFS", 0.17, 19], ["100147", "FFS", 0.17, 19], ["100148", "FFS", 0.01, 2], ["100150", "FFS", 0.17, 19], ["100151", "FS", 1.0, 3], ["100152", "FFS", 0.17, 19], ["100153", "FS", 1.0, 1], ["100154", "FFS", 0.17, 19]], "100158": [["100004", "FS", 1.0, 1], ["100005", "FFS", 0.01, 17], ["100006", "FFS", 0.01, 17], ["100010", "FFS", 1.0, 6], ["100012", "FS", 1.0, 4], ["100013", "FFS", 0.01, 33], ["100014", "FS", 1.0, 4], ["100015", "FFS", 0.01, 33], ["100019", "FS", 1.0, 1], ["100022", "FFS", 0.65, 1], ["100023", "FFS", 0.67, 2], ["100024", "FFS", 0.67, 2], ["100025", "FFS", 0.67, 2], ["100026", "FS", 1.0, 1], ["100027", "FS", 1.0, 4], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100032", "FFS", 0.25, 2], ["100050", "FS", 1.0, 2], ["100071", "FS", 1.0, 1], ["100073", "FS", 1.0, 2], ["100089", "FS", 1.0, 1], ["1000350", "FS", 1.0, 2], ["100104", "FS", 1.0, 2], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100127", "FFS", 0.01, 4], ["100139", "FS", 1.0, 1], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100172", "FFS", 0.5, 17], ["10003310", "FFS", 0.5, 17], ["10003330", "FFS", 0.5, 17]], "100159": [["100010", "FS", 1.0, 1], ["100012", "SS", 0.2, 2], ["100014", "SS", 0.2, 2], ["100019", "SS", 0.1, 2], ["100033", "FFS", 0.01, 6], ["100050", "FFS", 0.01, 2], ["100071", "FS", 1.0, 1], ["100073", "FFS", 0.01, 2], ["100089", "FS", 1.0, 1], ["1000350", "FFS", 0.01, 2], ["100104", "FFS", 0.01, 2], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100127", "SS", 0.05, 3], ["100139", "FS", 1.0, 1], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100158", "FFS", 0.01, 6], ["100191", "FS", 1.0, 1], ["100192", "FS", 1.0, 1]], "100160": [["100004", "FS", 1.0, 1], ["100005", "FFS", 0.01, 17], ["100006", "FFS", 0.01, 17], ["100010", "FFS", 1.0, 6], ["100012", "FS", 1.0, 4], ["100013", "FFS", 0.01, 33], ["100014", "FS", 1.0, 4], ["100015", "FFS", 0.01, 33], ["100019", "FS", 1.0, 1], ["100022", "FFS", 0.65, 1], ["100023", "FFS", 0.67, 2], ["100024", "FFS", 0.67, 2], ["100025", "FFS", 0.67, 2], ["100026", "FS", 1.0, 1], ["100027", "FS", 1.0, 4], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100032", "FFS", 0.25, 2], ["100050", "FS", 1.0, 2], ["100071", "FS", 1.0, 1], ["100073", "FS", 1.0, 2], ["100089", "FS", 1.0, 1], ["1000350", "FS", 1.0, 2], ["100104", "FS", 1.0, 2], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100127", "FFS", 0.01, 4], ["100139", "FS", 1.0, 1], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100159", "FFS", 0.01, 6], ["100172", "FFS", 0.5, 17], ["10003310", "FFS", 0.5, 17], ["10003330", "FFS", 0.5, 17]], "1000540": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 20], ["100096", "FFS", 0.01, 102], ["100097", "FFS", 0.01, 102], ["100098", "FFS", 0.01, 102], ["1000350", "FFS", 0.01, 22], ["100104", "FFS", 0.01, 22], ["100105", "FFS", 0.01, 37], ["100111", "FFS", 0.01, 60], ["100112", "FFS", 0.01, 60], ["1000470", "FFS", 0.01, 60], ["100115", "FFS", 0.01, 60], ["100116", "FFS", 0.01, 60], ["100117", "FFS", 0.01, 60], ["100118", "FFS", 0.01, 60], ["100119", "FFS", 0.01, 60], ["100120", "FFS", 0.01, 60], ["100121", "FFS", 0.01, 60], ["100122", "FFS", 0.01, 60], ["100123", "FFS", 0.01, 60], ["1000460", "FFS", 0.01, 18], ["100126", "FFS", 0.01, 18], ["100127", "FFS", 0.01, 48], ["100130", "FFS", 0.01, 18], ["100139", "FFS", 0.01, 60], ["100141", "FS", 1.0, 1], ["100142", "FFS", 0.01, 5], ["100143", "FFS", 0.01, 13], ["100144", "FFS", 0.01, 37], ["100146", "FFS", 0.01, 60], ["100147", "FFS", 0.01, 60], ["100148", "FS", 1.0, 2], ["100149", "FFS", 0.01, 18], ["100150", "FFS", 0.01, 60], ["100151", "FFS", 0.01, 3], ["100152", "FFS", 0.01, 60], ["100153", "FS", 1.0, 1], ["100154", "FFS", 0.01, 60], ["100155", "FFS", 0.01, 13], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100162": [["100001", "FS", 1.0, 2], ["100003", "FS", 1.0, 2], ["100012", "FFS", 0.11, 5], ["100014", "FFS", 0.11, 5], ["100023", "FFS", 0.43, 4], ["100024", "FFS", 0.43, 4], ["100025", "FFS", 0.43, 4], ["100026", "FS", 1.0, 2], ["100028", "FS", 1.0, 4], ["100029", "FS", 1.0, 2], ["100030", "FS", 1.0, 2], ["100033", "FFS", 0.01, 33], ["100035", "FFS", 0.35, 8], ["100036", "FFS", 0.35, 8], ["100071", "FS", 1.0, 1], ["100072", "FFS", 0.01, 18], ["100081", "FFS", 0.01, 18], ["100082", "FFS", 0.01, 18], ["1000360", "FFS", 0.01, 18], ["100085", "FFS", 0.01, 18], ["100087", "FFS", 0.01, 18], ["100088", "FFS", 0.01, 18], ["100089", "FS", 1.0, 1], ["100090", "FFS", 0.01, 18], ["100093", "FFS", 0.01, 18], ["100099", "FFS", 0.01, 18], ["100101", "FFS", 0.01, 18], ["100102", "FFS", 0.01, 18], ["100105", "FS", 1.0, 4], ["100107", "FFS", 0.01, 18], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100139", "FS", 1.0, 1], ["100144", "FS", 1.0, 4], ["100145", "FFS", 0.01, 18], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100158", "FFS", 0.01, 33], ["100159", "FS", 1.0, 2], ["100160", "FFS", 0.01, 33], ["1000540", "FFS", 0.01, 18]], "100163": [["100001", "FS", 1.0, 2], ["100003", "FS", 1.0, 2], ["100012", "FFS", 0.11, 5], ["100014", "FFS", 0.11, 5], ["100023", "FFS", 0.43, 4], ["100024", "FFS", 0.43, 4], ["100025", "FFS", 0.43, 4], ["100026", "FS", 1.0, 2], ["100028", "FS", 1.0, 4], ["100029", "FS", 1.0, 2], ["100030", "FS", 1.0, 2], ["100033", "FFS", 0.01, 33], ["100035", "FFS", 0.35, 8], ["100036", "FFS", 0.35, 8], ["100071", "FS", 1.0, 1], ["100072", "FFS", 0.01, 18], ["100081", "FFS", 0.01, 18], ["100082", "FFS", 0.01, 18], ["1000360", "FFS", 0.01, 18], ["100085", "FFS", 0.01, 18], ["100087", "FFS", 0.01, 18], ["100088", "FFS", 0.01, 18], ["100089", "FS", 1.0, 1], ["100090", "FFS", 0.01, 18], ["100093", "FFS", 0.01, 18], ["100099", "FFS", 0.01, 18], ["100101", "FFS", 0.01, 18], ["100102", "FFS", 0.01, 18], ["100105", "FS", 1.0, 4], ["100107", "FFS", 0.01, 18], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100139", "FS", 1.0, 1], ["100144", "FS", 1.0, 4], ["100145", "FFS", 0.01, 18], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100158", "FFS", 0.01, 33], ["100159", "FS", 1.0, 2], ["100160", "FFS", 0.01, 33], ["1000540", "FFS", 0.01, 18]], "100164": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 20], ["100096", "FFS", 0.01, 102], ["100097", "FFS", 0.01, 102], ["100098", "FFS", 0.01, 102], ["1000350", "FFS", 0.01, 22], ["100104", "FFS", 0.01, 22], ["100105", "FFS", 0.01, 37], ["100111", "FFS", 0.01, 60], ["100112", "FFS", 0.01, 60], ["1000470", "FFS", 0.01, 60], ["100115", "FFS", 0.01, 60], ["100116", "FFS", 0.01, 60], ["100117", "FFS", 0.01, 60], ["100118", "FFS", 0.01, 60], ["100119", "FFS", 0.01, 60], ["100120", "FFS", 0.01, 60], ["100121", "FFS", 0.01, 60], ["100122", "FFS", 0.01, 60], ["100123", "FFS", 0.01, 60], ["1000460", "FFS", 0.01, 18], ["100126", "FFS", 0.01, 18], ["100127", "FFS", 0.01, 48], ["100130", "FFS", 0.01, 18], ["100139", "FFS", 0.01, 60], ["100141", "FS", 1.0, 1], ["100142", "FFS", 0.01, 5], ["100143", "FFS", 0.01, 13], ["100144", "FFS", 0.01, 37], ["100146", "FFS", 0.01, 60], ["100147", "FFS", 0.01, 60], ["100148", "FS", 1.0, 2], ["100149", "FFS", 0.01, 18], ["100150", "FFS", 0.01, 60], ["100151", "FFS", 0.01, 3], ["100152", "FFS", 0.01, 60], ["100153", "FS", 1.0, 1], ["100154", "FFS", 0.01, 60], ["100155", "FFS", 0.01, 13], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100162", "FFS", 0.01, 18], ["100163", "FFS", 0.01, 18], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100165": [["100013", "FS", 1.0, 1], ["100015", "FS", 1.0, 1], ["100033", "FS", 1.0, 1], ["100072", "FS", 1.0, 4], ["100081", "FS", 1.0, 4], ["100082", "FS", 1.0, 4], ["1000360", "FS", 1.0, 4], ["100085", "FS", 1.0, 4], ["100087", "FS", 1.0, 4], ["100088", "FS", 1.0, 4], ["100090", "FS", 1.0, 4], ["100093", "FS", 1.0, 4], ["100099", "FS", 1.0, 4], ["100101", "FS", 1.0, 4], ["100102", "FS", 1.0, 4], ["100107", "FS", 1.0, 4], ["100145", "FS", 1.0, 4], ["100158", "FS", 1.0, 1], ["100159", "FS", 1.0, 1], ["100160", "FS", 1.0, 1], ["1000540", "FS", 1.0, 4], ["100162", "FS", 1.0, 1], ["100163", "FS", 1.0, 1], ["100164", "FS", 1.0, 4], ["100168", "FS", 1.0, 1], ["100169", "FS", 1.0, 1], ["100175", "FS", 1.0, 1], ["100176", "FS", 1.0, 1], ["100178", "FS", 1.0, 1], ["100181", "FS", 1.0, 1], ["100184", "FS", 1.0, 1], ["1000560", "FS", 1.0, 1]], "100166": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 20], ["100096", "FFS", 0.01, 102], ["100097", "FFS", 0.01, 102], ["100098", "FFS", 0.01, 102], ["1000350", "FFS", 0.01, 22], ["100104", "FFS", 0.01, 22], ["100105", "FFS", 0.01, 37], ["100111", "FFS", 0.01, 60], ["100112", "FFS", 0.01, 60], ["1000470", "FFS", 0.01, 60], ["100115", "FFS", 0.01, 60], ["100116", "FFS", 0.01, 60], ["100117", "FFS", 0.01, 60], ["100118", "FFS", 0.01, 60], ["100119", "FFS", 0.01, 60], ["100120", "FFS", 0.01, 60], ["100121", "FFS", 0.01, 60], ["100122", "FFS", 0.01, 60], ["100123", "FFS", 0.01, 60], ["1000460", "FFS", 0.01, 18], ["100126", "FFS", 0.01, 18], ["100127", "FFS", 0.01, 48], ["100130", "FFS", 0.01, 18], ["100139", "FFS", 0.01, 60], ["100141", "FS", 1.0, 1], ["100142", "FFS", 0.01, 5], ["100143", "FFS", 0.01, 13], ["100144", "FFS", 0.01, 37], ["100146", "FFS", 0.01, 60], ["100147", "FFS", 0.01, 60], ["100148", "FS", 1.0, 2], ["100149", "FFS", 0.01, 18], ["100150", "FFS", 0.01, 60], ["100151", "FFS", 0.01, 3], ["100152", "FFS", 0.01, 60], ["100153", "FS", 1.0, 1], ["100154", "FFS", 0.01, 60], ["100155", "FFS", 0.01, 13], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100162", "FFS", 0.01, 18], ["100163", "FFS", 0.01, 18], ["100165", "FS", 1.0, 4], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100167": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 20], ["100096", "FFS", 0.01, 102], ["100097", "FFS", 0.01, 102], ["100098", "FFS", 0.01, 102], ["1000350", "FFS", 0.01, 22], ["100104", "FFS", 0.01, 22], ["100105", "FFS", 0.01, 37], ["100111", "FFS", 0.01, 60], ["100112", "FFS", 0.01, 60], ["1000470", "FFS", 0.01, 60], ["100115", "FFS", 0.01, 60], ["100116", "FFS", 0.01, 60], ["100117", "FFS", 0.01, 60], ["100118", "FFS", 0.01, 60], ["100119", "FFS", 0.01, 60], ["100120", "FFS", 0.01, 60], ["100121", "FFS", 0.01, 60], ["100122", "FFS", 0.01, 60], ["100123", "FFS", 0.01, 60], ["1000460", "FFS", 0.01, 18], ["100126", "FFS", 0.01, 18], ["100127", "FFS", 0.01, 48], ["100130", "FFS", 0.01, 18], ["100139", "FFS", 0.01, 60], ["100141", "FS", 1.0, 1], ["100142", "FFS", 0.01, 5], ["100143", "FFS", 0.01, 13], ["100144", "FFS", 0.01, 37], ["100146", "FFS", 0.01, 60], ["100147", "FFS", 0.01, 60], ["100148", "FS", 1.0, 2], ["100149", "FFS", 0.01, 18], ["100150", "FFS", 0.01, 60], ["100151", "FFS", 0.01, 3], ["100152", "FFS", 0.01, 60], ["100153", "FS", 1.0, 1], ["100154", "FFS", 0.01, 60], ["100155", "FFS", 0.01, 13], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100162", "FFS", 0.01, 18], ["100163", "FFS", 0.01, 18], ["100165", "FS", 1.0, 4], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100168": [["100004", "FS", 1.0, 1], ["100005", "FFS", 0.01, 17], ["100006", "FFS", 0.01, 17], ["100010", "FFS", 1.0, 6], ["100012", "FS", 1.0, 4], ["100013", "FFS", 0.01, 33], ["100014", "FS", 1.0, 4], ["100015", "FFS", 0.01, 33], ["100019", "FS", 1.0, 1], ["100022", "FFS", 0.65, 1], ["100023", "FFS", 0.67, 2], ["100024", "FFS", 0.67, 2], ["100025", "FFS", 0.67, 2], ["100026", "FS", 1.0, 1], ["100027", "FS", 1.0, 4], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100032", "FFS", 0.25, 2], ["100050", "FS", 1.0, 2], ["100071", "FS", 1.0, 1], ["100073", "FS", 1.0, 2], ["100089", "FS", 1.0, 1], ["1000350", "FS", 1.0, 2], ["100104", "FS", 1.0, 2], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100127", "FFS", 0.01, 4], ["100139", "FS", 1.0, 1], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100159", "FFS", 0.01, 6], ["100162", "FFS", 0.01, 33], ["100163", "FFS", 0.01, 33], ["100172", "FFS", 0.5, 17], ["10003310", "FFS", 0.5, 17], ["10003330", "FFS", 0.5, 17]], "100169": [["100004", "FS", 1.0, 1], ["100005", "FFS", 0.01, 17], ["100006", "FFS", 0.01, 17], ["100010", "FFS", 1.0, 6], ["100012", "FS", 1.0, 4], ["100013", "FFS", 0.01, 33], ["100014", "FS", 1.0, 4], ["100015", "FFS", 0.01, 33], ["100019", "FS", 1.0, 1], ["100022", "FFS", 0.65, 1], ["100023", "FFS", 0.67, 2], ["100024", "FFS", 0.67, 2], ["100025", "FFS", 0.67, 2], ["100026", "FS", 1.0, 1], ["100027", "FS", 1.0, 4], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100032", "FFS", 0.25, 2], ["100050", "FS", 1.0, 2], ["100071", "FS", 1.0, 1], ["100073", "FS", 1.0, 2], ["100089", "FS", 1.0, 1], ["1000350", "FS", 1.0, 2], ["100104", "FS", 1.0, 2], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100127", "FFS", 0.01, 4], ["100139", "FS", 1.0, 1], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100159", "FFS", 0.01, 6], ["100162", "FFS", 0.01, 33], ["100163", "FFS", 0.01, 33], ["100172", "FFS", 0.5, 17], ["10003310", "FFS", 0.5, 17], ["10003330", "FFS", 0.5, 17]], "100170": [["100003", "FS", 1.0, 1], ["100005", "FS", 1.0, 13], ["100006", "FS", 1.0, 13], ["100027", "FFS", 0.97, 1], ["100028", "FS", 1.0, 1], ["100033", "FS", 1.0, 8], ["100071", "FS", 1.0, 1], ["100072", "FFS", 1.0, 5], ["100081", "FFS", 1.0, 5], ["100082", "FFS", 1.0, 5], ["1000360", "FFS", 1.0, 5], ["100085", "FFS", 1.0, 5], ["100087", "FFS", 1.0, 5], ["100088", "FFS", 1.0, 5], ["100089", "FS", 1.0, 1], ["100090", "FFS", 1.0, 5], ["100093", "FFS", 1.0, 5], ["100099", "FFS", 1.0, 5], ["100101", "FFS", 1.0, 5], ["100102", "FFS", 1.0, 5], ["100105", "FS", 1.0, 1], ["100107", "FFS", 1.0, 5], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100139", "FS", 1.0, 1], ["100144", "FS", 1.0, 1], ["100145", "FFS", 1.0, 5], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100158", "FS", 1.0, 8], ["100160", "FS", 1.0, 8], ["1000540", "FFS", 1.0, 5], ["100164", "FFS", 1.0, 5], ["100166", "FFS", 1.0, 5], ["100167", "FFS", 1.0, 5], ["100168", "FS", 1.0, 8], ["100169", "FS", 1.0, 8], ["100172", "FS", 1.0, 13], ["10003310", "FS", 1.0, 13], ["10003330", "FS", 1.0, 13]], "10003300": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 20], ["100096", "FFS", 0.01, 102], ["100097", "FFS", 0.01, 102], ["100098", "FFS", 0.01, 102], ["1000350", "FFS", 0.01, 22], ["100104", "FFS", 0.01, 22], ["100105", "FFS", 0.01, 37], ["100111", "FFS", 0.01, 60], ["100112", "FFS", 0.01, 60], ["1000470", "FFS", 0.01, 60], ["100115", "FFS", 0.01, 60], ["100116", "FFS", 0.01, 60], ["100117", "FFS", 0.01, 60], ["100118", "FFS", 0.01, 60], ["100119", "FFS", 0.01, 60], ["100120", "FFS", 0.01, 60], ["100121", "FFS", 0.01, 60], ["100122", "FFS", 0.01, 60], ["100123", "FFS", 0.01, 60], ["1000460", "FFS", 0.01, 18], ["100126", "FFS", 0.01, 18], ["100127", "FFS", 0.01, 48], ["100130", "FFS", 0.01, 18], ["100139", "FFS", 0.01, 60], ["100141", "FS", 1.0, 1], ["100142", "FFS", 0.01, 5], ["100143", "FFS", 0.01, 13], ["100144", "FFS", 0.01, 37], ["100146", "FFS", 0.01, 60], ["100147", "FFS", 0.01, 60], ["100148", "FS", 1.0, 2], ["100149", "FFS", 0.01, 18], ["100150", "FFS", 0.01, 60], ["100151", "FFS", 0.01, 3], ["100152", "FFS", 0.01, 60], ["100153", "FS", 1.0, 1], ["100154", "FFS", 0.01, 60], ["100155", "FFS", 0.01, 13], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100162", "FFS", 0.01, 18], ["100163", "FFS", 0.01, 18], ["100165", "FS", 1.0, 4], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100170", "SS", 0.33, 5], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100172": [["100001", "FFS", 0.01, 368], ["100002", "FFS", 0.01, 180], ["100003", "FFS", 0.01, 322], ["100004", "FFS", 0.01, 53], ["100010", "FFS", 0.01, 134], ["100012", "FFS", 0.71, 1], ["100013", "FFS", 0.55, 3], ["100014", "FFS", 0.71, 1], ["100015", "FFS", 0.55, 3], ["100018", "FS", 1.0, 3], ["100019", "FFS", 0.01, 58], ["100020", "FS", 1.0, 3], ["100021", "FS", 1.0, 3], ["100023", "FFS", 0.95, 2], ["100024", "FFS", 0.95, 2], ["100025", "FFS", 0.95, 2], ["100028", "FS", 1.0, 14], ["100034", "FS", 1.0, 1], ["100035", "FFS", 0.08, 5], ["100036", "FFS", 0.08, 5], ["100039", "FS", 1.0, 8], ["100040", "FS", 1.0, 2], ["100041", "FS", 1.0, 2], ["100042", "FS", 1.0, 8], ["1000320", "FS", 1.0, 2], ["100044", "FS", 1.0, 8], ["100045", "FS", 1.0, 8], ["100046", "FS", 1.0, 8], ["100047", "FS", 1.0, 8], ["100049", "FFS", 0.2, 12], ["100050", "FFS", 0.01, 80], ["100054", "FFS", 0.2, 12], ["100055", "FFS", 0.2, 12], ["100056", "FFS", 0.2, 12], ["100057", "FFS", 0.2, 12], ["100065", "FFS", 0.2, 12], ["100066", "FFS", 0.2, 12], ["100067", "FFS", 0.2, 12], ["100068", "FFS", 0.2, 12], ["100069", "FFS", 0.2, 12], ["100071", "FFS", 0.25, 11], ["100072", "FFS", 0.25, 16], ["100073", "FFS", 0.01, 80], ["1000340", "FS", 1.0, 3], ["100077", "FS", 1.0, 3], ["100078", "FS", 1.0, 3], ["100079", "FS", 1.0, 3], ["100081", "FFS", 0.25, 16], ["100082", "FFS", 0.25, 16], ["1000360", "FFS", 0.25, 16], ["100085", "FFS", 0.25, 16], ["100087", "FFS", 0.25, 16], ["100088", "FFS", 0.25, 16], ["100089", "FFS", 0.25, 11], ["100090", "FFS", 0.25, 16], ["100091", "FS", 1.0, 5], ["100093", "FFS", 0.25, 16], ["100094", "FS", 1.0, 3], ["100096", "FFS", 0.2, 12], ["100097", "FFS", 0.2, 12], ["100098", "FFS", 0.2, 12], ["100099", "FFS", 0.25, 16], ["1000350", "FFS", 0.01, 80], ["100101", "FFS", 0.25, 16], ["100102", "FFS", 0.25, 16], ["100104", "FFS", 0.01, 80], ["100105", "FS", 1.0, 14], ["100106", "FS", 1.0, 5], ["100107", "FFS", 0.25, 16], ["100111", "FFS", 0.25, 11], ["100112", "FFS", 0.25, 11], ["1000470", "FFS", 0.25, 11], ["100115", "FFS", 0.25, 11], ["100116", "FFS", 0.25, 11], ["100117", "FFS", 0.25, 11], ["100118", "FFS", 0.25, 11], ["100119", "FFS", 0.25, 11], ["100120", "FFS", 0.25, 11], ["100121", "FFS", 0.25, 11], ["100122", "FFS", 0.25, 11], ["100123", "FFS", 0.25, 11], ["100124", "FS", 1.0, 5], ["1000460", "FS", 1.0, 2], ["100126", "FS", 1.0, 2], ["100127", "FFS", 0.01, 177], ["100128", "FS", 1.0, 5], ["100129", "FS", 1.0, 5], ["100130", "FS", 1.0, 2], ["1000530", "FS", 1.0, 5], ["100132", "FS", 1.0, 5], ["100133", "FS", 1.0, 5], ["100134", "FS", 1.0, 5], ["100139", "FFS", 0.25, 11], ["100144", "FS", 1.0, 14], ["100145", "FFS", 0.25, 16], ["100146", "FFS", 0.25, 11], ["100147", "FFS", 0.25, 11], ["100149", "FS", 1.0, 2], ["100150", "FFS", 0.25, 11], ["100151", "FS", 1.0, 1], ["100152", "FFS", 0.25, 11], ["100154", "FFS", 0.25, 11], ["1000540", "FFS", 0.25, 16], ["100162", "FFS", 0.55, 3], ["100163", "FFS", 0.55, 3], ["100164", "FFS", 0.25, 16], ["100165", "FS", 1.0, 1], ["100166", "FFS", 0.25, 16], ["100167", "FFS", 0.25, 16], ["10003300", "FFS", 0.25, 16], ["100173", "FS", 1.0, 16], ["100174", "FS", 1.0, 16], ["10003320", "FS", 1.0, 16], ["100182", "FS", 1.0, 16], ["100183", "FS", 1.0, 16], ["10003340", "FS", 1.0, 16]], "100173": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 20], ["100096", "FFS", 0.01, 102], ["100097", "FFS", 0.01, 102], ["100098", "FFS", 0.01, 102], ["1000350", "FFS", 0.01, 22], ["100104", "FFS", 0.01, 22], ["100105", "FFS", 0.01, 37], ["100111", "FFS", 0.01, 60], ["100112", "FFS", 0.01, 60], ["1000470", "FFS", 0.01, 60], ["100115", "FFS", 0.01, 60], ["100116", "FFS", 0.01, 60], ["100117", "FFS", 0.01, 60], ["100118", "FFS", 0.01, 60], ["100119", "FFS", 0.01, 60], ["100120", "FFS", 0.01, 60], ["100121", "FFS", 0.01, 60], ["100122", "FFS", 0.01, 60], ["100123", "FFS", 0.01, 60], ["1000460", "FFS", 0.01, 18], ["100126", "FFS", 0.01, 18], ["100127", "FFS", 0.01, 48], ["100130", "FFS", 0.01, 18], ["100139", "FFS", 0.01, 60], ["100141", "FS", 1.0, 1], ["100142", "FFS", 0.01, 5], ["100143", "FFS", 0.01, 13], ["100144", "FFS", 0.01, 37], ["100146", "FFS", 0.01, 60], ["100147", "FFS", 0.01, 60], ["100148", "FS", 1.0, 2], ["100149", "FFS", 0.01, 18], ["100150", "FFS", 0.01, 60], ["100151", "FFS", 0.01, 3], ["100152", "FFS", 0.01, 60], ["100153", "FS", 1.0, 1], ["100154", "FFS", 0.01, 60], ["100155", "FFS", 0.01, 13], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100162", "FFS", 0.01, 18], ["100163", "FFS", 0.01, 18], ["100165", "FS", 1.0, 4], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100170", "SS", 0.33, 5], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100174": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 20], ["100096", "FFS", 0.01, 102], ["100097", "FFS", 0.01, 102], ["100098", "FFS", 0.01, 102], ["1000350", "FFS", 0.01, 22], ["100104", "FFS", 0.01, 22], ["100105", "FFS", 0.01, 37], ["100111", "FFS", 0.01, 60], ["100112", "FFS", 0.01, 60], ["1000470", "FFS", 0.01, 60], ["100115", "FFS", 0.01, 60], ["100116", "FFS", 0.01, 60], ["100117", "FFS", 0.01, 60], ["100118", "FFS", 0.01, 60], ["100119", "FFS", 0.01, 60], ["100120", "FFS", 0.01, 60], ["100121", "FFS", 0.01, 60], ["100122", "FFS", 0.01, 60], ["100123", "FFS", 0.01, 60], ["1000460", "FFS", 0.01, 18], ["100126", "FFS", 0.01, 18], ["100127", "FFS", 0.01, 48], ["100130", "FFS", 0.01, 18], ["100139", "FFS", 0.01, 60], ["100141", "FS", 1.0, 1], ["100142", "FFS", 0.01, 5], ["100143", "FFS", 0.01, 13], ["100144", "FFS", 0.01, 37], ["100146", "FFS", 0.01, 60], ["100147", "FFS", 0.01, 60], ["100148", "FS", 1.0, 2], ["100149", "FFS", 0.01, 18], ["100150", "FFS", 0.01, 60], ["100151", "FFS", 0.01, 3], ["100152", "FFS", 0.01, 60], ["100153", "FS", 1.0, 1], ["100154", "FFS", 0.01, 60], ["100155", "FFS", 0.01, 13], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100162", "FFS", 0.01, 18], ["100163", "FFS", 0.01, 18], ["100165", "FS", 1.0, 4], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100170", "SS", 0.33, 5], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100175": [["100004", "FS", 1.0, 1], ["100005", "FFS", 0.01, 17], ["100006", "FFS", 0.01, 17], ["100010", "FFS", 1.0, 6], ["100012", "FS", 1.0, 4], ["100013", "FFS", 0.01, 33], ["100014", "FS", 1.0, 4], ["100015", "FFS", 0.01, 33], ["100019", "FS", 1.0, 1], ["100022", "FFS", 0.65, 1], ["100023", "FFS", 0.67, 2], ["100024", "FFS", 0.67, 2], ["100025", "FFS", 0.67, 2], ["100026", "FS", 1.0, 1], ["100027", "FS", 1.0, 4], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100032", "FFS", 0.25, 2], ["100050", "FS", 1.0, 2], ["100071", "FS", 1.0, 1], ["100073", "FS", 1.0, 2], ["100089", "FS", 1.0, 1], ["1000350", "FS", 1.0, 2], ["100104", "FS", 1.0, 2], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100127", "FFS", 0.01, 4], ["100139", "FS", 1.0, 1], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100159", "FFS", 0.01, 6], ["100162", "FFS", 0.01, 33], ["100163", "FFS", 0.01, 33], ["100170", "FFS", 0.67, 8], ["100172", "FFS", 0.01, 17], ["10003310", "FFS", 0.5, 17], ["10003330", "FFS", 0.5, 17]], "100176": [["100004", "FS", 1.0, 1], ["100005", "FFS", 0.01, 17], ["100006", "FFS", 0.01, 17], ["100010", "FFS", 1.0, 6], ["100012", "FS", 1.0, 4], ["100013", "FFS", 0.01, 33], ["100014", "FS", 1.0, 4], ["100015", "FFS", 0.01, 33], ["100019", "FS", 1.0, 1], ["100022", "FFS", 0.65, 1], ["100023", "FFS", 0.67, 2], ["100024", "FFS", 0.67, 2], ["100025", "FFS", 0.67, 2], ["100026", "FS", 1.0, 1], ["100027", "FS", 1.0, 4], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100032", "FFS", 0.25, 2], ["100050", "FS", 1.0, 2], ["100071", "FS", 1.0, 1], ["100073", "FS", 1.0, 2], ["100089", "FS", 1.0, 1], ["1000350", "FS", 1.0, 2], ["100104", "FS", 1.0, 2], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100127", "FFS", 0.01, 4], ["100139", "FS", 1.0, 1], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100159", "FFS", 0.01, 6], ["100162", "FFS", 0.01, 33], ["100163", "FFS", 0.01, 33], ["100170", "FFS", 0.67, 8], ["100172", "FFS", 0.01, 17], ["10003310", "FFS", 0.5, 17], ["10003330", "FFS", 0.5, 17]], "100177": [["100003", "FS", 1.0, 1], ["100005", "FS", 1.0, 13], ["100006", "FS", 1.0, 13], ["100027", "FFS", 0.97, 1], ["100028", "FS", 1.0, 1], ["100033", "FS", 1.0, 8], ["100071", "FS", 1.0, 1], ["100072", "FFS", 1.0, 5], ["100081", "FFS", 1.0, 5], ["100082", "FFS", 1.0, 5], ["1000360", "FFS", 1.0, 5], ["100085", "FFS", 1.0, 5], ["100087", "FFS", 1.0, 5], ["100088", "FFS", 1.0, 5], ["100089", "FS", 1.0, 1], ["100090", "FFS", 1.0, 5], ["100093", "FFS", 1.0, 5], ["100099", "FFS", 1.0, 5], ["100101", "FFS", 1.0, 5], ["100102", "FFS", 1.0, 5], ["100105", "FS", 1.0, 1], ["100107", "FFS", 1.0, 5], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100139", "FS", 1.0, 1], ["100144", "FS", 1.0, 1], ["100145", "FFS", 1.0, 5], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100158", "FS", 1.0, 8], ["100160", "FS", 1.0, 8], ["1000540", "FFS", 1.0, 5], ["100164", "FFS", 1.0, 5], ["100166", "FFS", 1.0, 5], ["100167", "FFS", 1.0, 5], ["100168", "FS", 1.0, 8], ["100169", "FS", 1.0, 8], ["10003300", "FFS", 1.0, 5], ["100172", "FS", 1.0, 13], ["100173", "FFS", 1.0, 5], ["100174", "FFS", 1.0, 5], ["100175", "FS", 1.0, 8], ["100176", "FS", 1.0, 8], ["10003310", "FS", 1.0, 13], ["10003330", "FS", 1.0, 13]], "100178": [["100004", "FS", 1.0, 1], ["100005", "FFS", 0.01, 17], ["100006", "FFS", 0.01, 17], ["100010", "FFS", 1.0, 6], ["100012", "FS", 1.0, 4], ["100013", "FFS", 0.01, 33], ["100014", "FS", 1.0, 4], ["100015", "FFS", 0.01, 33], ["100019", "FS", 1.0, 1], ["100022", "FFS", 0.65, 1], ["100023", "FFS", 0.67, 2], ["100024", "FFS", 0.67, 2], ["100025", "FFS", 0.67, 2], ["100026", "FS", 1.0, 1], ["100027", "FS", 1.0, 4], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100032", "FFS", 0.25, 2], ["100050", "FS", 1.0, 2], ["100071", "FS", 1.0, 1], ["100073", "FS", 1.0, 2], ["100089", "FS", 1.0, 1], ["1000350", "FS", 1.0, 2], ["100104", "FS", 1.0, 2], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100127", "FFS", 0.01, 4], ["100139", "FS", 1.0, 1], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100159", "FFS", 0.01, 6], ["100162", "FFS", 0.01, 33], ["100163", "FFS", 0.01, 33], ["100170", "FFS", 0.67, 8], ["100172", "FFS", 0.01, 17], ["100177", "FFS", 0.67, 8], ["10003310", "FFS", 0.5, 17], ["10003330", "FFS", 0.5, 17]], "10003320": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 20], ["100096", "FFS", 0.01, 102], ["100097", "FFS", 0.01, 102], ["100098", "FFS", 0.01, 102], ["1000350", "FFS", 0.01, 22], ["100104", "FFS", 0.01, 22], ["100105", "FFS", 0.01, 37], ["100111", "FFS", 0.01, 60], ["100112", "FFS", 0.01, 60], ["1000470", "FFS", 0.01, 60], ["100115", "FFS", 0.01, 60], ["100116", "FFS", 0.01, 60], ["100117", "FFS", 0.01, 60], ["100118", "FFS", 0.01, 60], ["100119", "FFS", 0.01, 60], ["100120", "FFS", 0.01, 60], ["100121", "FFS", 0.01, 60], ["100122", "FFS", 0.01, 60], ["100123", "FFS", 0.01, 60], ["1000460", "FFS", 0.01, 18], ["100126", "FFS", 0.01, 18], ["100127", "FFS", 0.01, 48], ["100130", "FFS", 0.01, 18], ["100139", "FFS", 0.01, 60], ["100141", "FS", 1.0, 1], ["100142", "FFS", 0.01, 5], ["100143", "FFS", 0.01, 13], ["100144", "FFS", 0.01, 37], ["100146", "FFS", 0.01, 60], ["100147", "FFS", 0.01, 60], ["100148", "FS", 1.0, 2], ["100149", "FFS", 0.01, 18], ["100150", "FFS", 0.01, 60], ["100151", "FFS", 0.01, 3], ["100152", "FFS", 0.01, 60], ["100153", "FS", 1.0, 1], ["100154", "FFS", 0.01, 60], ["100155", "FFS", 0.01, 13], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100162", "FFS", 0.01, 18], ["100163", "FFS", 0.01, 18], ["100165", "FS", 1.0, 4], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100170", "SS", 0.33, 5], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100177", "SS", 0.33, 5], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "10003310": [["100001", "FFS", 0.01, 368], ["100002", "FFS", 0.01, 180], ["100003", "FFS", 0.01, 322], ["100004", "FFS", 0.01, 53], ["100010", "FFS", 0.01, 134], ["100012", "FFS", 0.71, 1], ["100013", "FFS", 0.55, 3], ["100014", "FFS", 0.71, 1], ["100015", "FFS", 0.55, 3], ["100018", "FS", 1.0, 3], ["100019", "FFS", 0.01, 58], ["100020", "FS", 1.0, 3], ["100021", "FS", 1.0, 3], ["100023", "FFS", 0.95, 2], ["100024", "FFS", 0.95, 2], ["100025", "FFS", 0.95, 2], ["100028", "FS", 1.0, 14], ["100034", "FS", 1.0, 1], ["100035", "FFS", 0.08, 5], ["100036", "FFS", 0.08, 5], ["100039", "FS", 1.0, 8], ["100040", "FS", 1.0, 2], ["100041", "FS", 1.0, 2], ["100042", "FS", 1.0, 8], ["1000320", "FS", 1.0, 2], ["100044", "FS", 1.0, 8], ["100045", "FS", 1.0, 8], ["100046", "FS", 1.0, 8], ["100047", "FS", 1.0, 8], ["100049", "FFS", 0.2, 12], ["100050", "FFS", 0.01, 80], ["100054", "FFS", 0.2, 12], ["100055", "FFS", 0.2, 12], ["100056", "FFS", 0.2, 12], ["100057", "FFS", 0.2, 12], ["100065", "FFS", 0.2, 12], ["100066", "FFS", 0.2, 12], ["100067", "FFS", 0.2, 12], ["100068", "FFS", 0.2, 12], ["100069", "FFS", 0.2, 12], ["100071", "FFS", 0.25, 11], ["100072", "FFS", 0.25, 16], ["100073", "FFS", 0.01, 80], ["1000340", "FS", 1.0, 3], ["100077", "FS", 1.0, 3], ["100078", "FS", 1.0, 3], ["100079", "FS", 1.0, 3], ["100081", "FFS", 0.25, 16], ["100082", "FFS", 0.25, 16], ["1000360", "FFS", 0.25, 16], ["100085", "FFS", 0.25, 16], ["100087", "FFS", 0.25, 16], ["100088", "FFS", 0.25, 16], ["100089", "FFS", 0.25, 11], ["100090", "FFS", 0.25, 16], ["100091", "FS", 1.0, 5], ["100093", "FFS", 0.25, 16], ["100094", "FS", 1.0, 3], ["100096", "FFS", 0.2, 12], ["100097", "FFS", 0.2, 12], ["100098", "FFS", 0.2, 12], ["100099", "FFS", 0.25, 16], ["1000350", "FFS", 0.01, 80], ["100101", "FFS", 0.25, 16], ["100102", "FFS", 0.25, 16], ["100104", "FFS", 0.01, 80], ["100105", "FS", 1.0, 14], ["100106", "FS", 1.0, 5], ["100107", "FFS", 0.25, 16], ["100111", "FFS", 0.25, 11], ["100112", "FFS", 0.25, 11], ["1000470", "FFS", 0.25, 11], ["100115", "FFS", 0.25, 11], ["100116", "FFS", 0.25, 11], ["100117", "FFS", 0.25, 11], ["100118", "FFS", 0.25, 11], ["100119", "FFS", 0.25, 11], ["100120", "FFS", 0.25, 11], ["100121", "FFS", 0.25, 11], ["100122", "FFS", 0.25, 11], ["100123", "FFS", 0.25, 11], ["100124", "FS", 1.0, 5], ["1000460", "FS", 1.0, 2], ["100126", "FS", 1.0, 2], ["100127", "FFS", 0.01, 177], ["100128", "FS", 1.0, 5], ["100129", "FS", 1.0, 5], ["100130", "FS", 1.0, 2], ["1000530", "FS", 1.0, 5], ["100132", "FS", 1.0, 5], ["100133", "FS", 1.0, 5], ["100134", "FS", 1.0, 5], ["100139", "FFS", 0.25, 11], ["100144", "FS", 1.0, 14], ["100145", "FFS", 0.25, 16], ["100146", "FFS", 0.25, 11], ["100147", "FFS", 0.25, 11], ["100149", "FS", 1.0, 2], ["100150", "FFS", 0.25, 11], ["100151", "FS", 1.0, 1], ["100152", "FFS", 0.25, 11], ["100154", "FFS", 0.25, 11], ["1000540", "FFS", 0.25, 16], ["100162", "FFS", 0.55, 3], ["100163", "FFS", 0.55, 3], ["100164", "FFS", 0.25, 16], ["100165", "FS", 1.0, 1], ["100166", "FFS", 0.25, 16], ["100167", "FFS", 0.25, 16], ["10003300", "FFS", 0.25, 16], ["100173", "FFS", 0.25, 16], ["100174", "FFS", 0.25, 16], ["10003320", "FFS", 0.25, 16], ["100182", "FS", 1.0, 16], ["100183", "FS", 1.0, 16], ["10003340", "FS", 1.0, 16]], "100181": [["100004", "FS", 1.0, 1], ["100005", "FFS", 0.01, 17], ["100006", "FFS", 0.01, 17], ["100010", "FFS", 1.0, 6], ["100012", "FS", 1.0, 4], ["100013", "FFS", 0.01, 33], ["100014", "FS", 1.0, 4], ["100015", "FFS", 0.01, 33], ["100019", "FS", 1.0, 1], ["100022", "FFS", 0.65, 1], ["100023", "FFS", 0.67, 2], ["100024", "FFS", 0.67, 2], ["100025", "FFS", 0.67, 2], ["100026", "FS", 1.0, 1], ["100027", "FS", 1.0, 4], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100032", "FFS", 0.25, 2], ["100050", "FS", 1.0, 2], ["100071", "FS", 1.0, 1], ["100073", "FS", 1.0, 2], ["100089", "FS", 1.0, 1], ["1000350", "FS", 1.0, 2], ["100104", "FS", 1.0, 2], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100127", "FFS", 0.01, 4], ["100139", "FS", 1.0, 1], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100159", "FFS", 0.01, 6], ["100162", "FFS", 0.01, 33], ["100163", "FFS", 0.01, 33], ["100170", "FFS", 0.67, 8], ["100172", "FFS", 0.01, 17], ["100177", "FFS", 0.67, 8], ["10003310", "FFS", 0.01, 17], ["10003330", "FFS", 0.5, 17]], "100182": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 20], ["100096", "FFS", 0.01, 102], ["100097", "FFS", 0.01, 102], ["100098", "FFS", 0.01, 102], ["1000350", "FFS", 0.01, 22], ["100104", "FFS", 0.01, 22], ["100105", "FFS", 0.01, 37], ["100111", "FFS", 0.01, 60], ["100112", "FFS", 0.01, 60], ["1000470", "FFS", 0.01, 60], ["100115", "FFS", 0.01, 60], ["100116", "FFS", 0.01, 60], ["100117", "FFS", 0.01, 60], ["100118", "FFS", 0.01, 60], ["100119", "FFS", 0.01, 60], ["100120", "FFS", 0.01, 60], ["100121", "FFS", 0.01, 60], ["100122", "FFS", 0.01, 60], ["100123", "FFS", 0.01, 60], ["1000460", "FFS", 0.01, 18], ["100126", "FFS", 0.01, 18], ["100127", "FFS", 0.01, 48], ["100130", "FFS", 0.01, 18], ["100139", "FFS", 0.01, 60], ["100141", "FS", 1.0, 1], ["100142", "FFS", 0.01, 5], ["100143", "FFS", 0.01, 13], ["100144", "FFS", 0.01, 37], ["100146", "FFS", 0.01, 60], ["100147", "FFS", 0.01, 60], ["100148", "FS", 1.0, 2], ["100149", "FFS", 0.01, 18], ["100150", "FFS", 0.01, 60], ["100151", "FFS", 0.01, 3], ["100152", "FFS", 0.01, 60], ["100153", "FS", 1.0, 1], ["100154", "FFS", 0.01, 60], ["100155", "FFS", 0.01, 13], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100162", "FFS", 0.01, 18], ["100163", "FFS", 0.01, 18], ["100165", "FS", 1.0, 4], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100170", "SS", 0.33, 5], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100177", "SS", 0.33, 5], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100183": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 20], ["100096", "FFS", 0.01, 102], ["100097", "FFS", 0.01, 102], ["100098", "FFS", 0.01, 102], ["1000350", "FFS", 0.01, 22], ["100104", "FFS", 0.01, 22], ["100105", "FFS", 0.01, 37], ["100111", "FFS", 0.01, 60], ["100112", "FFS", 0.01, 60], ["1000470", "FFS", 0.01, 60], ["100115", "FFS", 0.01, 60], ["100116", "FFS", 0.01, 60], ["100117", "FFS", 0.01, 60], ["100118", "FFS", 0.01, 60], ["100119", "FFS", 0.01, 60], ["100120", "FFS", 0.01, 60], ["100121", "FFS", 0.01, 60], ["100122", "FFS", 0.01, 60], ["100123", "FFS", 0.01, 60], ["1000460", "FFS", 0.01, 18], ["100126", "FFS", 0.01, 18], ["100127", "FFS", 0.01, 48], ["100130", "FFS", 0.01, 18], ["100139", "FFS", 0.01, 60], ["100141", "FS", 1.0, 1], ["100142", "FFS", 0.01, 5], ["100143", "FFS", 0.01, 13], ["100144", "FFS", 0.01, 37], ["100146", "FFS", 0.01, 60], ["100147", "FFS", 0.01, 60], ["100148", "FS", 1.0, 2], ["100149", "FFS", 0.01, 18], ["100150", "FFS", 0.01, 60], ["100151", "FFS", 0.01, 3], ["100152", "FFS", 0.01, 60], ["100153", "FS", 1.0, 1], ["100154", "FFS", 0.01, 60], ["100155", "FFS", 0.01, 13], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100162", "FFS", 0.01, 18], ["100163", "FFS", 0.01, 18], ["100165", "FS", 1.0, 4], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100170", "SS", 0.33, 5], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100177", "SS", 0.33, 5], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100184": [["100004", "FS", 1.0, 1], ["100005", "FFS", 0.01, 17], ["100006", "FFS", 0.01, 17], ["100010", "FFS", 1.0, 6], ["100012", "FS", 1.0, 4], ["100013", "FFS", 0.01, 33], ["100014", "FS", 1.0, 4], ["100015", "FFS", 0.01, 33], ["100019", "FS", 1.0, 1], ["100022", "FFS", 0.65, 1], ["100023", "FFS", 0.67, 2], ["100024", "FFS", 0.67, 2], ["100025", "FFS", 0.67, 2], ["100026", "FS", 1.0, 1], ["100027", "FS", 1.0, 4], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100032", "FFS", 0.25, 2], ["100050", "FS", 1.0, 2], ["100071", "FS", 1.0, 1], ["100073", "FS", 1.0, 2], ["100089", "FS", 1.0, 1], ["1000350", "FS", 1.0, 2], ["100104", "FS", 1.0, 2], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100127", "FFS", 0.01, 4], ["100139", "FS", 1.0, 1], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100159", "FFS", 0.01, 6], ["100162", "FFS", 0.01, 33], ["100163", "FFS", 0.01, 33], ["100170", "FFS", 0.67, 8], ["100172", "FFS", 0.01, 17], ["100177", "FFS", 0.67, 8], ["10003310", "FFS", 0.01, 17], ["10003330", "FFS", 0.5, 17]], "1000560": [["100004", "FS", 1.0, 1], ["100005", "FFS", 0.01, 17], ["100006", "FFS", 0.01, 17], ["100010", "FFS", 1.0, 6], ["100012", "FS", 1.0, 4], ["100013", "FFS", 0.01, 33], ["100014", "FS", 1.0, 4], ["100015", "FFS", 0.01, 33], ["100019", "FS", 1.0, 1], ["100022", "FFS", 0.65, 1], ["100023", "FFS", 0.67, 2], ["100024", "FFS", 0.67, 2], ["100025", "FFS", 0.67, 2], ["100026", "FS", 1.0, 1], ["100027", "FS", 1.0, 4], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100032", "FFS", 0.25, 2], ["100050", "FS", 1.0, 2], ["100071", "FS", 1.0, 1], ["100073", "FS", 1.0, 2], ["100089", "FS", 1.0, 1], ["1000350", "FS", 1.0, 2], ["100104", "FS", 1.0, 2], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100127", "FFS", 0.01, 4], ["100139", "FS", 1.0, 1], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100159", "FFS", 0.01, 6], ["100162", "FFS", 0.01, 33], ["100163", "FFS", 0.01, 33], ["100170", "FFS", 0.67, 8], ["100172", "FFS", 0.01, 17], ["100177", "FFS", 0.67, 8], ["10003310", "FFS", 0.01, 17], ["10003330", "FFS", 0.5, 17]], "100186": [["100003", "FS", 1.0, 1], ["100005", "FS", 1.0, 13], ["100006", "FS", 1.0, 13], ["100027", "FFS", 0.97, 1], ["100028", "FS", 1.0, 1], ["100033", "FS", 1.0, 8], ["100071", "FS", 1.0, 1], ["100072", "FFS", 1.0, 5], ["100081", "FFS", 1.0, 5], ["100082", "FFS", 1.0, 5], ["1000360", "FFS", 1.0, 5], ["100085", "FFS", 1.0, 5], ["100087", "FFS", 1.0, 5], ["100088", "FFS", 1.0, 5], ["100089", "FS", 1.0, 1], ["100090", "FFS", 1.0, 5], ["100093", "FFS", 1.0, 5], ["100099", "FFS", 1.0, 5], ["100101", "FFS", 1.0, 5], ["100102", "FFS", 1.0, 5], ["100105", "FS", 1.0, 1], ["100107", "FFS", 1.0, 5], ["100111", "FS", 1.0, 1], ["100112", "FS", 1.0, 1], ["1000470", "FS", 1.0, 1], ["100115", "FS", 1.0, 1], ["100116", "FS", 1.0, 1], ["100117", "FS", 1.0, 1], ["100118", "FS", 1.0, 1], ["100119", "FS", 1.0, 1], ["100120", "FS", 1.0, 1], ["100121", "FS", 1.0, 1], ["100122", "FS", 1.0, 1], ["100123", "FS", 1.0, 1], ["100139", "FS", 1.0, 1], ["100144", "FS", 1.0, 1], ["100145", "FFS", 1.0, 5], ["100146", "FS", 1.0, 1], ["100147", "FS", 1.0, 1], ["100150", "FS", 1.0, 1], ["100152", "FS", 1.0, 1], ["100154", "FS", 1.0, 1], ["100158", "FS", 1.0, 8], ["100160", "FS", 1.0, 8], ["1000540", "FFS", 1.0, 5], ["100164", "FFS", 1.0, 5], ["100166", "FFS", 1.0, 5], ["100167", "FFS", 1.0, 5], ["100168", "FS", 1.0, 8], ["100169", "FS", 1.0, 8], ["10003300", "FFS", 1.0, 5], ["100172", "FS", 1.0, 13], ["100173", "FFS", 1.0, 5], ["100174", "FFS", 1.0, 5], ["100175", "FS", 1.0, 8], ["100176", "FS", 1.0, 8], ["100178", "FS", 1.0, 8], ["10003320", "FFS", 1.0, 5], ["10003310", "FS", 1.0, 13], ["100181", "FS", 1.0, 8], ["100182", "FFS", 1.0, 5], ["100183", "FFS", 1.0, 5], ["100184", "FS", 1.0, 8], ["1000560", "FS", 1.0, 8], ["10003330", "FS", 1.0, 13]], "10003330": [["100001", "FFS", 0.01, 368], ["100002", "FFS", 0.01, 180], ["100003", "FFS", 0.01, 322], ["100004", "FFS", 0.01, 53], ["100010", "FFS", 0.01, 134], ["100012", "FFS", 0.71, 1], ["100013", "FFS", 0.55, 3], ["100014", "FFS", 0.71, 1], ["100015", "FFS", 0.55, 3], ["100018", "FS", 1.0, 3], ["100019", "FFS", 0.01, 58], ["100020", "FS", 1.0, 3], ["100021", "FS", 1.0, 3], ["100023", "FFS", 0.95, 2], ["100024", "FFS", 0.95, 2], ["100025", "FFS", 0.95, 2], ["100028", "FS", 1.0, 14], ["100034", "FS", 1.0, 1], ["100035", "FFS", 0.08, 5], ["100036", "FFS", 0.08, 5], ["100039", "FS", 1.0, 8], ["100040", "FS", 1.0, 2], ["100041", "FS", 1.0, 2], ["100042", "FS", 1.0, 8], ["1000320", "FS", 1.0, 2], ["100044", "FS", 1.0, 8], ["100045", "FS", 1.0, 8], ["100046", "FS", 1.0, 8], ["100047", "FS", 1.0, 8], ["100049", "FFS", 0.2, 12], ["100050", "FFS", 0.01, 80], ["100054", "FFS", 0.2, 12], ["100055", "FFS", 0.2, 12], ["100056", "FFS", 0.2, 12], ["100057", "FFS", 0.2, 12], ["100065", "FFS", 0.2, 12], ["100066", "FFS", 0.2, 12], ["100067", "FFS", 0.2, 12], ["100068", "FFS", 0.2, 12], ["100069", "FFS", 0.2, 12], ["100071", "FFS", 0.25, 11], ["100072", "FFS", 0.25, 16], ["100073", "FFS", 0.01, 80], ["1000340", "FS", 1.0, 3], ["100077", "FS", 1.0, 3], ["100078", "FS", 1.0, 3], ["100079", "FS", 1.0, 3], ["100081", "FFS", 0.25, 16], ["100082", "FFS", 0.25, 16], ["1000360", "FFS", 0.25, 16], ["100085", "FFS", 0.25, 16], ["100087", "FFS", 0.25, 16], ["100088", "FFS", 0.25, 16], ["100089", "FFS", 0.25, 11], ["100090", "FFS", 0.25, 16], ["100091", "FS", 1.0, 5], ["100093", "FFS", 0.25, 16], ["100094", "FS", 1.0, 3], ["100096", "FFS", 0.2, 12], ["100097", "FFS", 0.2, 12], ["100098", "FFS", 0.2, 12], ["100099", "FFS", 0.25, 16], ["1000350", "FFS", 0.01, 80], ["100101", "FFS", 0.25, 16], ["100102", "FFS", 0.25, 16], ["100104", "FFS", 0.01, 80], ["100105", "FS", 1.0, 14], ["100106", "FS", 1.0, 5], ["100107", "FFS", 0.25, 16], ["100111", "FFS", 0.25, 11], ["100112", "FFS", 0.25, 11], ["1000470", "FFS", 0.25, 11], ["100115", "FFS", 0.25, 11], ["100116", "FFS", 0.25, 11], ["100117", "FFS", 0.25, 11], ["100118", "FFS", 0.25, 11], ["100119", "FFS", 0.25, 11], ["100120", "FFS", 0.25, 11], ["100121", "FFS", 0.25, 11], ["100122", "FFS", 0.25, 11], ["100123", "FFS", 0.25, 11], ["100124", "FS", 1.0, 5], ["1000460", "FS", 1.0, 2], ["100126", "FS", 1.0, 2], ["100127", "FFS", 0.01, 177], ["100128", "FS", 1.0, 5], ["100129", "FS", 1.0, 5], ["100130", "FS", 1.0, 2], ["1000530", "FS", 1.0, 5], ["100132", "FS", 1.0, 5], ["100133", "FS", 1.0, 5], ["100134", "FS", 1.0, 5], ["100139", "FFS", 0.25, 11], ["100144", "FS", 1.0, 14], ["100145", "FFS", 0.25, 16], ["100146", "FFS", 0.25, 11], ["100147", "FFS", 0.25, 11], ["100149", "FS", 1.0, 2], ["100150", "FFS", 0.25, 11], ["100151", "FS", 1.0, 1], ["100152", "FFS", 0.25, 11], ["100154", "FFS", 0.25, 11], ["1000540", "FFS", 0.25, 16], ["100162", "FFS", 0.55, 3], ["100163", "FFS", 0.55, 3], ["100164", "FFS", 0.25, 16], ["100165", "FS", 1.0, 1], ["100166", "FFS", 0.25, 16], ["100167", "FFS", 0.25, 16], ["10003300", "FFS", 0.25, 16], ["100173", "FFS", 0.25, 16], ["100174", "FFS", 0.25, 16], ["10003320", "FFS", 0.25, 16], ["100182", "FFS", 0.25, 16], ["100183", "FFS", 0.25, 16], ["10003340", "FS", 1.0, 16]], "10003340": [["100001", "FFS", 0.01, 6], ["100003", "FS", 1.0, 3], ["100004", "FFS", 0.01, 5], ["100010", "FFS", 0.01, 26], ["100012", "FS", 1.0, 6], ["100013", "FFS", 0.01, 18], ["100014", "FS", 1.0, 6], ["100015", "FFS", 0.01, 18], ["100018", "FFS", 0.01, 20], ["100019", "FFS", 0.1, 8], ["100020", "FFS", 0.01, 20], ["100021", "FFS", 0.01, 20], ["100023", "FS", 1.0, 1], ["100024", "FS", 1.0, 1], ["100025", "FS", 1.0, 1], ["100026", "FS", 1.0, 1], ["100028", "FFS", 0.01, 37], ["100029", "FS", 1.0, 1], ["100030", "FS", 1.0, 1], ["100033", "FFS", 0.88, 12], ["100035", "FFS", 0.01, 10], ["100036", "FFS", 0.01, 10], ["100039", "SS", 0.46, 2], ["100042", "SS", 0.46, 2], ["100044", "SS", 0.46, 2], ["100045", "SS", 0.46, 2], ["100046", "SS", 0.46, 2], ["100047", "SS", 0.46, 2], ["100049", "FFS", 0.01, 102], ["100050", "FFS", 0.01, 22], ["100054", "FFS", 0.01, 102], ["100055", "FFS", 0.01, 102], ["100056", "FFS", 0.01, 102], ["100057", "FFS", 0.01, 102], ["100065", "FFS", 0.01, 102], ["100066", "FFS", 0.01, 102], ["100067", "FFS", 0.01, 102], ["100068", "FFS", 0.01, 102], ["100069", "FFS", 0.01, 102], ["100071", "FFS", 0.01, 60], ["100073", "FFS", 0.01, 22], ["1000340", "FFS", 0.01, 20], ["100077", "FFS", 0.01, 20], ["100078", "FFS", 0.01, 20], ["100079", "FFS", 0.01, 20], ["100080", "FFS", 0.01, 8], ["100084", "FFS", 0.01, 8], ["100086", "FFS", 0.01, 2], ["100089", "FFS", 0.01, 60], ["100094", "FFS", 0.01, 20], ["100096", "FFS", 0.01, 102], ["100097", "FFS", 0.01, 102], ["100098", "FFS", 0.01, 102], ["1000350", "FFS", 0.01, 22], ["100104", "FFS", 0.01, 22], ["100105", "FFS", 0.01, 37], ["100111", "FFS", 0.01, 60], ["100112", "FFS", 0.01, 60], ["1000470", "FFS", 0.01, 60], ["100115", "FFS", 0.01, 60], ["100116", "FFS", 0.01, 60], ["100117", "FFS", 0.01, 60], ["100118", "FFS", 0.01, 60], ["100119", "FFS", 0.01, 60], ["100120", "FFS", 0.01, 60], ["100121", "FFS", 0.01, 60], ["100122", "FFS", 0.01, 60], ["100123", "FFS", 0.01, 60], ["1000460", "FFS", 0.01, 18], ["100126", "FFS", 0.01, 18], ["100127", "FFS", 0.01, 48], ["100130", "FFS", 0.01, 18], ["100139", "FFS", 0.01, 60], ["100141", "FS", 1.0, 1], ["100142", "FFS", 0.01, 5], ["100143", "FFS", 0.01, 13], ["100144", "FFS", 0.01, 37], ["100146", "FFS", 0.01, 60], ["100147", "FFS", 0.01, 60], ["100148", "FS", 1.0, 2], ["100149", "FFS", 0.01, 18], ["100150", "FFS", 0.01, 60], ["100151", "FFS", 0.01, 3], ["100152", "FFS", 0.01, 60], ["100153", "FS", 1.0, 1], ["100154", "FFS", 0.01, 60], ["100155", "FFS", 0.01, 13], ["100158", "FFS", 0.88, 12], ["100159", "FS", 1.0, 5], ["100160", "FFS", 0.88, 12], ["100162", "FFS", 0.01, 18], ["100163", "FFS", 0.01, 18], ["100165", "FS", 1.0, 4], ["100168", "FFS", 0.88, 12], ["100169", "FFS", 0.88, 12], ["100170", "SS", 0.33, 5], ["100175", "FFS", 0.88, 12], ["100176", "FFS", 0.88, 12], ["100177", "SS", 0.33, 5], ["100178", "FFS", 0.88, 12], ["100181", "FFS", 0.88, 12], ["100184", "FFS", 0.88, 12], ["1000560", "FFS", 0.88, 12], ["100186", "SS", 0.33, 5], ["100191", "FFS", 0.38, 85], ["100192", "FFS", 0.38, 85]], "100189": [["100071", "FFS", 0.01, 4], ["100072", "FFS", 0.01, 5], ["100081", "FFS", 0.01, 5], ["100082", "FFS", 0.01, 5], ["1000360", "FFS", 0.01, 5], ["100085", "FFS", 0.01, 5], ["100087", "FFS", 0.01, 5], ["100088", "FFS", 0.01, 5], ["100089", "FFS", 0.01, 4], ["100090", "FFS", 0.01, 5], ["100093", "FFS", 0.01, 5], ["100099", "FFS", 0.01, 5], ["100101", "FFS", 0.01, 5], ["100102", "FFS", 0.01, 5], ["100107", "FFS", 0.01, 5], ["100111", "FFS", 0.01, 4], ["100112", "FFS", 0.01, 4], ["1000470", "FFS", 0.01, 4], ["100115", "FFS", 0.01, 4], ["100116", "FFS", 0.01, 4], ["100117", "FFS", 0.01, 4], ["100118", "FFS", 0.01, 4], ["100119", "FFS", 0.01, 4], ["100120", "FFS", 0.01, 4], ["100121", "FFS", 0.01, 4], ["100122", "FFS", 0.01, 4], ["100123", "FFS", 0.01, 4], ["1000460", "FFS", 0.01, 2], ["100126", "FFS", 0.01, 2], ["100130", "FFS", 0.01, 2], ["100139", "FFS", 0.01, 4], ["100143", "FS", 1.0, 3], ["100145", "FFS", 0.01, 5], ["100146", "FFS", 0.01, 4], ["100147", "FFS", 0.01, 4], ["100149", "FFS", 0.01, 2], ["100150", "FFS", 0.01, 4], ["100151", "FS", 1.0, 2], ["100152", "FFS", 0.01, 4], ["100154", "FFS", 0.01, 4], ["100155", "FS", 1.0, 3], ["1000540", "FFS", 0.01, 5], ["100164", "FFS", 0.01, 5], ["100166", "FFS", 0.01, 5], ["100167", "FFS", 0.01, 5], ["10003300", "FFS", 0.01, 5], ["100173", "FFS", 0.01, 5], ["100174", "FFS", 0.01, 5], ["10003320", "FFS", 0.01, 5], ["100182", "FFS", 0.01, 5], ["100183", "FFS", 0.01, 5], ["10003340", "FFS", 0.01, 5]], "100190": [["100142", "FFS", 0.01, 3], ["100189", "FFS", 0.01, 3], ["100191", "SS", 0.93, 3], ["100192", "SS", 0.93, 3]], "100191": [["100001", "FFS", 0.4, 10], ["100003", "FS", 1.0, 9], ["100005", "FS", 1.0, 4], ["100006", "FS", 1.0, 4], ["100010", "FFS", 0.01, 10], ["100012", "FS", 1.0, 2], ["100014", "FS", 1.0, 2], ["100019", "FS", 1.0, 2], ["100027", "FS", 1.0, 2], ["100028", "FFS", 0.3, 38], ["100035", "FS", 1.0, 4], ["100036", "FS", 1.0, 4], ["100039", "FS", 1.0, 8], ["100042", "FS", 1.0, 8], ["100044", "FS", 1.0, 8], ["100045", "FS", 1.0, 8], ["100046", "FS", 1.0, 8], ["100047", "FS", 1.0, 8], ["100049", "FFS", 0.01, 25], ["100050", "FFS", 0.48, 19], ["100054", "FFS", 0.01, 25], ["100055", "FFS", 0.01, 25], ["100056", "FFS", 0.01, 25], ["100057", "FFS", 0.01, 25], ["100063", "FFS", 0.4, 1], ["100065", "FFS", 0.01, 25], ["100066", "FFS", 0.01, 25], ["100067", "FFS", 0.01, 25], ["100068", "FFS", 0.01, 25], ["100069", "FFS", 0.01, 25], ["100071", "FFS", 0.01, 118], ["100073", "FFS", 0.48, 19], ["100089", "FFS", 0.01, 118], ["100096", "FFS", 0.01, 25], ["100097", "FFS", 0.01, 25], ["100098", "FFS", 0.01, 25], ["1000350", "FFS", 0.48, 19], ["100104", "FFS", 0.48, 19], ["100105", "FFS", 0.3, 38], ["100111", "FFS", 0.01, 118], ["100112", "FFS", 0.01, 118], ["1000470", "FFS", 0.01, 118], ["100115", "FFS", 0.01, 118], ["100116", "FFS", 0.01, 118], ["100117", "FFS", 0.01, 118], ["100118", "FFS", 0.01, 118], ["100119", "FFS", 0.01, 118], ["100120", "FFS", 0.01, 118], ["100121", "FFS", 0.01, 118], ["100122", "FFS", 0.01, 118], ["100123", "FFS", 0.01, 118], ["100127", "FFS", 0.01, 35], ["100139", "FFS", 0.01, 118], ["100142", "FFS", 0.01, 23], ["100143", "FFS", 0.23, 15], ["100144", "FFS", 0.3, 38], ["100146", "FFS", 0.01, 118], ["100147", "FFS", 0.01, 118], ["100148", "FS", 1.0, 2], ["100150", "FFS", 0.01, 118], ["100152", "FFS", 0.01, 118], ["100154", "FFS", 0.01, 118], ["100155", "FFS", 0.23, 15], ["100172", "FS", 1.0, 4], ["10003310", "FS", 1.0, 4], ["10003330", "FS", 1.0, 4], ["100189", "FFS", 0.01, 23]], "100192": [["100001", "FFS", 0.4, 10], ["100003", "FS", 1.0, 9], ["100005", "FS", 1.0, 4], ["100006", "FS", 1.0, 4], ["100010", "FFS", 0.01, 10], ["100012", "FS", 1.0, 2], ["100014", "FS", 1.0, 2], ["100019", "FS", 1.0, 2], ["100027", "FS", 1.0, 2], ["100028", "FFS", 0.3, 38], ["100035", "FS", 1.0, 4], ["100036", "FS", 1.0, 4], ["100039", "FS", 1.0, 8], ["100042", "FS", 1.0, 8], ["100044", "FS", 1.0, 8], ["100045", "FS", 1.0, 8], ["100046", "FS", 1.0, 8], ["100047", "FS", 1.0, 8], ["100049", "FFS", 0.01, 25], ["100050", "FFS", 0.48, 19], ["100054", "FFS", 0.01, 25], ["100055", "FFS", 0.01, 25], ["100056", "FFS", 0.01, 25], ["100057", "FFS", 0.01, 25], ["100063", "FFS", 0.4, 1], ["100065", "FFS", 0.01, 25], ["100066", "FFS", 0.01, 25], ["100067", "FFS", 0.01, 25], ["100068", "FFS", 0.01, 25], ["100069", "FFS", 0.01, 25], ["100071", "FFS", 0.01, 118], ["100073", "FFS", 0.48, 19], ["100089", "FFS", 0.01, 118], ["100096", "FFS", 0.01, 25], ["100097", "FFS", 0.01, 25], ["100098", "FFS", 0.01, 25], ["1000350", "FFS", 0.48, 19], ["100104", "FFS", 0.48, 19], ["100105", "FFS", 0.3, 38], ["100111", "FFS", 0.01, 118], ["100112", "FFS", 0.01, 118], ["1000470", "FFS", 0.01, 118], ["100115", "FFS", 0.01, 118], ["100116", "FFS", 0.01, 118], ["100117", "FFS", 0.01, 118], ["100118", "FFS", 0.01, 118], ["100119", "FFS", 0.01, 118], ["100120", "FFS", 0.01, 118], ["100121", "FFS", 0.01, 118], ["100122", "FFS", 0.01, 118], ["100123", "FFS", 0.01, 118], ["100127", "FFS", 0.01, 35], ["100139", "FFS", 0.01, 118], ["100142", "FFS", 0.01, 23], ["100143", "FFS", 0.23, 15], ["100144", "FFS", 0.3, 38], ["100146", "FFS", 0.01, 118], ["100147", "FFS", 0.01, 118], ["100148", "FS", 1.0, 2], ["100150", "FFS", 0.01, 118], ["100152", "FFS", 0.01, 118], ["100154", "FFS", 0.01, 118], ["100155", "FFS", 0.23, 15], ["100172", "FS", 1.0, 4], ["10003310", "FS", 1.0, 4], ["10003330", "FS", 1.0, 4], ["100189", "FFS", 0.01, 23]]}

    gas_network.update(electroline)
    gas_network.update(dormitory)
    connections_dict = gas_network
    all_works = tasks_df['activity_id'].values

    for task_id, pred_info_lst in connections_dict.items():
        if str(task_id) not in all_works:
            continue

        row = tasks_df.loc[id2ind[str(task_id)]]

        # | ------ change links and info about them ------ |
        # by default, the links and their information change
        if len(pred_info_lst) > 0:
            pred_ids_lst, pred_types_lst, pred_lags_lst, pred_counts_lst = map(list, zip(*pred_info_lst))
        else:
            pred_ids_lst, pred_types_lst, pred_lags_lst, pred_counts_lst = ['-1'], ['-1'], [1.0], [INF]

        if not all_connections:
            pred_ids_lst_tmp, pred_types_lst_tmp, pred_lags_lst_tmp, pred_counts_lst_tmp = (
                row['predecessor_ids'].copy(), row['connection_types'].copy(), row['lags'].copy(), [INF] * len(row['lags']))
            if change_connections_info:
                pred_ids_lst_tmp, pred_types_lst_tmp, pred_lags_lst_tmp, pred_counts_lst_tmp = (
                    update_connections(pred_ids_lst_tmp, pred_ids_lst, pred_types_lst, pred_lags_lst, pred_counts_lst))
            pred_ids_lst, pred_types_lst, pred_lags_lst, pred_counts_lst = (
                append_new_connections(pred_ids_lst_tmp, pred_ids_lst, pred_types_lst, pred_lags_lst, pred_counts_lst))
        else:
            if row['predecessor_ids'] != ['-1']:
                # if 'lags' is unknown, thus 'connection_type' is also unknown
                pred_info_lst = [[pred_types_lst[i], pred_lags_lst[i], pred_counts_lst[i]]
                                 for i in range(len(pred_ids_lst)) if pred_ids_lst[i] in row['predecessor_ids']]
                pred_ids_lst = row['predecessor_ids']
                if len(pred_info_lst) > 0:
                    pred_types_lst, pred_lags_lst, pred_counts_lst = map(list, zip(*pred_info_lst))
                else:
                    pred_types_lst, pred_lags_lst, pred_counts_lst = ['-1'], [1.0], [INF]

        while len(pred_ids_lst) != len(pred_types_lst):
            pred_types_lst.append('FS')
            pred_lags_lst.append(1.0)
            pred_counts_lst.append(0)
        for col, val in zip(['predecessor_ids', 'connection_types', 'lags', 'counts'], [pred_ids_lst, pred_types_lst, pred_lags_lst, pred_counts_lst]):
            tasks_df.at[id2ind[str(task_id)], col] = val

    tasks_df['connection_types'] = tasks_df['connection_types'].apply(
        lambda x: [EdgeType(elem) if elem != '-1' else EdgeType.FinishStart for elem in x]
    )

    return tasks_df
